# .ArenaTournamentsApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiTeamArena**](ArenaTournamentsApi.md#apiTeamArena) | **GET** /api/team/{teamId}/arena | Get team Arena tournaments
[**apiTournament**](ArenaTournamentsApi.md#apiTournament) | **GET** /api/tournament | Get current tournaments
[**apiTournamentJoin**](ArenaTournamentsApi.md#apiTournamentJoin) | **POST** /api/tournament/{id}/join | Join an Arena tournament
[**apiTournamentPost**](ArenaTournamentsApi.md#apiTournamentPost) | **POST** /api/tournament | Create a new Arena tournament
[**apiTournamentTeamBattlePost**](ArenaTournamentsApi.md#apiTournamentTeamBattlePost) | **POST** /api/tournament/team-battle/{id} | Update a team battle
[**apiTournamentTerminate**](ArenaTournamentsApi.md#apiTournamentTerminate) | **POST** /api/tournament/{id}/terminate | Terminate an Arena tournament
[**apiTournamentUpdate**](ArenaTournamentsApi.md#apiTournamentUpdate) | **POST** /api/tournament/{id} | Update an Arena tournament
[**apiTournamentWithdraw**](ArenaTournamentsApi.md#apiTournamentWithdraw) | **POST** /api/tournament/{id}/withdraw | Pause of leave an Arena tournament
[**apiUserNameTournamentCreated**](ArenaTournamentsApi.md#apiUserNameTournamentCreated) | **GET** /api/user/{username}/tournament/created | Get tournaments created by a user
[**gamesByTournament**](ArenaTournamentsApi.md#gamesByTournament) | **GET** /api/tournament/{id}/games | Export games of an Arena tournament
[**resultsByTournament**](ArenaTournamentsApi.md#resultsByTournament) | **GET** /api/tournament/{id}/results | Get results of an Arena tournament
[**teamsByTournament**](ArenaTournamentsApi.md#teamsByTournament) | **GET** /api/tournament/{id}/teams | Get team standing of a team battle
[**tournament**](ArenaTournamentsApi.md#tournament) | **GET** /api/tournament/{id} | Get info about an Arena tournament


# **apiTeamArena**
> Array<any> apiTeamArena()

Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ArenaTournamentsApi(configuration);

let body:.ArenaTournamentsApiApiTeamArenaRequest = {
  // string | ID of the team
  teamId: "teamId_example",
  // number | How many tournaments to download. (optional)
  max: 100,
};

apiInstance.apiTeamArena(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | [**string**] | ID of the team | defaults to undefined
 **max** | [**number**] | How many tournaments to download. | (optional) defaults to 100


### Return type

**Array<any>**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of Arena tournaments of a team. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiTournament**
> ArenaTournaments apiTournament()

Get recently finished, ongoing, and upcoming tournaments.  This API is used to display the [Lichess tournament schedule](https://lichess.org/tournament). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ArenaTournamentsApi(configuration);

let body:any = {};

apiInstance.apiTournament(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters
This endpoint does not need any parameter.


### Return type

**ArenaTournaments**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of current tournaments. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiTournamentJoin**
> Ok apiTournamentJoin()

Join an Arena tournament, possibly with a password and/or a team. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ArenaTournamentsApi(configuration);

let body:.ArenaTournamentsApiApiTournamentJoinRequest = {
  // string | The tournament ID.
  id: "hL7vMrFQ",
  // string | The tournament password, if one is required (optional)
  password: "password_example",
  // string | The team to join the tournament with, for team battle tournaments (optional)
  team: "team_example",
};

apiInstance.apiTournamentJoin(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] | The tournament ID. | defaults to undefined
 **password** | [**string**] | The tournament password, if one is required | (optional) defaults to undefined
 **team** | [**string**] | The team to join the tournament with, for team battle tournaments | (optional) defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The tournament was successfully joined. |  * Access-Control-Allow-Origin -  <br>  |
**400** | Joining the tournament failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiTournamentPost**
> any apiTournamentPost()

Create a public or private Arena tournament.  This endpoint mirrors the form on <https://lichess.org/tournament/new>.  You can create up to 12 public tournaments per day, or 24 private tournaments.  A team battle can be created by specifying the `teambBattleByTeam` argument. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ArenaTournamentsApi(configuration);

let body:.ArenaTournamentsApiApiTournamentPostRequest = {
  // number | Clock initial time in minutes
  clockTime: 2,
  // number | Clock increment in seconds
  clockIncrement: 1,
  // number | How long the tournament lasts, in minutes
  minutes: 60,
  // string | The tournament name. Leave empty to get a random Grandmaster name (optional)
  name: "name_example",
  // number | How long to wait before starting the tournament, from now, in minutes (optional)
  waitMinutes: 5,
  // number | Timestamp to start the tournament at a given date and time. Overrides the `waitMinutes` setting (optional)
  startDate: 1,
  // VariantKey (optional)
  variant: "standard",
  // boolean | Games are rated and impact players ratings (optional)
  rated: true,
  // string | Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). (optional)
  position: "position_example",
  // boolean | Whether the players can use berserk (optional)
  berserkable: true,
  // boolean | After 2 wins, consecutive wins grant 4 points instead of 2. (optional)
  streakable: true,
  // boolean | Whether the players can discuss in a chat (optional)
  hasChat: true,
  // string | Anything you want to tell players about the tournament (optional)
  description: "description_example",
  // string | Make the tournament private, and restrict access with a password (optional)
  password: "password_example",
  // string | Set the ID of a team you lead to create a team battle. The other teams can be added using the [team battle edit endpoint](#operation/apiTournamentTeamBattlePost).  (optional)
  teambBattleByTeam: "teambBattleByTeam_example",
  // string | Restrict entry to members of a team.  The teamId is the last part of a team URL, e.g. `https://lichess.org/team/coders` has teamId = `coders`.  Leave empty to let everyone join the tournament.  Do not use this to create team battles, use `teamBattleByTeam` instead.  (optional)
  conditionsTeamMemberTeamId: "conditionsTeamMemberTeamId_example",
  // number | Minimum rating to join. Leave empty to let everyone join the tournament. (optional)
  conditionsMinRatingRating: 1,
  // number | Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. (optional)
  conditionsMaxRatingRating: 1,
  // number | Minimum number of rated games required to join. (optional)
  conditionsNbRatedGameNb: 1,
};

apiInstance.apiTournamentPost(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **clockTime** | [**number**]**Array<0 &#124; 0.25 &#124; 0.5 &#124; 0.75 &#124; 1 &#124; 1.5 &#124; 2 &#124; 3 &#124; 4 &#124; 5 &#124; 6 &#124; 7 &#124; 10 &#124; 15 &#124; 20 &#124; 25 &#124; 30 &#124; 40 &#124; 50 &#124; 60>** | Clock initial time in minutes | defaults to undefined
 **clockIncrement** | [**number**] | Clock increment in seconds | defaults to undefined
 **minutes** | [**number**] | How long the tournament lasts, in minutes | defaults to undefined
 **name** | [**string**] | The tournament name. Leave empty to get a random Grandmaster name | (optional) defaults to undefined
 **waitMinutes** | [**number**] | How long to wait before starting the tournament, from now, in minutes | (optional) defaults to 5
 **startDate** | [**number**] | Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting | (optional) defaults to undefined
 **variant** | **VariantKey** |  | (optional) defaults to undefined
 **rated** | [**boolean**] | Games are rated and impact players ratings | (optional) defaults to undefined
 **position** | [**string**] | Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). | (optional) defaults to undefined
 **berserkable** | [**boolean**] | Whether the players can use berserk | (optional) defaults to undefined
 **streakable** | [**boolean**] | After 2 wins, consecutive wins grant 4 points instead of 2. | (optional) defaults to undefined
 **hasChat** | [**boolean**] | Whether the players can discuss in a chat | (optional) defaults to undefined
 **description** | [**string**] | Anything you want to tell players about the tournament | (optional) defaults to undefined
 **password** | [**string**] | Make the tournament private, and restrict access with a password | (optional) defaults to undefined
 **teambBattleByTeam** | [**string**] | Set the ID of a team you lead to create a team battle. The other teams can be added using the [team battle edit endpoint](#operation/apiTournamentTeamBattlePost).  | (optional) defaults to undefined
 **conditionsTeamMemberTeamId** | [**string**] | Restrict entry to members of a team.  The teamId is the last part of a team URL, e.g. &#x60;https://lichess.org/team/coders&#x60; has teamId &#x3D; &#x60;coders&#x60;.  Leave empty to let everyone join the tournament.  Do not use this to create team battles, use &#x60;teamBattleByTeam&#x60; instead.  | (optional) defaults to undefined
 **conditionsMinRatingRating** | [**number**] | Minimum rating to join. Leave empty to let everyone join the tournament. | (optional) defaults to undefined
 **conditionsMaxRatingRating** | [**number**] | Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. | (optional) defaults to undefined
 **conditionsNbRatedGameNb** | [**number**] | Minimum number of rated games required to join. | (optional) defaults to undefined


### Return type

**any**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The Arena tournament has been successfully created. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the Arena tournament failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiTournamentTeamBattlePost**
> any apiTournamentTeamBattlePost()

Set the teams and number of leaders of a team battle.  To update the other attributes of a team battle, use the [tournament update endpoint](#operation/apiTournamentUpdate). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ArenaTournamentsApi(configuration);

let body:.ArenaTournamentsApiApiTournamentTeamBattlePostRequest = {
  // string | The tournament ID (8 characters)..
  id: "id_example",
  // string | All team IDs of the team battle, separated by commas. Make sure to always send the full list. Teams that are not in the list will be removed from the team battle.  Example: `coders,zhigalko_sergei-fan-club,hhSwTKZv` 
  teams: "teams_example",
  // number | Number team leaders per team.
  nbLeaders: 1,
};

apiInstance.apiTournamentTeamBattlePost(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] | The tournament ID (8 characters).. | defaults to undefined
 **teams** | [**string**] | All team IDs of the team battle, separated by commas. Make sure to always send the full list. Teams that are not in the list will be removed from the team battle.  Example: &#x60;coders,zhigalko_sergei-fan-club,hhSwTKZv&#x60;  | defaults to undefined
 **nbLeaders** | [**number**] | Number team leaders per team. | defaults to undefined


### Return type

**any**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The team battle tournament was successfully updated. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The update of the team battle tournament failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiTournamentTerminate**
> Ok apiTournamentTerminate()

Terminate an Arena tournament 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ArenaTournamentsApi(configuration);

let body:.ArenaTournamentsApiApiTournamentTerminateRequest = {
  // string | The tournament ID.
  id: "hL7vMrFQ",
};

apiInstance.apiTournamentTerminate(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] | The tournament ID. | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The tournament was successfully terminated. |  * Access-Control-Allow-Origin -  <br>  |
**400** | Terminating the tournament failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiTournamentUpdate**
> any apiTournamentUpdate()

Update an Arena tournament.  Be mindful not to make important changes to ongoing tournaments.  Can be used to update a team battle. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ArenaTournamentsApi(configuration);

let body:.ArenaTournamentsApiApiTournamentUpdateRequest = {
  // string | The tournament ID.
  id: "id_example",
  // number | Clock initial time in minutes
  clockTime: 2,
  // number | Clock increment in seconds
  clockIncrement: 1,
  // number | How long the tournament lasts, in minutes
  minutes: 60,
  // string | The tournament name. Leave empty to get a random Grandmaster name (optional)
  name: "name_example",
  // number | How long to wait before starting the tournament, from now, in minutes (optional)
  waitMinutes: 5,
  // number | Timestamp to start the tournament at a given date and time. Overrides the `waitMinutes` setting (optional)
  startDate: 1,
  // VariantKey (optional)
  variant: "standard",
  // boolean | Games are rated and impact players ratings (optional)
  rated: true,
  // string | Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). (optional)
  position: "position_example",
  // boolean | Whether the players can use berserk (optional)
  berserkable: true,
  // boolean | After 2 wins, consecutive wins grant 4 points instead of 2. (optional)
  streakable: true,
  // boolean | Whether the players can discuss in a chat (optional)
  hasChat: true,
  // string | Anything you want to tell players about the tournament (optional)
  description: "description_example",
  // string | Make the tournament private, and restrict access with a password (optional)
  password: "password_example",
  // number | Minimum rating to join. Leave empty to let everyone join the tournament. (optional)
  conditionsMinRatingRating: 1,
  // number | Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. (optional)
  conditionsMaxRatingRating: 1,
  // number | Minimum number of rated games required to join. (optional)
  conditionsNbRatedGameNb: 1,
};

apiInstance.apiTournamentUpdate(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] | The tournament ID. | defaults to undefined
 **clockTime** | [**number**]**Array<0 &#124; 0.25 &#124; 0.5 &#124; 0.75 &#124; 1 &#124; 1.5 &#124; 2 &#124; 3 &#124; 4 &#124; 5 &#124; 6 &#124; 7 &#124; 10 &#124; 15 &#124; 20 &#124; 25 &#124; 30 &#124; 40 &#124; 50 &#124; 60>** | Clock initial time in minutes | defaults to undefined
 **clockIncrement** | [**number**] | Clock increment in seconds | defaults to undefined
 **minutes** | [**number**] | How long the tournament lasts, in minutes | defaults to undefined
 **name** | [**string**] | The tournament name. Leave empty to get a random Grandmaster name | (optional) defaults to undefined
 **waitMinutes** | [**number**] | How long to wait before starting the tournament, from now, in minutes | (optional) defaults to 5
 **startDate** | [**number**] | Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting | (optional) defaults to undefined
 **variant** | **VariantKey** |  | (optional) defaults to undefined
 **rated** | [**boolean**] | Games are rated and impact players ratings | (optional) defaults to undefined
 **position** | [**string**] | Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). | (optional) defaults to undefined
 **berserkable** | [**boolean**] | Whether the players can use berserk | (optional) defaults to undefined
 **streakable** | [**boolean**] | After 2 wins, consecutive wins grant 4 points instead of 2. | (optional) defaults to undefined
 **hasChat** | [**boolean**] | Whether the players can discuss in a chat | (optional) defaults to undefined
 **description** | [**string**] | Anything you want to tell players about the tournament | (optional) defaults to undefined
 **password** | [**string**] | Make the tournament private, and restrict access with a password | (optional) defaults to undefined
 **conditionsMinRatingRating** | [**number**] | Minimum rating to join. Leave empty to let everyone join the tournament. | (optional) defaults to undefined
 **conditionsMaxRatingRating** | [**number**] | Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. | (optional) defaults to undefined
 **conditionsNbRatedGameNb** | [**number**] | Minimum number of rated games required to join. | (optional) defaults to undefined


### Return type

**any**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The Arena tournament was successfully updated. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The update of the Arena tournament failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiTournamentWithdraw**
> Ok apiTournamentWithdraw()

Leave a future Arena tournament, or take a break on an ongoing Arena tournament. It's possible to join again later. Points and streaks are preserved. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ArenaTournamentsApi(configuration);

let body:.ArenaTournamentsApiApiTournamentWithdrawRequest = {
  // string | The tournament ID.
  id: "hL7vMrFQ",
};

apiInstance.apiTournamentWithdraw(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] | The tournament ID. | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The tournament was successfully paused or left. |  * Access-Control-Allow-Origin -  <br>  |
**400** | Pausing/leaving the tournament failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiUserNameTournamentCreated**
> any apiUserNameTournamentCreated()

Get all tournaments created by a given user.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ArenaTournamentsApi(configuration);

let body:.ArenaTournamentsApiApiUserNameTournamentCreatedRequest = {
  // string | The user whose created tournaments to fetch
  username: "username_example",
  // 10 | 20 | 30 | Include tournaments in the given status: \"Created\" (10), \"Started\" (20), \"Finished\" (30)  You can add this parameter more than once to include tournaments in different statuses.   Example: `?status=10&status=20`  (optional)
  status: 10,
};

apiInstance.apiUserNameTournamentCreated(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | [**string**] | The user whose created tournaments to fetch | defaults to undefined
 **status** | [**10 | 20 | 30**]**Array<10 &#124; 20 &#124; 30>** | Include tournaments in the given status: \&quot;Created\&quot; (10), \&quot;Started\&quot; (20), \&quot;Finished\&quot; (30)  You can add this parameter more than once to include tournaments in different statuses.   Example: &#x60;?status&#x3D;10&amp;status&#x3D;20&#x60;  | (optional) defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of tournaments created by the user. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **gamesByTournament**
> any gamesByTournament()

Download games of a tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first) 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ArenaTournamentsApi(configuration);

let body:.ArenaTournamentsApiGamesByTournamentRequest = {
  // string | The tournament ID.
  id: "id_example",
  // string | Only games of a particular player. Leave empty to fetch games of all players. (optional)
  player: "player_example",
  // boolean | Include the PGN moves. (optional)
  moves: true,
  // boolean | Include the full PGN within the JSON response, in a `pgn` field. (optional)
  pgnInJson: false,
  // boolean | Include the PGN tags. (optional)
  tags: true,
  // boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }`  (optional)
  clocks: false,
  // boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }`  (optional)
  evals: false,
  // boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]`  (optional)
  opening: false,
};

apiInstance.gamesByTournament(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] | The tournament ID. | defaults to undefined
 **player** | [**string**] | Only games of a particular player. Leave empty to fetch games of all players. | (optional) defaults to undefined
 **moves** | [**boolean**] | Include the PGN moves. | (optional) defaults to undefined
 **pgnInJson** | [**boolean**] | Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | (optional) defaults to undefined
 **tags** | [**boolean**] | Include the PGN tags. | (optional) defaults to undefined
 **clocks** | [**boolean**] | Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | (optional) defaults to undefined
 **evals** | [**boolean**] | Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | (optional) defaults to undefined
 **opening** | [**boolean**] | Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | (optional) defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of games of an Arena tournament. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **resultsByTournament**
> any resultsByTournament()

Players of an Arena tournament, with their score and performance, sorted by rank (best first).  **Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON)**, i.e. one JSON object per line.  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ArenaTournamentsApi(configuration);

let body:.ArenaTournamentsApiResultsByTournamentRequest = {
  // string | The tournament ID.
  id: "id_example",
  // number | Max number of players to fetch (optional)
  nb: 1,
};

apiInstance.resultsByTournament(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] | The tournament ID. | defaults to undefined
 **nb** | [**number**] | Max number of players to fetch | (optional) defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The results of the Arena tournament. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **teamsByTournament**
> any teamsByTournament()

Teams of a team battle tournament, with top players, sorted by rank (best first). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ArenaTournamentsApi(configuration);

let body:.ArenaTournamentsApiTeamsByTournamentRequest = {
  // string | The tournament ID.
  id: "id_example",
};

apiInstance.teamsByTournament(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] | The tournament ID. | defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of teams of a team battle tournament, with their respective top players. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **tournament**
> any tournament()

Get detailed info about recently finished, current, or upcoming tournament's duels, player standings, and other info. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ArenaTournamentsApi(configuration);

let body:.ArenaTournamentsApiTournamentRequest = {
  // string | The tournament ID.
  id: "id_example",
  // number | Specify which page of player standings to view. (optional)
  page: 1,
};

apiInstance.tournament(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] | The tournament ID. | defaults to undefined
 **page** | [**number**] | Specify which page of player standings to view. | (optional) defaults to 1


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The information of the Arena tournament. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


