# .BoardApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiBoardSeek**](BoardApi.md#apiBoardSeek) | **POST** /api/board/seek | Create a seek
[**apiStreamEvent**](BoardApi.md#apiStreamEvent) | **GET** /api/stream/event | Stream incoming events
[**boardGameAbort**](BoardApi.md#boardGameAbort) | **POST** /api/board/game/{gameId}/abort | Abort a game
[**boardGameChatGet**](BoardApi.md#boardGameChatGet) | **GET** /api/board/game/{gameId}/chat | Fetch the game chat
[**boardGameChatPost**](BoardApi.md#boardGameChatPost) | **POST** /api/board/game/{gameId}/chat | Write in the chat
[**boardGameClaimVictory**](BoardApi.md#boardGameClaimVictory) | **POST** /api/board/game/{gameId}/claim-victory | Claim victory of a game
[**boardGameDraw**](BoardApi.md#boardGameDraw) | **POST** /api/board/game/{gameId}/draw/{accept} | Handle draw offers
[**boardGameMove**](BoardApi.md#boardGameMove) | **POST** /api/board/game/{gameId}/move/{move} | Make a Board move
[**boardGameResign**](BoardApi.md#boardGameResign) | **POST** /api/board/game/{gameId}/resign | Resign a game
[**boardGameStream**](BoardApi.md#boardGameStream) | **GET** /api/board/game/stream/{gameId} | Stream Board game state
[**boardGameTakeback**](BoardApi.md#boardGameTakeback) | **POST** /api/board/game/{gameId}/takeback/{accept} | Handle takeback offers


# **apiBoardSeek**
> void apiBoardSeek()

   Create a public seek, to start a game with a random player.    ### Real-time seek    Specify the `time` and `increment` clock values.  The response is streamed but doesn't contain any information.    **Keep the connection open to keep the seek active**.    If the client closes the connection, the seek is canceled. This way, if the client terminates, the user won't be paired in a game they wouldn't play.   When the seek is accepted, or expires, the server closes the connection.    **Make sure to also have an [Event stream](#operation/apiStreamEvent) open**, to be notified when a game starts.   We recommend opening the [Event stream](#operation/apiStreamEvent) first, then the seek stream. This way,   you won't miss the game event if the seek is accepted immediately.    ### Correspondence seek    Specify the `days` per turn value.  The response is not streamed, it immediately completes with the seek ID. The seek remains active on the server until it is joined by someone.

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BoardApi(configuration);

let body:.BoardApiApiBoardSeekRequest = {
  // boolean | Whether the game is rated and impacts players ratings. (optional)
  rated: true,
  // number | Clock initial time in minutes. Required for real-time seeks. (optional)
  time: 15,
  // number | Clock increment in seconds. Required for real-time seeks. (optional)
  increment: 15,
  // number | Days per turn. Required for correspondence seeks. (optional)
  days: 1,
  // VariantKey (optional)
  variant: "standard",
  // string | The color to play. Better left empty to automatically get 50% white. (optional)
  color: "random",
  // string | The rating range of potential opponents. Better left empty. Example: 1500-1800  (optional)
  ratingRange: "ratingRange_example",
};

apiInstance.apiBoardSeek(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **rated** | [**boolean**] | Whether the game is rated and impacts players ratings. | (optional) defaults to undefined
 **time** | [**number**] | Clock initial time in minutes. Required for real-time seeks. | (optional) defaults to undefined
 **increment** | [**number**] | Clock increment in seconds. Required for real-time seeks. | (optional) defaults to undefined
 **days** | [**number**]**Array<1 &#124; 3 &#124; 5 &#124; 7 &#124; 10 &#124; 14>** | Days per turn. Required for correspondence seeks. | (optional) defaults to undefined
 **variant** | **VariantKey** |  | (optional) defaults to undefined
 **color** | [**string**]**Array<&#39;random&#39; &#124; &#39;white&#39; &#124; &#39;black&#39;>** | The color to play. Better left empty to automatically get 50% white. | (optional) defaults to 'random'
 **ratingRange** | [**string**] | The rating range of potential opponents. Better left empty. Example: 1500-1800  | (optional) defaults to undefined


### Return type

**void**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: text/plain, application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The seek was successfully created. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the seek failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiStreamEvent**
> ApiStreamEvent apiStreamEvent()

   Stream the events reaching a lichess user in real time as [ndjson](#section/Introduction/Streaming-with-ND-JSON).    Each line is a JSON object containing a `type` field. Possible values are:   - `gameStart` Start of a game   - `gameFinish` Completion of a game   - `challenge` A player sends you a challenge   - `challengeCanceled` A player cancels their challenge to you   - `challengeDeclined` The opponent declines your challenge     When the stream opens, all current challenges and games are sent.

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BoardApi(configuration);

let body:any = {};

apiInstance.apiStreamEvent(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters
This endpoint does not need any parameter.


### Return type

**ApiStreamEvent**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The stream of events reaching the logged in user. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **boardGameAbort**
> Ok boardGameAbort()

Abort a game being played with the Board API. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BoardApi(configuration);

let body:.BoardApiBoardGameAbortRequest = {
  // string
  gameId: "5IrD6Gzz",
};

apiInstance.boardGameAbort(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The game successfully aborted. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The abortion of the game failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **boardGameChatGet**
> any boardGameChatGet()

Get the messages posted in the game chat 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BoardApi(configuration);

let body:.BoardApiBoardGameChatGetRequest = {
  // string
  gameId: "5IrD6Gzz",
};

apiInstance.boardGameChatGet(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined


### Return type

**any**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The messages posted in the chat. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **boardGameChatPost**
> Ok boardGameChatPost()

Post a message to the player or spectator chat, in a game being played with the Board API. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BoardApi(configuration);

let body:.BoardApiBoardGameChatPostRequest = {
  // string
  gameId: "5IrD6Gzz",
  // string
  room: "player",
  // string
  text: "Thank you for the game!",
};

apiInstance.boardGameChatPost(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined
 **room** | [**string**]**Array<&#39;player&#39; &#124; &#39;spectator&#39;>** |  | defaults to undefined
 **text** | [**string**] |  | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The message was successfully posted in the chat. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The posting of the message in the chat failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **boardGameClaimVictory**
> Ok boardGameClaimVictory()

Claim victory when the opponent has left the game for a while. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BoardApi(configuration);

let body:.BoardApiBoardGameClaimVictoryRequest = {
  // string
  gameId: "5IrD6Gzz",
};

apiInstance.boardGameClaimVictory(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The victory was successfully claimed. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The victory claim has failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **boardGameDraw**
> Ok boardGameDraw()

Create/accept/decline draw offers. - `yes`: Offer a draw, or accept the opponent's draw offer. - `no`: Decline a draw offer from the opponent. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BoardApi(configuration);

let body:.BoardApiBoardGameDrawRequest = {
  // string
  gameId: "5IrD6Gzz",
  // boolean
  accept: false,
};

apiInstance.boardGameDraw(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined
 **accept** | [**boolean**] |  | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The draw offer was successfully sent. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The draw offering failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **boardGameMove**
> Ok boardGameMove()

Make a move in a game being played with the Board API.  The move can also contain a draw offer/agreement. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BoardApi(configuration);

let body:.BoardApiBoardGameMoveRequest = {
  // string
  gameId: "5IrD6Gzz",
  // string | The move to play, in UCI format
  move: "e2e4",
  // boolean | Whether to offer (or agree to) a draw (optional)
  offeringDraw: true,
};

apiInstance.boardGameMove(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined
 **move** | [**string**] | The move to play, in UCI format | defaults to undefined
 **offeringDraw** | [**boolean**] | Whether to offer (or agree to) a draw | (optional) defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The move was successfully made. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The move failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **boardGameResign**
> Ok boardGameResign()

Resign a game being played with the Board API. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BoardApi(configuration);

let body:.BoardApiBoardGameResignRequest = {
  // string
  gameId: "5IrD6Gzz",
};

apiInstance.boardGameResign(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The game was successfully resigned. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The resigning from the game failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **boardGameStream**
> GameStreamEvent boardGameStream()

 Stream the state of a game being played with the Board API, as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  Use this endpoint to get updates about the game in real-time, with a single request.  Each line is a JSON object containing a `type` field. Possible values are:   - `gameFull` Full game data. All values are immutable, except for the `state` field.   - `gameState` Current state of the game. Immutable values not included. Sent when a move is played, a draw is offered, or when the game ends.   - `chatLine` Chat message sent by a user in the `room` \"player\" or \"spectator\".    The first line is always of type `gameFull`.

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BoardApi(configuration);

let body:.BoardApiBoardGameStreamRequest = {
  // string
  gameId: "5IrD6Gzz",
};

apiInstance.boardGameStream(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined


### Return type

**GameStreamEvent**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson, application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The stream of the game. |  * Access-Control-Allow-Origin -  <br>  |
**404** | The game was not found. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **boardGameTakeback**
> Ok boardGameTakeback()

Create/accept/decline takebacks. - `yes`: Propose a takeback, or accept the opponent's takeback offer. - `no`: Decline a takeback offer from the opponent. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BoardApi(configuration);

let body:.BoardApiBoardGameTakebackRequest = {
  // string
  gameId: "5IrD6Gzz",
  // boolean
  accept: false,
};

apiInstance.boardGameTakeback(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined
 **accept** | [**boolean**] |  | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The takeback offer was successfully sent. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The takeback offering failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


