# .BotApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiBotOnline**](BotApi.md#apiBotOnline) | **GET** /api/bot/online | Get online bots
[**apiStreamEvent**](BotApi.md#apiStreamEvent) | **GET** /api/stream/event | Stream incoming events
[**botAccountUpgrade**](BotApi.md#botAccountUpgrade) | **POST** /api/bot/account/upgrade | Upgrade to Bot account
[**botGameAbort**](BotApi.md#botGameAbort) | **POST** /api/bot/game/{gameId}/abort | Abort a game
[**botGameChat**](BotApi.md#botGameChat) | **POST** /api/bot/game/{gameId}/chat | Write in the chat
[**botGameMove**](BotApi.md#botGameMove) | **POST** /api/bot/game/{gameId}/move/{move} | Make a Bot move
[**botGameResign**](BotApi.md#botGameResign) | **POST** /api/bot/game/{gameId}/resign | Resign a game
[**botGameStream**](BotApi.md#botGameStream) | **GET** /api/bot/game/stream/{gameId} | Stream Bot game state


# **apiBotOnline**
> User apiBotOnline()

Stream the [online bot users](https://lichess.org/player/bots), as [ndjson](#section/Introduction/Streaming-with-ND-JSON). Throttled to 50 bot users per second.

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BotApi(configuration);

let body:.BotApiApiBotOnlineRequest = {
  // number | How many bot users to fetch (optional)
  nb: 20,
};

apiInstance.apiBotOnline(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nb** | [**number**] | How many bot users to fetch | (optional) defaults to undefined


### Return type

**User**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of online bot users |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiStreamEvent**
> ApiStreamEvent apiStreamEvent()

   Stream the events reaching a lichess user in real time as [ndjson](#section/Introduction/Streaming-with-ND-JSON).    Each line is a JSON object containing a `type` field. Possible values are:   - `gameStart` Start of a game   - `gameFinish` Completion of a game   - `challenge` A player sends you a challenge   - `challengeCanceled` A player cancels their challenge to you   - `challengeDeclined` The opponent declines your challenge     When the stream opens, all current challenges and games are sent.

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BotApi(configuration);

let body:any = {};

apiInstance.apiStreamEvent(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters
This endpoint does not need any parameter.


### Return type

**ApiStreamEvent**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The stream of events reaching the logged in user. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **botAccountUpgrade**
> Ok botAccountUpgrade()

Upgrade a lichess player account into a Bot account. Only Bot accounts can use the Bot API.  The account **cannot have played any game** before becoming a Bot account. The upgrade is **irreversible**. The account will only be able to play as a Bot.  To upgrade an account to Bot, use the [official lichess-bot client](https://github.com/careless25/lichess-bot), or follow these steps: - Create an [API access token](https://lichess.org/account/oauth/token/create?scopes[]=bot:play) with \"Play bot moves\" permission. - `curl -d '' https://lichess.org/api/bot/account/upgrade -H \"Authorization: Bearer <yourTokenHere>\"`  To know if an account has already been upgraded, use the [Get my profile API](#operation/accountMe): the `title` field should be set to `BOT`. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BotApi(configuration);

let body:any = {};

apiInstance.botAccountUpgrade(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters
This endpoint does not need any parameter.


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The bot account was successfully upgraded. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The upgrade of the bot account failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **botGameAbort**
> Ok botGameAbort()

Abort a game being played with the Bot API. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BotApi(configuration);

let body:.BotApiBotGameAbortRequest = {
  // string
  gameId: "5IrD6Gzz",
};

apiInstance.botGameAbort(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The game was successfully aborted. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The abortion of the game failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **botGameChat**
> Ok botGameChat()

Post a message to the player or spectator chat, in a game being played with the Bot API. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BotApi(configuration);

let body:.BotApiBotGameChatRequest = {
  // string
  gameId: "5IrD6Gzz",
  // string
  room: "player",
  // string
  text: "Thank you for the game!",
};

apiInstance.botGameChat(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined
 **room** | [**string**]**Array<&#39;player&#39; &#124; &#39;spectator&#39;>** |  | defaults to undefined
 **text** | [**string**] |  | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The message was successfully posted in chat. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The posting of the  message in chat failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **botGameMove**
> Ok botGameMove()

Make a move in a game being played with the Bot API.  The move can also contain a draw offer/agreement. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BotApi(configuration);

let body:.BotApiBotGameMoveRequest = {
  // string
  gameId: "5IrD6Gzz",
  // string | The move to play, in UCI format
  move: "e2e4",
  // boolean | Whether to offer (or agree to) a draw (optional)
  offeringDraw: true,
};

apiInstance.botGameMove(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined
 **move** | [**string**] | The move to play, in UCI format | defaults to undefined
 **offeringDraw** | [**boolean**] | Whether to offer (or agree to) a draw | (optional) defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The bot move was successfully made. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The bot move failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **botGameResign**
> Ok botGameResign()

Resign a game being played with the Bot API. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BotApi(configuration);

let body:.BotApiBotGameResignRequest = {
  // string
  gameId: "5IrD6Gzz",
};

apiInstance.botGameResign(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The game was successfully resigned from. |  * Access-Control-Allow-Origin -  <br>  |
**400** | Resigning the game failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **botGameStream**
> GameStreamEvent botGameStream()

 Stream the state of a game being played with the Bot API, as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  Use this endpoint to get updates about the game in real-time, with a single request.  Each line is a JSON object containing a `type` field. Possible values are:   - `gameFull` Full game data. All values are immutable, except for the `state` field.   - `gameState` Current state of the game. Immutable values not included.   - `chatLine` Chat message sent by a user (or the bot itself) in the `room` \"player\" or \"spectator\".    The first line is always of type `gameFull`.

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BotApi(configuration);

let body:.BotApiBotGameStreamRequest = {
  // string
  gameId: "5IrD6Gzz",
};

apiInstance.botGameStream(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined


### Return type

**GameStreamEvent**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson, application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The stream of the bot game. |  * Access-Control-Allow-Origin -  <br>  |
**404** | The bot game was not found. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


