# .BroadcastsApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**broadcastAllRoundsPgn**](BroadcastsApi.md#broadcastAllRoundsPgn) | **GET** /api/broadcast/{broadcastTournamentId}.pgn | Export all rounds as PGN
[**broadcastIndex**](BroadcastsApi.md#broadcastIndex) | **GET** /api/broadcast | Get official broadcasts
[**broadcastPush**](BroadcastsApi.md#broadcastPush) | **POST** /broadcast/round/{broadcastRoundId}/push | Push PGN to your broadcast round
[**broadcastRoundCreate**](BroadcastsApi.md#broadcastRoundCreate) | **POST** /broadcast/{broadcastTournamentId}/new | Create a broadcast round
[**broadcastRoundGet**](BroadcastsApi.md#broadcastRoundGet) | **GET** /broadcast/{broadcastTournamentSlug}/{broadcastRoundSlug}/{broadcastRoundId} | Get your broadcast round
[**broadcastRoundPgn**](BroadcastsApi.md#broadcastRoundPgn) | **GET** /api/broadcast/round/{broadcastRoundId}.pgn | Export one round as PGN
[**broadcastRoundUpdate**](BroadcastsApi.md#broadcastRoundUpdate) | **POST** /broadcast/round/{broadcastRoundId}/edit | Update your broadcast round
[**broadcastStreamRoundPgn**](BroadcastsApi.md#broadcastStreamRoundPgn) | **GET** /api/stream/broadcast/round/{broadcastRoundId}.pgn | Stream an ongoing broadcast tournament as PGN
[**broadcastTourCreate**](BroadcastsApi.md#broadcastTourCreate) | **POST** /broadcast/new | Create a broadcast tournament
[**broadcastTourGet**](BroadcastsApi.md#broadcastTourGet) | **GET** /broadcast/{slug}/{broadcastTournamentId} | Get your broadcast tournament
[**broadcastTourUpdate**](BroadcastsApi.md#broadcastTourUpdate) | **POST** /broadcast/{broadcastTournamentId}/edit | Update your broadcast tournament


# **broadcastAllRoundsPgn**
> any broadcastAllRoundsPgn()

Download all games of all rounds of a broadcast in PGN format.  You may want to [download only the games of a single round](#operation/broadcastRoundPgn) instead. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BroadcastsApi(configuration);

let body:.BroadcastsApiBroadcastAllRoundsPgnRequest = {
  // string | The broadcast tournament ID (8 characters).
  broadcastTournamentId: "broadcastTournamentId_example",
};

apiInstance.broadcastAllRoundsPgn(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastTournamentId** | [**string**] | The broadcast tournament ID (8 characters). | defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The PGN representation of the broadcast. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **broadcastIndex**
> Array<any> broadcastIndex()

Get all incoming, ongoing, and finished official broadcasts. The broadcasts are sorted by start date, most recent first.  Broadcasts are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BroadcastsApi(configuration);

let body:.BroadcastsApiBroadcastIndexRequest = {
  // number | Max number of broadcasts to fetch (optional)
  nb: 20,
};

apiInstance.broadcastIndex(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nb** | [**number**] | Max number of broadcasts to fetch | (optional) defaults to 20


### Return type

**Array<any>**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of official broadcasts. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **broadcastPush**
> Array<Ok> broadcastPush(body)

Update your broadcast with new PGN. Only for broadcast without a source URL. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BroadcastsApi(configuration);

let body:.BroadcastsApiBroadcastPushRequest = {
  // string | The broadcast round ID (8 characters).
  broadcastRoundId: "broadcastRoundId_example",
  // string | The PGN. It can contain up to 64 games, separated by a double new line.
  body: "body_example",
};

apiInstance.broadcastPush(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | **string**| The PGN. It can contain up to 64 games, separated by a double new line. |
 **broadcastRoundId** | [**string**] | The broadcast round ID (8 characters). | defaults to undefined


### Return type

**Array<Ok>**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: text/plain
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The broadcast was successfully updated. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **broadcastRoundCreate**
> any broadcastRoundCreate()

Create a new broadcast round to relay external games. This endpoint accepts the same form data as the web form. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BroadcastsApi(configuration);

let body:.BroadcastsApiBroadcastRoundCreateRequest = {
  // string | The broadcast tournament ID (8 characters).
  broadcastTournamentId: "broadcastTournamentId_example",
  // string | Name of the broadcast round. Length must be between 3 and 80 characters.  Example: `Round 1` 
  name: "name_example",
  // string | URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: `https://myserver.org/myevent/round-10/games.pgn`  If the syncUrl is missing, then the broadcast needs to be fed by [pushing PGN to it](#operation/broadcastPush).  (optional)
  syncUrl: "syncUrl_example",
  // number | Timestamp in milliseconds of broadcast round start. Leave empty to manually start the broadcast round.  Example: `1356998400070`  (optional)
  startsAt: 1356998400070,
};

apiInstance.broadcastRoundCreate(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastTournamentId** | [**string**] | The broadcast tournament ID (8 characters). | defaults to undefined
 **name** | [**string**] | Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 1&#x60;  | defaults to undefined
 **syncUrl** | [**string**] | URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  If the syncUrl is missing, then the broadcast needs to be fed by [pushing PGN to it](#operation/broadcastPush).  | (optional) defaults to undefined
 **startsAt** | [**number**] | Timestamp in milliseconds of broadcast round start. Leave empty to manually start the broadcast round.  Example: &#x60;1356998400070&#x60;  | (optional) defaults to undefined


### Return type

**any**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The broadcast round was successfully created. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the broadcast failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **broadcastRoundGet**
> Array<any> broadcastRoundGet()

Get information about a broadcast round that you created. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BroadcastsApi(configuration);

let body:.BroadcastsApiBroadcastRoundGetRequest = {
  // string | The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by `-`. Only the `broadcastRoundId` is actually used.
  broadcastTournamentSlug: "broadcastTournamentSlug_example",
  // string | The broadcast round slug. Only used for SEO, the slug can be safely replaced by `-`. Only the `broadcastRoundId` is actually used.
  broadcastRoundSlug: "broadcastRoundSlug_example",
  // string | The broadcast Round ID (8 characters).
  broadcastRoundId: "broadcastRoundId_example",
};

apiInstance.broadcastRoundGet(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastTournamentSlug** | [**string**] | The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. | defaults to undefined
 **broadcastRoundSlug** | [**string**] | The broadcast round slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. | defaults to undefined
 **broadcastRoundId** | [**string**] | The broadcast Round ID (8 characters). | defaults to undefined


### Return type

**Array<any>**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The information about the broadcast round. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **broadcastRoundPgn**
> any broadcastRoundPgn()

Download all games of a single round of a broadcast tournament in PGN format.  You *could* poll this endpoint to get updates about a tournament, but it would be slow, and very inneficient.  Instead, consider [streaming the tournament](#operation/broadcastStreamRoundPgn) to get a new PGN every time a game is updated, in real-time. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BroadcastsApi(configuration);

let body:.BroadcastsApiBroadcastRoundPgnRequest = {
  // string | The round ID (8 characters).
  broadcastRoundId: "broadcastRoundId_example",
};

apiInstance.broadcastRoundPgn(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastRoundId** | [**string**] | The round ID (8 characters). | defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The PGN representation of the round. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **broadcastRoundUpdate**
> Ok broadcastRoundUpdate()

Update information about a broadcast round that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. For instance, if you omit `startDate`, then any pre-existing start date will be removed. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BroadcastsApi(configuration);

let body:.BroadcastsApiBroadcastRoundUpdateRequest = {
  // string | The broadcast round ID (8 characters).
  broadcastRoundId: "broadcastRoundId_example",
  // string | Name of the broadcast round. Length must be between 3 and 80 characters.  Example: `Round 10` 
  name: "name_example",
  // string | URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: `https://myserver.org/myevent/round-10/games.pgn`  (optional)
  syncUrl: "syncUrl_example",
  // number | Timestamp in milliseconds of broadcast start. Leave empty to manually start the broadcast.  Example: `1356998400070`  (optional)
  startsAt: 1356998400070,
};

apiInstance.broadcastRoundUpdate(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastRoundId** | [**string**] | The broadcast round ID (8 characters). | defaults to undefined
 **name** | [**string**] | Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 10&#x60;  | defaults to undefined
 **syncUrl** | [**string**] | URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  | (optional) defaults to undefined
 **startsAt** | [**number**] | Timestamp in milliseconds of broadcast start. Leave empty to manually start the broadcast.  Example: &#x60;1356998400070&#x60;  | (optional) defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The broadcast round was successfully edited. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The edition of the broadcast tournament failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **broadcastStreamRoundPgn**
> any broadcastStreamRoundPgn()

This streaming endpoint first sends all games of a broadcast tournament in PGN format.  Then, it waits for new moves to be played. As soon as it happens, the entire PGN of the game is sent to the stream.  The stream will also send PGNs when games are added to the tournament.  This is the best way to get updates about an ongoing tournament. Streaming means no polling, and no pollings means no latency, and minimum impact on the server. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BroadcastsApi(configuration);

let body:.BroadcastsApiBroadcastStreamRoundPgnRequest = {
  // string | The broadcast round ID (8 characters).
  broadcastRoundId: "broadcastRoundId_example",
};

apiInstance.broadcastStreamRoundPgn(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastRoundId** | [**string**] | The broadcast round ID (8 characters). | defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The PGN representation of the tournament games, then the PGNs of games as they are updated. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **broadcastTourCreate**
> any broadcastTourCreate()

Create a new broadcast tournament to relay external games. This endpoint accepts the same form data as the [web form](https://lichess.org/broadcast/new). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BroadcastsApi(configuration);

let body:.BroadcastsApiBroadcastTourCreateRequest = {
  // string | Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: `Sinquefield Cup` 
  name: "name_example",
  // string | Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: `An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.` 
  description: "description_example",
  // string | Optional long description of the broadcast. Markdown is supported. Length must be less than 20,000 characters. (optional)
  markup: "markup_example",
  // boolean | For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. (optional)
  official: true,
};

apiInstance.broadcastTourCreate(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | [**string**] | Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  | defaults to undefined
 **description** | [**string**] | Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  | defaults to undefined
 **markup** | [**string**] | Optional long description of the broadcast. Markdown is supported. Length must be less than 20,000 characters. | (optional) defaults to undefined
 **official** | [**boolean**] | For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. | (optional) defaults to undefined


### Return type

**any**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The broadcast tournament was successfully created. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the broadcast tournament failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **broadcastTourGet**
> Array<any> broadcastTourGet()

Get information about a broadcast tournament that you created. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BroadcastsApi(configuration);

let body:.BroadcastsApiBroadcastTourGetRequest = {
  // string | The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by `-`. Only the `broadcastTournamentId` is actually used.
  slug: "slug_example",
  // string | The broadcast tournament ID (8 characters).
  broadcastTournamentId: "broadcastTournamentId_example",
};

apiInstance.broadcastTourGet(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **slug** | [**string**] | The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastTournamentId&#x60; is actually used. | defaults to undefined
 **broadcastTournamentId** | [**string**] | The broadcast tournament ID (8 characters). | defaults to undefined


### Return type

**Array<any>**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The information about the broadcast tournament. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **broadcastTourUpdate**
> Ok broadcastTourUpdate()

Update information about a broadcast tournament that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BroadcastsApi(configuration);

let body:.BroadcastsApiBroadcastTourUpdateRequest = {
  // string | The broadcast ID (8 characters).
  broadcastTournamentId: "broadcastTournamentId_example",
  // string | Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: `Sinquefield Cup` 
  name: "name_example",
  // string | Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: `An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.` 
  description: "description_example",
  // string | Optional long description of the broadcast tournament. Markdown is supported. Length must be less than 20,000 characters. (optional)
  markup: "markup_example",
  // boolean | For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. (optional)
  official: true,
};

apiInstance.broadcastTourUpdate(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastTournamentId** | [**string**] | The broadcast ID (8 characters). | defaults to undefined
 **name** | [**string**] | Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  | defaults to undefined
 **description** | [**string**] | Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  | defaults to undefined
 **markup** | [**string**] | Optional long description of the broadcast tournament. Markdown is supported. Length must be less than 20,000 characters. | (optional) defaults to undefined
 **official** | [**boolean**] | For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. | (optional) defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The broadcast tournament was successfully edited. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The edition of the broadcast tournament failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


