# .BulkPairingsApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**bulkPairingCreate**](BulkPairingsApi.md#bulkPairingCreate) | **POST** /api/bulk-pairing | Create a bulk pairing
[**bulkPairingDelete**](BulkPairingsApi.md#bulkPairingDelete) | **DELETE** /api/bulk-pairing/{id} | Cancel a bulk pairing
[**bulkPairingGet**](BulkPairingsApi.md#bulkPairingGet) | **GET** /api/bulk-pairing | View upcoming bulk pairings
[**bulkPairingStartClocks**](BulkPairingsApi.md#bulkPairingStartClocks) | **POST** /api/bulk-pairing/{id}/start-clocks | Manually start clocks


# **bulkPairingCreate**
> any bulkPairingCreate()

Schedule many games at once, up to 24h in advance.  OAuth tokens are required for all paired players, with the `challenge:write` scope.  You can schedule up to 500 games every 10 minutes. [Contact us](mailto:contact@lichess.org) if you need higher limits.  The entire bulk is rejected if:   - a token is missing   - a token is present more than once   - a token lacks the `challenge:write` scope   - a player account is closed   - a player is paired more than once   - a bulk is already scheduled to start at the same time with the same player   - you have 10 scheduled bulks   - you have 1000 scheduled games  Partial bulks are never created. Either it all fails, or it all succeeds. When it fails, it does so with an error message explaining the issue. Failed bulks are not counted in the rate limiting, they are free. Fix the issues, manually or programmatically, then retry to schedule the bulk.  A successful bulk creation returns a JSON bulk document. Its ID can be used for further operations. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BulkPairingsApi(configuration);

let body:.BulkPairingsApiBulkPairingCreateRequest = {
  // string | OAuth tokens of all the players to pair, with the syntax `tokenOfWhitePlayerInGame1:tokenOfBlackPlayerInGame1,tokenOfWhitePlayerInGame2:tokenOfBlackPlayerInGame2,...`.  The 2 tokens of the players of a game are separated with `:`. The first token gets the white pieces. Games are separated with `,`.  Up to 1000 tokens can be sent, for a max of 500 games.  Each token must be included at most once.  Example: `token1:token2,token3:token4,token5:token6`  (optional)
  players: "players_example",
  // number | Clock initial time in seconds. Example: `600`  (optional)
  clockLimit: 0,
  // number | Clock increment in seconds. Example: `5`  (optional)
  clockIncrement: 0,
  // number | Date at which the games will be created. Up to 24h in the future. Omit, or set to current date and time, to start the games immediately. Example: `1612289869919`  (optional)
  pairAt: 1,
  // number | Date at which the clocks will be automatically started. Up to 24h in the future. Note that the clocks can start earlier than specified, if players start making moves in the game. If omitted, the clocks will not start automatically. Example: `1612289869919`  (optional)
  startClocksAt: 1,
  // boolean | Game is rated and impacts players ratings (optional)
  rated: true,
  // VariantKey (optional)
  variant: "standard",
  // string | Message that will be sent to each player, when the game is created.  It is sent from your user account.  `{opponent}` and `{game}` are placeholders that will be replaced with the opponent and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the `{game}` placeholder.  (optional)
  message: "Your game with {opponent} is ready: {game}.",
};

apiInstance.bulkPairingCreate(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **players** | [**string**] | OAuth tokens of all the players to pair, with the syntax &#x60;tokenOfWhitePlayerInGame1:tokenOfBlackPlayerInGame1,tokenOfWhitePlayerInGame2:tokenOfBlackPlayerInGame2,...&#x60;.  The 2 tokens of the players of a game are separated with &#x60;:&#x60;. The first token gets the white pieces. Games are separated with &#x60;,&#x60;.  Up to 1000 tokens can be sent, for a max of 500 games.  Each token must be included at most once.  Example: &#x60;token1:token2,token3:token4,token5:token6&#x60;  | (optional) defaults to undefined
 **clockLimit** | [**number**] | Clock initial time in seconds. Example: &#x60;600&#x60;  | (optional) defaults to undefined
 **clockIncrement** | [**number**] | Clock increment in seconds. Example: &#x60;5&#x60;  | (optional) defaults to undefined
 **pairAt** | [**number**] | Date at which the games will be created. Up to 24h in the future. Omit, or set to current date and time, to start the games immediately. Example: &#x60;1612289869919&#x60;  | (optional) defaults to undefined
 **startClocksAt** | [**number**] | Date at which the clocks will be automatically started. Up to 24h in the future. Note that the clocks can start earlier than specified, if players start making moves in the game. If omitted, the clocks will not start automatically. Example: &#x60;1612289869919&#x60;  | (optional) defaults to undefined
 **rated** | [**boolean**] | Game is rated and impacts players ratings | (optional) defaults to undefined
 **variant** | **VariantKey** |  | (optional) defaults to undefined
 **message** | [**string**] | Message that will be sent to each player, when the game is created.  It is sent from your user account.  &#x60;{opponent}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder.  | (optional) defaults to 'Your game with {opponent} is ready: {game}.'


### Return type

**any**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The bulk pairings have been successfully created. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the bulk pairings failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **bulkPairingDelete**
> Ok bulkPairingDelete()

Cancel and delete a bulk pairing that is scheduled in the future.  If the games have already been created, then this does nothing.  Canceling a bulk pairing does not refund the rate limit cost of that bulk pairing. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BulkPairingsApi(configuration);

let body:.BulkPairingsApiBulkPairingDeleteRequest = {
  // string
  id: "5IrD6Gzz",
};

apiInstance.bulkPairingDelete(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] |  | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The bulk pairing was successfully deleted. |  * Access-Control-Allow-Origin -  <br>  |
**404** | The bulk pairing to delete was not found. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **bulkPairingGet**
> Array<any> bulkPairingGet()

Get a list of upcoming bulk pairings you created.  Only bulk pairings that are scheduled in the future, or that have a clock start scheduled in the future, are listed.  Bulk pairings are deleted from the server after the pairings are done and the clocks have started. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BulkPairingsApi(configuration);

let body:any = {};

apiInstance.bulkPairingGet(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters
This endpoint does not need any parameter.


### Return type

**Array<any>**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of upcoming bulk pairing the logged in user created. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **bulkPairingStartClocks**
> Ok bulkPairingStartClocks()

Immediately start all clocks of the games of a bulk pairing.  This overrides the `startClocksAt` value of an existing bulk pairing.  If the games have not yet been created (`bulk.pairAt` is in the future), then this does nothing.  If the clocks have already started (`bulk.startClocksAt` is in the past), then this does nothing. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .BulkPairingsApi(configuration);

let body:.BulkPairingsApiBulkPairingStartClocksRequest = {
  // string
  id: "5IrD6Gzz",
};

apiInstance.bulkPairingStartClocks(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] |  | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The clocks of the games of a bulk pairing were successfully started. |  * Access-Control-Allow-Origin -  <br>  |
**404** | The bulk pairing was not found. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


