# .ChallengesApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**adminChallengeTokens**](ChallengesApi.md#adminChallengeTokens) | **POST** /api/token/admin-challenge | Admin challenge tokens
[**challengeAccept**](ChallengesApi.md#challengeAccept) | **POST** /api/challenge/{challengeId}/accept | Accept a challenge
[**challengeAi**](ChallengesApi.md#challengeAi) | **POST** /api/challenge/ai | Challenge the AI
[**challengeCancel**](ChallengesApi.md#challengeCancel) | **POST** /api/challenge/{challengeId}/cancel | Cancel a challenge
[**challengeCreate**](ChallengesApi.md#challengeCreate) | **POST** /api/challenge/{username} | Create a challenge
[**challengeDecline**](ChallengesApi.md#challengeDecline) | **POST** /api/challenge/{challengeId}/decline | Decline a challenge
[**challengeList**](ChallengesApi.md#challengeList) | **GET** /api/challenge | List your challenges
[**challengeOpen**](ChallengesApi.md#challengeOpen) | **POST** /api/challenge/open | Open-ended challenge
[**challengeStartClocks**](ChallengesApi.md#challengeStartClocks) | **POST** /api/challenge/{gameId}/start-clocks | Start clocks of a game
[**roundAddTime**](ChallengesApi.md#roundAddTime) | **POST** /api/round/{gameId}/add-time/{seconds} | Add time to the opponent clock


# **adminChallengeTokens**
> void adminChallengeTokens()

**For administrators only. You are not allowed to use this endpoint.**  Create and obtain `challenge:write` tokens for multiple users.  If a similar token already exists for a user, it is reused. This endpoint is idempotent. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ChallengesApi(configuration);

let body:.ChallengesApiAdminChallengeTokensRequest = {
  // string | Usernames separated with commas
  users: "thibault,neio,lizen2,lizen3",
  // string | User visible description of the token
  description: "FIDE tournament XYZ",
};

apiInstance.adminChallengeTokens(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **users** | [**string**] | Usernames separated with commas | defaults to undefined
 **description** | [**string**] | User visible description of the token | defaults to undefined


### Return type

**void**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The &#x60;challenge:write&#x60; tokens of each user |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the tokens failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **challengeAccept**
> Ok challengeAccept()

Accept an incoming challenge.  You should receive a `gameStart` event on the [incoming events stream](#operation/apiStreamEvent). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ChallengesApi(configuration);

let body:.ChallengesApiChallengeAcceptRequest = {
  // string
  challengeId: "5IrD6Gzz",
};

apiInstance.challengeAccept(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **challengeId** | [**string**] |  | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The challenge was successfully accepted. |  * Access-Control-Allow-Origin -  <br>  |
**404** | The challenge to accept was not found. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **challengeAi**
> GameJson challengeAi()

Start a game with Lichess AI.  You will be notified on the [event stream](#operation/apiStreamEvent) that a new game has started. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ChallengesApi(configuration);

let body:.ChallengesApiChallengeAiRequest = {
  // number | AI strength (optional)
  level: 1,
  // number | Clock initial time in seconds. If empty, a correspondence game is created. (optional)
  clockLimit: 300,
  // number | Clock increment in seconds. If empty, a correspondence game is created. (optional)
  clockIncrement: 1,
  // number | Days per move, for correspondence games. Clock settings must be omitted. (optional)
  days: 5,
  // string | Which color you get to play (optional)
  color: "random",
  // VariantKey (optional)
  variant: "standard",
  // string | Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. (optional)
  fen: "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1",
};

apiInstance.challengeAi(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **level** | [**number**] | AI strength | (optional) defaults to undefined
 **clockLimit** | [**number**] | Clock initial time in seconds. If empty, a correspondence game is created. | (optional) defaults to undefined
 **clockIncrement** | [**number**] | Clock increment in seconds. If empty, a correspondence game is created. | (optional) defaults to undefined
 **days** | [**number**] | Days per move, for correspondence games. Clock settings must be omitted. | (optional) defaults to undefined
 **color** | [**string**]**Array<&#39;random&#39; &#124; &#39;white&#39; &#124; &#39;black&#39;>** | Which color you get to play | (optional) defaults to ColorEnum_Random
 **variant** | **VariantKey** |  | (optional) defaults to undefined
 **fen** | [**string**] | Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. | (optional) defaults to 'rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1'


### Return type

**GameJson**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The game with Lichess AI was successfully started. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of a game with Lichess AI failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **challengeCancel**
> Ok challengeCancel()

Cancel a challenge you sent, or aborts the game if the challenge was accepted, but the game was not yet played. Note that the ID of a game is the same as the ID of the challenge that created it. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ChallengesApi(configuration);

let body:.ChallengesApiChallengeCancelRequest = {
  // string
  challengeId: "5IrD6Gzz",
  // string | Optional `challenge:write` token of the opponent. If set, the game can be canceled even if both players have moved. (optional)
  opponentToken: "opponentToken_example",
};

apiInstance.challengeCancel(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **challengeId** | [**string**] |  | defaults to undefined
 **opponentToken** | [**string**] | Optional &#x60;challenge:write&#x60; token of the opponent. If set, the game can be canceled even if both players have moved. | (optional) defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The challenge was successfully cancelled. |  * Access-Control-Allow-Origin -  <br>  |
**404** | The challenge to cancel was not found. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **challengeCreate**
> ChallengeJson challengeCreate()

Challenge someone to play. The targeted player can choose to accept or decline.  If the challenge is accepted, you will be notified on the [event stream](#operation/apiStreamEvent) that a new game has started. The game ID will be the same as the challenge ID.  If you also have an OAuth token with `challenge:write` scope for the receiving user, you can make them accept the challenge immediately by setting the `acceptByToken` field.  Challenges for realtime games (not correspondence) expire after 20s if not accepted. To prevent that, use the `keepAliveStream` flag described below. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ChallengesApi(configuration);

let body:.ChallengesApiChallengeCreateRequest = {
  // string
  username: "LeelaChess",
  // boolean | Game is rated and impacts players ratings (optional)
  rated: true,
  // number | Clock initial time in seconds. If empty, a correspondence game is created. (optional)
  clockLimit: 300,
  // number | Clock increment in seconds. If empty, a correspondence game is created. (optional)
  clockIncrement: 1,
  // number | Days per move, for correspondence games. Clock settings must be omitted. (optional)
  days: 5,
  // string | Which color you get to play (optional)
  color: "random",
  // VariantKey (optional)
  variant: "standard",
  // string | Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. Castling moves will use UCI_Chess960 notation, for example e1h1 instead of e1g1. (optional)
  fen: "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1",
  // boolean | If set, the response is streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). The challenge is kept alive until the connection is closed by the client. When the challenge is accepted, declined or canceled, a message of the form `{\\\"done\\\":\\\"accepted\\\"}` is sent, then the connection is closed by the server. If not set, the response is not streamed, and the challenge expires after 20s if not accepted.  (optional)
  keepAliveStream: true,
  // string | Immediately accept the challenge and create the game. Pass in an OAuth token (with the `challenge:write` scope) for the receiving user. On success, the response will contain a `game` field instead of a `challenge` field.  Alternatively, consider the [bulk pairing API](#operation/bulkPairingCreate).  (optional)
  acceptByToken: "acceptByToken_example",
  // string | **Only if `acceptByToken` is set.**  Message that is sent to each player, when the game is created. It is sent from your user account.  `{opponent}`, `{player}` and `{game}` are placeholders that will be replaced with the opponent name, player name, and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the `{game}` placeholder.  (optional)
  message: "Your game with {opponent} is ready: {game}.",
};

apiInstance.challengeCreate(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | [**string**] |  | defaults to undefined
 **rated** | [**boolean**] | Game is rated and impacts players ratings | (optional) defaults to undefined
 **clockLimit** | [**number**] | Clock initial time in seconds. If empty, a correspondence game is created. | (optional) defaults to undefined
 **clockIncrement** | [**number**] | Clock increment in seconds. If empty, a correspondence game is created. | (optional) defaults to undefined
 **days** | [**number**] | Days per move, for correspondence games. Clock settings must be omitted. | (optional) defaults to undefined
 **color** | [**string**]**Array<&#39;random&#39; &#124; &#39;white&#39; &#124; &#39;black&#39;>** | Which color you get to play | (optional) defaults to 'random'
 **variant** | **VariantKey** |  | (optional) defaults to undefined
 **fen** | [**string**] | Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. Castling moves will use UCI_Chess960 notation, for example e1h1 instead of e1g1. | (optional) defaults to 'rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1'
 **keepAliveStream** | [**boolean**] | If set, the response is streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). The challenge is kept alive until the connection is closed by the client. When the challenge is accepted, declined or canceled, a message of the form &#x60;{\\\&quot;done\\\&quot;:\\\&quot;accepted\\\&quot;}&#x60; is sent, then the connection is closed by the server. If not set, the response is not streamed, and the challenge expires after 20s if not accepted.  | (optional) defaults to undefined
 **acceptByToken** | [**string**] | Immediately accept the challenge and create the game. Pass in an OAuth token (with the &#x60;challenge:write&#x60; scope) for the receiving user. On success, the response will contain a &#x60;game&#x60; field instead of a &#x60;challenge&#x60; field.  Alternatively, consider the [bulk pairing API](#operation/bulkPairingCreate).  | (optional) defaults to undefined
 **message** | [**string**] | **Only if &#x60;acceptByToken&#x60; is set.**  Message that is sent to each player, when the game is created. It is sent from your user account.  &#x60;{opponent}&#x60;, &#x60;{player}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent name, player name, and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder.  | (optional) defaults to 'Your game with {opponent} is ready: {game}.'


### Return type

**ChallengeJson**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The challenge was successfully created. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the challenge failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **challengeDecline**
> Ok challengeDecline()

Decline an incoming challenge. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ChallengesApi(configuration);

let body:.ChallengesApiChallengeDeclineRequest = {
  // string
  challengeId: "5IrD6Gzz",
  // string | Reason challenge was declined. It will be translated to the player's language. See [the full list in the translation file](https://github.com/ornicar/lila/blob/43fbd61029ff3960a21fbd213944bed66325696d/translation/source/challenge.xml#L14). (optional)
  reason: "generic",
};

apiInstance.challengeDecline(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **challengeId** | [**string**] |  | defaults to undefined
 **reason** | [**string**]**Array<&#39;generic&#39; &#124; &#39;later&#39; &#124; &#39;tooFast&#39; &#124; &#39;tooSlow&#39; &#124; &#39;timeControl&#39; &#124; &#39;rated&#39; &#124; &#39;casual&#39; &#124; &#39;standard&#39; &#124; &#39;variant&#39; &#124; &#39;noBot&#39; &#124; &#39;onlyBot&#39;>** | Reason challenge was declined. It will be translated to the player&#39;s language. See [the full list in the translation file](https://github.com/ornicar/lila/blob/43fbd61029ff3960a21fbd213944bed66325696d/translation/source/challenge.xml#L14). | (optional) defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The challenge was successfully declined. |  * Access-Control-Allow-Origin -  <br>  |
**404** | The challenge to decline was not found. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **challengeList**
> InlineResponse2003 challengeList()

Get a list of challenges created by or targeted at you. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ChallengesApi(configuration);

let body:any = {};

apiInstance.challengeList(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters
This endpoint does not need any parameter.


### Return type

**InlineResponse2003**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of challenges created by or targeted at the logged in user. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **challengeOpen**
> any challengeOpen()

Create a challenge that any 2 players can join.  Share the URL of the challenge. the first 2 players to click it will be paired for a game.  The response body also contains `whiteUrl` and `blackUrl`. You can control which color each player gets by giving them these URLs, instead of the main challenge URL.  Open challenges expire after 24h.  To directly pair 2 known players, use [this endpoint](#operation/challengeCreate) instead, with the `acceptByToken` parameter. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ChallengesApi(configuration);

let body:.ChallengesApiChallengeOpenRequest = {
  // boolean | Game is rated and impacts players ratings (optional)
  rated: true,
  // number | Clock initial time in seconds. If empty, a correspondence game is created. (optional)
  clockLimit: 300,
  // number | Clock increment in seconds. If empty, a correspondence game is created. (optional)
  clockIncrement: 1,
  // VariantKey (optional)
  variant: "standard",
  // string | Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. (optional)
  fen: "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1",
  // string | Optional name for the challenge, that players will see on the challenge page. (optional)
  name: "name_example",
};

apiInstance.challengeOpen(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **rated** | [**boolean**] | Game is rated and impacts players ratings | (optional) defaults to undefined
 **clockLimit** | [**number**] | Clock initial time in seconds. If empty, a correspondence game is created. | (optional) defaults to undefined
 **clockIncrement** | [**number**] | Clock increment in seconds. If empty, a correspondence game is created. | (optional) defaults to undefined
 **variant** | **VariantKey** |  | (optional) defaults to undefined
 **fen** | [**string**] | Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. | (optional) defaults to 'rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1'
 **name** | [**string**] | Optional name for the challenge, that players will see on the challenge page. | (optional) defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The challenge was successfully created. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the challenge failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **challengeStartClocks**
> Ok challengeStartClocks()

Start the clocks of a game immediately, even if a player has not yet made a move.  Requires the OAuth tokens of both players with `challenge:write` scope.  If the clocks have already started, the call will have no effect. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ChallengesApi(configuration);

let body:.ChallengesApiChallengeStartClocksRequest = {
  // string
  gameId: "gameId_example",
  // string | OAuth token of a player (optional)
  token1: "token1_example",
  // string | OAuth token of the other player (optional)
  token2: "token2_example",
};

apiInstance.challengeStartClocks(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined
 **token1** | [**string**] | OAuth token of a player | (optional) defaults to undefined
 **token2** | [**string**] | OAuth token of the other player | (optional) defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The clock of a game was successfully started. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **roundAddTime**
> Ok roundAddTime()

Add seconds to the opponent's clock. Can be used to create games with time odds. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .ChallengesApi(configuration);

let body:.ChallengesApiRoundAddTimeRequest = {
  // string
  gameId: "gameId_example",
  // string | How many seconds to give
  seconds: "seconds_example",
};

apiInstance.roundAddTime(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined
 **seconds** | [**string**] | How many seconds to give | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Time was successfully added to the opponent&#39;s clock. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


