# .GamesApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiAccountPlaying**](GamesApi.md#apiAccountPlaying) | **GET** /api/account/playing | Get my ongoing games
[**apiGamesUser**](GamesApi.md#apiGamesUser) | **GET** /api/games/user/{username} | Export games of a user
[**apiUserCurrentGame**](GamesApi.md#apiUserCurrentGame) | **GET** /api/user/{username}/current-game | Export ongoing game of a user
[**gameImport**](GamesApi.md#gameImport) | **POST** /api/import | Import one game
[**gamePgn**](GamesApi.md#gamePgn) | **GET** /game/export/{gameId} | Export one game
[**gamesByUsers**](GamesApi.md#gamesByUsers) | **POST** /api/stream/games-by-users | Stream games of users
[**gamesExportIds**](GamesApi.md#gamesExportIds) | **POST** /games/export/_ids | Export games by IDs
[**streamGame**](GamesApi.md#streamGame) | **GET** /api/stream/game/{id} | Stream moves of a game


# **apiAccountPlaying**
> any apiAccountPlaying()

Get the ongoing games of the current user. Real-time and correspondence games are included. The most urgent games are listed first. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .GamesApi(configuration);

let body:.GamesApiApiAccountPlayingRequest = {
  // number | Max number of games to fetch (optional)
  nb: 9,
};

apiInstance.apiAccountPlaying(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nb** | [**number**] | Max number of games to fetch | (optional) defaults to 9


### Return type

**any**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The ongoing games of the logged in user. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiGamesUser**
> any apiGamesUser()

Download all games of any user in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first)  We recommend streaming the response, for it can be very long. <https://lichess.org/@/german11> for instance has more than 320,000 games.  The game stream is throttled, depending on who is making the request:   - Anonymous request: 20 games per second   - [OAuth2 authenticated](#section/Authentication) request: 30 games per second   - Authenticated, downloading your own games: 60 games per second 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .GamesApi(configuration);

let body:.GamesApiApiGamesUserRequest = {
  // string | The user name.
  username: "username_example",
  // number | Download games played since this timestamp. (optional)
  since: 1356998400070,
  // number | Download games played until this timestamp. (optional)
  until: 1356998400070,
  // number | How many games to download. Leave empty to download all games. (optional)
  max: 1,
  // string | [Filter] Only games played against this opponent (optional)
  vs: "vs_example",
  // boolean | [Filter] Only rated (`true`) or casual (`false`) games (optional)
  rated: true,
  // PerfType | [Filter] Only games in these speeds or variants.   Multiple perf types can be specified, separated by a comma.   Example: blitz,rapid,classical (optional)
  perfType: null,
  // 'white' | 'black' | [Filter] Only games played as this color. (optional)
  color: "null",
  // boolean | [Filter] Only games with or without a computer analysis available (optional)
  analysed: true,
  // boolean | Include the PGN moves. (optional)
  moves: true,
  // boolean | Include the full PGN within the JSON response, in a `pgn` field. The response type must be set to `application/x-ndjson` by the request `Accept` header. (optional)
  pgnInJson: false,
  // boolean | Include the PGN tags. (optional)
  tags: true,
  // boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }`  (optional)
  clocks: false,
  // boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }`  (optional)
  evals: false,
  // boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]`  (optional)
  opening: false,
  // boolean | Include ongoing games. The last 3 moves will be omitted. (optional)
  ongoing: false,
  // boolean | Include finished games. Set to `false` to only get ongoing games. (optional)
  finished: true,
  // string | URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: <https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt>  (optional)
  players: "players_example",
  // 'dateAsc' | 'dateDesc' | Sort order of the games. (optional)
  sort: "dateDesc",
};

apiInstance.apiGamesUser(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | [**string**] | The user name. | defaults to undefined
 **since** | [**number**] | Download games played since this timestamp. | (optional) defaults to undefined
 **until** | [**number**] | Download games played until this timestamp. | (optional) defaults to undefined
 **max** | [**number**] | How many games to download. Leave empty to download all games. | (optional) defaults to undefined
 **vs** | [**string**] | [Filter] Only games played against this opponent | (optional) defaults to undefined
 **rated** | [**boolean**] | [Filter] Only rated (&#x60;true&#x60;) or casual (&#x60;false&#x60;) games | (optional) defaults to undefined
 **perfType** | **PerfType** | [Filter] Only games in these speeds or variants.   Multiple perf types can be specified, separated by a comma.   Example: blitz,rapid,classical | (optional) defaults to undefined
 **color** | [**&#39;white&#39; | &#39;black&#39;**]**Array<&#39;white&#39; &#124; &#39;black&#39;>** | [Filter] Only games played as this color. | (optional) defaults to 'null'
 **analysed** | [**boolean**] | [Filter] Only games with or without a computer analysis available | (optional) defaults to undefined
 **moves** | [**boolean**] | Include the PGN moves. | (optional) defaults to undefined
 **pgnInJson** | [**boolean**] | Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. The response type must be set to &#x60;application/x-ndjson&#x60; by the request &#x60;Accept&#x60; header. | (optional) defaults to undefined
 **tags** | [**boolean**] | Include the PGN tags. | (optional) defaults to undefined
 **clocks** | [**boolean**] | Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | (optional) defaults to undefined
 **evals** | [**boolean**] | Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | (optional) defaults to undefined
 **opening** | [**boolean**] | Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | (optional) defaults to undefined
 **ongoing** | [**boolean**] | Include ongoing games. The last 3 moves will be omitted. | (optional) defaults to undefined
 **finished** | [**boolean**] | Include finished games. Set to &#x60;false&#x60; to only get ongoing games. | (optional) defaults to undefined
 **players** | [**string**] | URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  | (optional) defaults to undefined
 **sort** | [**&#39;dateAsc&#39; | &#39;dateDesc&#39;**]**Array<&#39;dateAsc&#39; &#124; &#39;dateDesc&#39;>** | Sort order of the games. | (optional) defaults to 'dateDesc'


### Return type

**any**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The games of the user. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiUserCurrentGame**
> any apiUserCurrentGame()

Download the ongoing game, or the last game played, of a user. Available in either PGN or JSON format. If the game is ongoing, the 3 last moves are omitted. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .GamesApi(configuration);

let body:.GamesApiApiUserCurrentGameRequest = {
  // string
  username: "username_example",
  // boolean | Include the PGN moves. (optional)
  moves: true,
  // boolean | Include the full PGN within the JSON response, in a `pgn` field. (optional)
  pgnInJson: false,
  // boolean | Include the PGN tags. (optional)
  tags: true,
  // boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }`  (optional)
  clocks: true,
  // boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }`  (optional)
  evals: true,
  // boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]`  (optional)
  opening: true,
  // boolean | Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: `5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)`  (optional)
  literate: false,
  // string | URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: <https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt>  (optional)
  players: "players_example",
};

apiInstance.apiUserCurrentGame(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | [**string**] |  | defaults to undefined
 **moves** | [**boolean**] | Include the PGN moves. | (optional) defaults to undefined
 **pgnInJson** | [**boolean**] | Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | (optional) defaults to undefined
 **tags** | [**boolean**] | Include the PGN tags. | (optional) defaults to undefined
 **clocks** | [**boolean**] | Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | (optional) defaults to undefined
 **evals** | [**boolean**] | Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | (optional) defaults to undefined
 **opening** | [**boolean**] | Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | (optional) defaults to undefined
 **literate** | [**boolean**] | Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60;  | (optional) defaults to undefined
 **players** | [**string**] | URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  | (optional) defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The ongoing (or last) game of a user. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **gameImport**
> any gameImport()

Import a game from PGN. See <https://lichess.org/paste>.  Rate limiting: 200 games per hour for OAuth requests, 100 games per hour for anonymous requests.  To broadcast ongoing games, consider [pushing to a broadcast instead](#operation/broadcastPush). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .GamesApi(configuration);

let body:.GamesApiGameImportRequest = {
  // string | The PGN. It can contain only one game. Most standard tags are supported. (optional)
  pgn: "pgn_example",
};

apiInstance.gameImport(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pgn** | [**string**] | The PGN. It can contain only one game. Most standard tags are supported. | (optional) defaults to undefined


### Return type

**any**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The game was successfully imported. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **gamePgn**
> any gamePgn()

Download one game in either PGN or JSON format.  Ongoing games have their last 3 moves omitted, after move 5. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .GamesApi(configuration);

let body:.GamesApiGamePgnRequest = {
  // string | The game ID (8 characters).
  gameId: "gameId_example",
  // boolean | Include the PGN moves. (optional)
  moves: true,
  // boolean | Include the full PGN within the JSON response, in a `pgn` field. (optional)
  pgnInJson: false,
  // boolean | Include the PGN tags. (optional)
  tags: true,
  // boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }`  (optional)
  clocks: true,
  // boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }`  (optional)
  evals: true,
  // boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]`  (optional)
  opening: true,
  // boolean | Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: `5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)`  (optional)
  literate: false,
  // string | URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: <https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt>  (optional)
  players: "players_example",
};

apiInstance.gamePgn(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] | The game ID (8 characters). | defaults to undefined
 **moves** | [**boolean**] | Include the PGN moves. | (optional) defaults to undefined
 **pgnInJson** | [**boolean**] | Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | (optional) defaults to undefined
 **tags** | [**boolean**] | Include the PGN tags. | (optional) defaults to undefined
 **clocks** | [**boolean**] | Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | (optional) defaults to undefined
 **evals** | [**boolean**] | Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | (optional) defaults to undefined
 **opening** | [**boolean**] | Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | (optional) defaults to undefined
 **literate** | [**boolean**] | Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60;  | (optional) defaults to undefined
 **players** | [**string**] | URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  | (optional) defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The game representation. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **gamesByUsers**
> any gamesByUsers(body)

Stream the games played between a list of users, in real time. Only games where **both players** are part of the list are included.  By default, games are only sent to the stream when they start. To also get all ongoing games at the beginning of the stream, use the `withCurrentGames` flag.  Maximum number of users: 300.  Games are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  The method is `POST` so a longer list of IDs can be sent in the request body. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .GamesApi(configuration);

let body:.GamesApiGamesByUsersRequest = {
  // string | Up to 300 user IDs separated by commas.
  body: "aliquantus,chess-network,lovlas",
  // boolean | Include the already started games at the beginning of the stream. (optional)
  withCurrentGames: false,
};

apiInstance.gamesByUsers(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | **string**| Up to 300 user IDs separated by commas. |
 **withCurrentGames** | [**boolean**] | Include the already started games at the beginning of the stream. | (optional) defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: text/plain
 - **Accept**: application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The stream of the games played between the users. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **gamesExportIds**
> any gamesExportIds(body)

Download games by IDs in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format, depending on the request Accept header.  Games are sorted by reverse chronological order (most recent first)  The method is `POST` so a longer list of IDs can be sent in the request body.  300 IDs can be submitted.  Ongoing games have their last 3 moves omitted, after move 5. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .GamesApi(configuration);

let body:.GamesApiGamesExportIdsRequest = {
  // string | Game IDs separated by commas. Up to 300.
  body: "TJxUmbWK,4OtIh2oh,ILwozzRZ",
  // boolean | Include the PGN moves. (optional)
  moves: true,
  // boolean | Include the full PGN within the JSON response, in a `pgn` field. (optional)
  pgnInJson: false,
  // boolean | Include the PGN tags. (optional)
  tags: true,
  // boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }`  (optional)
  clocks: false,
  // boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }`  (optional)
  evals: false,
  // boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]`  (optional)
  opening: false,
  // string | URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: <https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt>  (optional)
  players: "players_example",
};

apiInstance.gamesExportIds(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | **string**| Game IDs separated by commas. Up to 300. |
 **moves** | [**boolean**] | Include the PGN moves. | (optional) defaults to undefined
 **pgnInJson** | [**boolean**] | Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | (optional) defaults to undefined
 **tags** | [**boolean**] | Include the PGN tags. | (optional) defaults to undefined
 **clocks** | [**boolean**] | Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | (optional) defaults to undefined
 **evals** | [**boolean**] | Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | (optional) defaults to undefined
 **opening** | [**boolean**] | Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | (optional) defaults to undefined
 **players** | [**string**] | URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  | (optional) defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: text/plain
 - **Accept**: application/x-chess-pgn, application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The representation of the games. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **streamGame**
> any streamGame()

Stream positions and moves of any ongoing game, in [ndjson](#section/Introduction/Streaming-with-ND-JSON).  A description of the game is sent as a first message. Then a message is sent each time a move is played. Finally a description of the game is sent when it finishes, and the stream is closed.  After move 5, the stream intentionally remains 3 moves behind the game status, as to prevent cheat bots from using this API.  No more than 8 game streams can be opened at the same time from the same IP address. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .GamesApi(configuration);

let body:.GamesApiStreamGameRequest = {
  // string
  id: "LuGQwhBb",
};

apiInstance.streamGame(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] |  | defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The stream of the game moves. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


