# .OAuthApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiToken**](OAuthApi.md#apiToken) | **POST** /api/token | Obtain access token
[**apiTokenDelete**](OAuthApi.md#apiTokenDelete) | **DELETE** /api/token | Revoke access token
[**oauth**](OAuthApi.md#oauth) | **GET** /oauth | Request authorization code


# **apiToken**
> void apiToken()

OAuth2 token endpoint. Exchanges an authorization code for an access token. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .OAuthApi(configuration);

let body:.OAuthApiApiTokenRequest = {
  // string | Must be `authorization_code`. (optional)
  grantType: "authorization_code",
  // string | The authorization code that was sent in the `code` parameter to your `redirect_uri`. (optional)
  code: "liu_iS1uOZg99Htmo58ex2jKgYziUfzsnAl0",
  // string | A `code_challenge` was used to request the authorization code. This must be the `code_verifier` it was derived from. (optional)
  codeVerifier: "Ry1rbGdOMTQtUjhOc0lmTnFKak1LTHV0NjlRMll2aXYtTThkQnlJRkRpaGwyQjh0ZDNFdzFPSG9KUlY4M1NrRzJ5ZHhUdjVZR08zLTZOT3dCN2xLfjZOXzU2WHk4SENP",
  // string | Must match the `redirect_uri` used to request the authorization code. (optional)
  redirectUri: "http://example.com/",
  // string | Must match the `client_id` used to request the authorization code. (optional)
  clientId: "example.com",
};

apiInstance.apiToken(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **grantType** | [**string**] | Must be &#x60;authorization_code&#x60;. | (optional) defaults to undefined
 **code** | [**string**] | The authorization code that was sent in the &#x60;code&#x60; parameter to your &#x60;redirect_uri&#x60;. | (optional) defaults to undefined
 **codeVerifier** | [**string**] | A &#x60;code_challenge&#x60; was used to request the authorization code. This must be the &#x60;code_verifier&#x60; it was derived from. | (optional) defaults to undefined
 **redirectUri** | [**string**] | Must match the &#x60;redirect_uri&#x60; used to request the authorization code. | (optional) defaults to undefined
 **clientId** | [**string**] | Must match the &#x60;client_id&#x60; used to request the authorization code. | (optional) defaults to undefined


### Return type

**void**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Access token successfully obtained. |  * Access-Control-Allow-Origin -  <br>  |
**400** | Failed to obtain access token. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiTokenDelete**
> void apiTokenDelete()

Revokes the access token sent as Bearer for this request.

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .OAuthApi(configuration);

let body:any = {};

apiInstance.apiTokenDelete(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters
This endpoint does not need any parameter.


### Return type

**void**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**204** | Access token revoked. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **oauth**
> void oauth()

OAuth2 authorization endpoint.  Start the OAuth2 Authorization Code Flow with PKCE by securely generating two random strings unique to each authorization request: * `code_verifier` * `state`  Store these in session storage. Make sure not to reveal `code_verifier` to eavesdroppers. Do not show it in URLs, do not abuse `state` to store it, do not send it over insecure connections. However it is fine if the user themselves can extract `code_verifier`, which will always be possible for fully client-side apps.  Then send the user to this endpoint. They will be prompted to grant authorization and then be redirected back to the given `redirect_uri`.  If the authorization failed, the following query string parameters will be appended to the redirection: * `error`, in particular with value `access_denied` if the user    cancelled authorization * `error_description` to aid debugging * `state`, exactly as passed in the `state` parameter  If the authorization succeeded, the following query string parameters will be appended to the redirection: * `code`, containing a fresh short-lived authorization code * `state`, exactly as passed in the `state` parameter  Next, to defend against cross site request forgery, check that the returned `state` matches the `state` you originally generated.  Finally, continue by using the authorization code to [obtain an access token](#operation/apiToken). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .OAuthApi(configuration);

let body:.OAuthApiOauthRequest = {
  // string | Must be `code`.
  responseType: "response_type_example",
  // string | Arbitrary identifier that uniquely identifies your application.
  clientId: "example.com",
  // string | The absolute URL that the user should be redirected to with the authorization result.
  redirectUri: "redirect_uri_example",
  // string | Must be `S256`.
  codeChallengeMethod: "code_challenge_method_example",
  // string | Compute `BASE64URL(SHA256(code_verifier))`.
  codeChallenge: "code_challenge_example",
  // string | Space separated list of requested OAuth scopes, if any. (optional)
  scope: "scope_example",
  // string | Arbitrary state that will be returned verbatim with the authorization result. (optional)
  state: "state_example",
};

apiInstance.oauth(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **responseType** | [**string**] | Must be &#x60;code&#x60;. | defaults to undefined
 **clientId** | [**string**] | Arbitrary identifier that uniquely identifies your application. | defaults to undefined
 **redirectUri** | [**string**] | The absolute URL that the user should be redirected to with the authorization result. | defaults to undefined
 **codeChallengeMethod** | [**string**] | Must be &#x60;S256&#x60;. | defaults to undefined
 **codeChallenge** | [**string**] | Compute &#x60;BASE64URL(SHA256(code_verifier))&#x60;. | defaults to undefined
 **scope** | [**string**] | Space separated list of requested OAuth scopes, if any. | (optional) defaults to undefined
 **state** | [**string**] | Arbitrary state that will be returned verbatim with the authorization result. | (optional) defaults to undefined


### Return type

**void**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Authorization prompt will be displayed to the user. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


