# .OpeningExplorerApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**openingExplorerLichess**](OpeningExplorerApi.md#openingExplorerLichess) | **GET** /lichess | Lichess games
[**openingExplorerMaster**](OpeningExplorerApi.md#openingExplorerMaster) | **GET** /masters | Masters database
[**openingExplorerMasterGame**](OpeningExplorerApi.md#openingExplorerMasterGame) | **GET** /master/pgn/{gameId} | OTB master game
[**openingExplorerPlayer**](OpeningExplorerApi.md#openingExplorerPlayer) | **GET** /player? | Player games


# **openingExplorerLichess**
> any openingExplorerLichess()

**Endpoint: <https://explorer.lichess.ovh/lichess>**  Games sampled from all Lichess players.  Example: `curl https://explorer.lichess.ovh/lichess?variant=standard&speeds=blitz,rapid,classical&ratings=2200,2500&fen=rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR%20w%20KQkq%20-%200%201` 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .OpeningExplorerApi(configuration);

let body:.OpeningExplorerApiOpeningExplorerLichessRequest = {
  // VariantKey | Variant (optional)
  variant: "standard",
  // string | FEN of the root position (optional)
  fen: "rnbqkbnr/ppp1pppp/8/3pP3/8/8/PPPP1PPP/RNBQKBNR b KQkq - 0 2",
  // string | Comma separated sequence of legal moves in UCI notation. Play additional moves starting from `fen`. Required to find an opening name, if `fen` is not an exact match for a named position.  (optional)
  play: "e2e4,e7e5,c2c4,c7c6,c4e5",
  // Array<Speed> | Comma separated list of game speeds to look for (optional)
  speeds: [
    "ultraBullet",
  ],
  // Array<1600 | 1800 | 2000 | 2200 | 2500> | Comma separated list of rating groups, ranging from their value to the next higher group (optional)
  ratings: [
    1600,
  ],
  // string | Include only games from this month or later (optional)
  since: "0000-01",
  // string | Include only games from this month or earlier (optional)
  until: "3000-12",
  // number | Number of most common moves to display (optional)
  moves: 12,
  // number | Number of top games to display (optional)
  topGames: 4,
  // number | Number of recent games to display (optional)
  recentGames: 4,
};

apiInstance.openingExplorerLichess(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **variant** | **VariantKey** | Variant | (optional) defaults to undefined
 **fen** | [**string**] | FEN of the root position | (optional) defaults to undefined
 **play** | [**string**] | Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  | (optional) defaults to ''
 **speeds** | **Array&lt;Speed&gt;** | Comma separated list of game speeds to look for | (optional) defaults to undefined
 **ratings** | **Array<1600 &#124; 1800 &#124; 2000 &#124; 2200 &#124; 2500>** | Comma separated list of rating groups, ranging from their value to the next higher group | (optional) defaults to undefined
 **since** | [**string**] | Include only games from this month or later | (optional) defaults to '0000-01'
 **until** | [**string**] | Include only games from this month or earlier | (optional) defaults to '3000-12'
 **moves** | [**number**] | Number of most common moves to display | (optional) defaults to 12
 **topGames** | [**number**] | Number of top games to display | (optional) defaults to 4
 **recentGames** | [**number**] | Number of recent games to display | (optional) defaults to 4


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Opening statistics and game references for the position. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **openingExplorerMaster**
> any openingExplorerMaster()

**Endpoint: <https://explorer.lichess.ovh/masters>**  Example: `curl https://explorer.lichess.ovh/masters?play=d2d4,d7d5,c2c4,c7c6,c4d5` 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .OpeningExplorerApi(configuration);

let body:.OpeningExplorerApiOpeningExplorerMasterRequest = {
  // string | FEN of the root position (optional)
  fen: "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1",
  // string | Comma separated sequence of legal moves in UCI notation. Play additional moves starting from `fen`. Required to find an opening name, if `fen` is not an exact match for a named position.  (optional)
  play: "e2e4,e7e5,c2c4,c7c6,c4e5",
  // number | Include only games from this year or later (optional)
  since: 1952,
  // number | Include only games from thi year or earlier (optional)
  until: 3.14,
  // number | Number of most common moves to display (optional)
  moves: 12,
  // number | Number of top games to display (optional)
  topGames: 15,
};

apiInstance.openingExplorerMaster(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **fen** | [**string**] | FEN of the root position | (optional) defaults to undefined
 **play** | [**string**] | Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  | (optional) defaults to ''
 **since** | [**number**] | Include only games from this year or later | (optional) defaults to 1952
 **until** | [**number**] | Include only games from thi year or earlier | (optional) defaults to undefined
 **moves** | [**number**] | Number of most common moves to display | (optional) defaults to 12
 **topGames** | [**number**] | Number of top games to display | (optional) defaults to 15


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Opening statistics and game references for the position. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **openingExplorerMasterGame**
> any openingExplorerMasterGame()

**Endpoint: `https://explorer.lichess.ovh/masters/pgn/{gameId}`**  Example: `curl https://explorer.lichess.ovh/masters/pgn/aAbqI4ey` 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .OpeningExplorerApi(configuration);

let body:.OpeningExplorerApiOpeningExplorerMasterGameRequest = {
  // string
  gameId: "gameId_example",
};

apiInstance.openingExplorerMasterGame(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | [**string**] |  | defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The PGN representation of the game. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **openingExplorerPlayer**
> any openingExplorerPlayer()

**Endpoint: <https://explorer.lichess.ovh/player>**  Games of a Lichess player.  Responds with a stream of newline delimited JSON. Will start indexing on demand, immediately respond with the current results, and stream more updates until indexing is complete. The stream is throttled and deduplicated. Empty lines may be sent to avoid timeouts.  Will index new games at most once per minute, and revisit previously ongoing games at most once every day.  Example: `curl https://explorer.lichess.ovh/player?player=revoof&color=white&play=d2d4,d7d5&recentGames=1` 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .OpeningExplorerApi(configuration);

let body:.OpeningExplorerApiOpeningExplorerPlayerRequest = {
  // VariantKey | Variant (optional)
  variant: "standard",
  // string | FEN of the root position (optional)
  fen: "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1",
  // string | Comma separated sequence of legal moves in UCI notation. Play additional moves starting from `fen`. Required to find an opening name, if `fen` is not an exact match for a named position.  (optional)
  play: "d2d4,d7d5",
  // Array<Speed> | Comma separated list of game speeds to look for (optional)
  speeds: [
    "ultraBullet",
  ],
  // Array<'casual' | 'rated'> | Comma separated list of modes (optional)
  modes: [
    "casual",
  ],
  // string | Include only games from this month or later (optional)
  since: "0000-01",
  // string | Include only games from this month or earlier (optional)
  until: "3000-12",
  // number | Number of most common moves to display (optional)
  moves: 3.14,
  // number | Number of recent games to display (optional)
  recentGames: 4,
};

apiInstance.openingExplorerPlayer(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **variant** | **VariantKey** | Variant | (optional) defaults to undefined
 **fen** | [**string**] | FEN of the root position | (optional) defaults to undefined
 **play** | [**string**] | Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  | (optional) defaults to ''
 **speeds** | **Array&lt;Speed&gt;** | Comma separated list of game speeds to look for | (optional) defaults to undefined
 **modes** | **Array<&#39;casual&#39; &#124; &#39;rated&#39;>** | Comma separated list of modes | (optional) defaults to undefined
 **since** | [**string**] | Include only games from this month or later | (optional) defaults to '0000-01'
 **until** | [**string**] | Include only games from this month or earlier | (optional) defaults to '3000-12'
 **moves** | [**number**] | Number of most common moves to display | (optional) defaults to undefined
 **recentGames** | [**number**] | Number of recent games to display | (optional) defaults to 4


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/nd-json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Opening statistics and game references for the position. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


