# .PuzzlesApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiPuzzleActivity**](PuzzlesApi.md#apiPuzzleActivity) | **GET** /api/puzzle/activity | Get your puzzle activity
[**apiPuzzleDaily**](PuzzlesApi.md#apiPuzzleDaily) | **GET** /api/puzzle/daily | Get the daily puzzle
[**apiPuzzleDashboard**](PuzzlesApi.md#apiPuzzleDashboard) | **GET** /api/puzzle/dashboard/{days} | Get your puzzle dashboard
[**apiStormDashboard**](PuzzlesApi.md#apiStormDashboard) | **GET** /api/storm/dashboard/{username} | Get the storm dashboard of a player


# **apiPuzzleActivity**
> PuzzleRoundJson apiPuzzleActivity()

Download your puzzle activity in [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Puzzle activity is sorted by reverse chronological order (most recent first)  We recommend streaming the response, for it can be very long. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .PuzzlesApi(configuration);

let body:.PuzzlesApiApiPuzzleActivityRequest = {
  // number | How many entries to download. Leave empty to download all activity. (optional)
  max: 1,
};

apiInstance.apiPuzzleActivity(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **max** | [**number**] | How many entries to download. Leave empty to download all activity. | (optional) defaults to undefined


### Return type

**PuzzleRoundJson**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The puzzle activity of the logged in user. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiPuzzleDaily**
> any apiPuzzleDaily()

Get the daily Lichess puzzle in JSON format.  Alternatively, you can [post it in your slack workspace](https://lichess.org/daily-puzzle-slack). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .PuzzlesApi(configuration);

let body:any = {};

apiInstance.apiPuzzleDaily(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters
This endpoint does not need any parameter.


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The daily puzzle. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiPuzzleDashboard**
> any apiPuzzleDashboard()

Download your [puzzle dashboard](https://lichess.org/training/dashboard/30/dashboard) as JSON.  Also includes all puzzle themes played, with aggregated results.  Allows re-creating the [improvement/strengths](https://lichess.org/training/dashboard/30/improvementAreas) interfaces. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .PuzzlesApi(configuration);

let body:.PuzzlesApiApiPuzzleDashboardRequest = {
  // number | How many days to look back when aggregating puzzle results. 30 is sensible.
  days: 1,
};

apiInstance.apiPuzzleDashboard(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **days** | [**number**] | How many days to look back when aggregating puzzle results. 30 is sensible. | defaults to undefined


### Return type

**any**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The puzzle dashboard of the logged in user. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiStormDashboard**
> any apiStormDashboard()

Download the [storm dashboard](https://lichess.org/storm/dashboard/mrbasso) of any player as JSON.  Contains the aggregated highscores, and the history of storm runs aggregated by days.  Use `?days=0` if you only care about the highscores. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .PuzzlesApi(configuration);

let body:.PuzzlesApiApiStormDashboardRequest = {
  // string | Username of the player
  username: "username_example",
  // number | How many days of history to return (optional)
  days: 30,
};

apiInstance.apiStormDashboard(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | [**string**] | Username of the player | defaults to undefined
 **days** | [**number**] | How many days of history to return | (optional) defaults to 30


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The storm dashboard of a player. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


