# .StudiesApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**studyAllChaptersPgn**](StudiesApi.md#studyAllChaptersPgn) | **GET** /api/study/{studyId}.pgn | Export all chapters
[**studyChapterPgn**](StudiesApi.md#studyChapterPgn) | **GET** /study/{studyId}/{chapterId}.pgn | Export one study chapter
[**studyExportAllPgn**](StudiesApi.md#studyExportAllPgn) | **GET** /study/by/{username}/export.pgn | Export all studies of a user


# **studyAllChaptersPgn**
> any studyAllChaptersPgn()

Download all chapters of a study in PGN format. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .StudiesApi(configuration);

let body:.StudiesApiStudyAllChaptersPgnRequest = {
  // string | The study ID (8 characters).
  studyId: "studyId_example",
  // boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }`  (optional)
  clocks: true,
  // boolean | Include analysis and annotator comments in the PGN moves, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }`  (optional)
  comments: true,
  // boolean | Include non-mainline moves, when available.  Example: `4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2`  (optional)
  variations: true,
};

apiInstance.studyAllChaptersPgn(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **studyId** | [**string**] | The study ID (8 characters). | defaults to undefined
 **clocks** | [**boolean**] | Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | (optional) defaults to undefined
 **comments** | [**boolean**] | Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60;  | (optional) defaults to undefined
 **variations** | [**boolean**] | Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60;  | (optional) defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The PGN representation of the study. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **studyChapterPgn**
> any studyChapterPgn()

Download one study chapter in PGN format. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .StudiesApi(configuration);

let body:.StudiesApiStudyChapterPgnRequest = {
  // string | The study ID (8 characters).
  studyId: "studyId_example",
  // string | The chapter ID (8 characters).
  chapterId: "chapterId_example",
  // boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }`  (optional)
  clocks: true,
  // boolean | Include analysis and annotator comments in the PGN moves, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }`  (optional)
  comments: true,
  // boolean | Include non-mainline moves, when available.  Example: `4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2`  (optional)
  variations: true,
};

apiInstance.studyChapterPgn(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **studyId** | [**string**] | The study ID (8 characters). | defaults to undefined
 **chapterId** | [**string**] | The chapter ID (8 characters). | defaults to undefined
 **clocks** | [**boolean**] | Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | (optional) defaults to undefined
 **comments** | [**boolean**] | Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60;  | (optional) defaults to undefined
 **variations** | [**boolean**] | Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60;  | (optional) defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The chapter of the study. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **studyExportAllPgn**
> any studyExportAllPgn()

Download all chapters of all studies of a user in PGN format.  If authenticated, then all public, unlisted, and private studies are included.  If not, only public, listed studies are included. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .StudiesApi(configuration);

let body:.StudiesApiStudyExportAllPgnRequest = {
  // string | The user whose studies we export
  username: "username_example",
  // boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }`  (optional)
  clocks: true,
  // boolean | Include analysis and annotator comments in the PGN moves, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }`  (optional)
  comments: true,
  // boolean | Include non-mainline moves, when available.  Example: `4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2`  (optional)
  variations: true,
};

apiInstance.studyExportAllPgn(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | [**string**] | The user whose studies we export | defaults to undefined
 **clocks** | [**boolean**] | Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | (optional) defaults to undefined
 **comments** | [**boolean**] | Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60;  | (optional) defaults to undefined
 **variations** | [**boolean**] | Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60;  | (optional) defaults to undefined


### Return type

**any**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The studies of the user. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


