# .SwissTournamentsApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiSwissJoin**](SwissTournamentsApi.md#apiSwissJoin) | **POST** /api/swiss/{id}/join | Join a Swiss tournament
[**apiSwissNew**](SwissTournamentsApi.md#apiSwissNew) | **POST** /api/swiss/new/{teamId} | Create a new Swiss tournament
[**apiSwissTerminate**](SwissTournamentsApi.md#apiSwissTerminate) | **POST** /api/swiss/{id}/terminate | Terminate a Swiss tournament
[**apiSwissUpdate**](SwissTournamentsApi.md#apiSwissUpdate) | **POST** /api/swiss/{id}/edit | Update a Swiss tournament.
[**apiTeamSwiss**](SwissTournamentsApi.md#apiTeamSwiss) | **GET** /api/team/{teamId}/swiss | Get team swiss tournaments
[**gamesBySwiss**](SwissTournamentsApi.md#gamesBySwiss) | **GET** /api/swiss/{id}/games | Export games of a Swiss tournament
[**resultsBySwiss**](SwissTournamentsApi.md#resultsBySwiss) | **GET** /api/swiss/{id}/results | Get results of a swiss tournament
[**swissTrf**](SwissTournamentsApi.md#swissTrf) | **GET** /swiss/{id}.trf | Export TRF of a Swiss tournament


# **apiSwissJoin**
> Ok apiSwissJoin()

Join a Swiss tournament, possibly with a password. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .SwissTournamentsApi(configuration);

let body:.SwissTournamentsApiApiSwissJoinRequest = {
  // string | The tournament ID.
  id: "hL7vMrFQ",
  // string | The tournament password, if one is required (optional)
  password: "password_example",
};

apiInstance.apiSwissJoin(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] | The tournament ID. | defaults to undefined
 **password** | [**string**] | The tournament password, if one is required | (optional) defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The tournament was successfully joined. |  * Access-Control-Allow-Origin -  <br>  |
**400** | Joining the tournament failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiSwissNew**
> any apiSwissNew()

Create a Swiss tournament for your team.  This endpoint mirrors the Swiss tournament form from your team pagee.  You can create up to 12 tournaments per day. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .SwissTournamentsApi(configuration);

let body:.SwissTournamentsApiApiSwissNewRequest = {
  // string | ID of the team
  teamId: "teamId_example",
  // number | Clock initial time in seconds
  clockLimit: 300,
  // number | Clock increment in seconds
  clockIncrement: 1,
  // number | Maximum number of rounds to play
  nbRounds: 8,
  // string | The tournament name. Leave empty to get a random Grandmaster name (optional)
  name: "name_example",
  // number | Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation. (optional)
  startsAt: 1,
  // number | How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI.  (optional)
  roundInterval: 0,
  // VariantKey (optional)
  variant: "standard",
  // string | Anything you want to tell players about the tournament (optional)
  description: "description_example",
  // boolean | Games are rated and impact players ratings (optional)
  rated: true,
  // number | Who can read and write in the chat. - 0  = No-one - 10 = Only team leaders - 20 = Only team members - 30 = All Lichess players  (optional)
  chatFor: 20,
};

apiInstance.apiSwissNew(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | [**string**] | ID of the team | defaults to undefined
 **clockLimit** | [**number**] | Clock initial time in seconds | defaults to undefined
 **clockIncrement** | [**number**] | Clock increment in seconds | defaults to undefined
 **nbRounds** | [**number**] | Maximum number of rounds to play | defaults to 8
 **name** | [**string**] | The tournament name. Leave empty to get a random Grandmaster name | (optional) defaults to undefined
 **startsAt** | [**number**] | Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation. | (optional) defaults to undefined
 **roundInterval** | [**number**] | How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI.  | (optional) defaults to undefined
 **variant** | **VariantKey** |  | (optional) defaults to undefined
 **description** | [**string**] | Anything you want to tell players about the tournament | (optional) defaults to undefined
 **rated** | [**boolean**] | Games are rated and impact players ratings | (optional) defaults to undefined
 **chatFor** | [**number**] | Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players  | (optional) defaults to 20


### Return type

**any**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The Swiss tournament was successfully created. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the Swiss tournament failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiSwissTerminate**
> Ok apiSwissTerminate()

Terminate a Swiss tournament 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .SwissTournamentsApi(configuration);

let body:.SwissTournamentsApiApiSwissTerminateRequest = {
  // string | The Swiss tournament ID.
  id: "W5FrxusN",
};

apiInstance.apiSwissTerminate(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] | The Swiss tournament ID. | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The Swiss tournament was successfully terminated. |  * Access-Control-Allow-Origin -  <br>  |
**400** | Terminating the Swiss tournament failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiSwissUpdate**
> any apiSwissUpdate()

Update a Swiss tournament.  Be mindful not to make important changes to ongoing tournaments. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .SwissTournamentsApi(configuration);

let body:.SwissTournamentsApiApiSwissUpdateRequest = {
  // string | The tournament ID.
  id: "hL7vMrFQ",
  // number | Clock initial time in seconds
  clockLimit: 300,
  // number | Clock increment in seconds
  clockIncrement: 1,
  // number | Maximum number of rounds to play
  nbRounds: 8,
  // string | The tournament name. Leave empty to get a random Grandmaster name (optional)
  name: "name_example",
  // number | Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation. (optional)
  startsAt: 1,
  // number | How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI.  (optional)
  roundInterval: 0,
  // VariantKey (optional)
  variant: "standard",
  // string | Anything you want to tell players about the tournament (optional)
  description: "description_example",
  // boolean | Games are rated and impact players ratings (optional)
  rated: true,
  // number | Who can read and write in the chat. - 0  = No-one - 10 = Only team leaders - 20 = Only team members - 30 = All Lichess players  (optional)
  chatFor: 20,
};

apiInstance.apiSwissUpdate(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] | The tournament ID. | defaults to undefined
 **clockLimit** | [**number**] | Clock initial time in seconds | defaults to undefined
 **clockIncrement** | [**number**] | Clock increment in seconds | defaults to undefined
 **nbRounds** | [**number**] | Maximum number of rounds to play | defaults to 8
 **name** | [**string**] | The tournament name. Leave empty to get a random Grandmaster name | (optional) defaults to undefined
 **startsAt** | [**number**] | Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation. | (optional) defaults to undefined
 **roundInterval** | [**number**] | How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI.  | (optional) defaults to undefined
 **variant** | **VariantKey** |  | (optional) defaults to undefined
 **description** | [**string**] | Anything you want to tell players about the tournament | (optional) defaults to undefined
 **rated** | [**boolean**] | Games are rated and impact players ratings | (optional) defaults to undefined
 **chatFor** | [**number**] | Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players  | (optional) defaults to 20


### Return type

**any**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The Swiss tournament was successfully updated. |  * Access-Control-Allow-Origin -  <br>  |
**400** | Updating the swiss failed. |  -  |
**401** | This user cannot update this Swiss. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiTeamSwiss**
> Array<any> apiTeamSwiss()

Get all swiss tournaments of a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .SwissTournamentsApi(configuration);

let body:.SwissTournamentsApiApiTeamSwissRequest = {
  // string
  teamId: "coders",
  // number | How many tournaments to download. (optional)
  max: 100,
};

apiInstance.apiTeamSwiss(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | [**string**] |  | defaults to undefined
 **max** | [**number**] | How many tournaments to download. | (optional) defaults to 100


### Return type

**Array<any>**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of Swiss tournaments of a team. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **gamesBySwiss**
> any gamesBySwiss()

Download games of a swiss tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (last round first) 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .SwissTournamentsApi(configuration);

let body:.SwissTournamentsApiGamesBySwissRequest = {
  // string | The tournament ID.
  id: "id_example",
  // boolean | Include the PGN moves. (optional)
  moves: true,
  // boolean | Include the full PGN within the JSON response, in a `pgn` field. (optional)
  pgnInJson: false,
  // boolean | Include the PGN tags. (optional)
  tags: true,
  // boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }`  (optional)
  clocks: false,
  // boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }`  (optional)
  evals: false,
  // boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]`  (optional)
  opening: false,
};

apiInstance.gamesBySwiss(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] | The tournament ID. | defaults to undefined
 **moves** | [**boolean**] | Include the PGN moves. | (optional) defaults to undefined
 **pgnInJson** | [**boolean**] | Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | (optional) defaults to undefined
 **tags** | [**boolean**] | Include the PGN tags. | (optional) defaults to undefined
 **clocks** | [**boolean**] | Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | (optional) defaults to undefined
 **evals** | [**boolean**] | Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | (optional) defaults to undefined
 **opening** | [**boolean**] | Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | (optional) defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of games of a Swiss tournament. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **resultsBySwiss**
> any resultsBySwiss()

Players of a swiss tournament, with their score and performance, sorted by rank (best first).  Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .SwissTournamentsApi(configuration);

let body:.SwissTournamentsApiResultsBySwissRequest = {
  // string | The tournament ID.
  id: "id_example",
  // number | Max number of players to fetch (optional)
  nb: 1,
};

apiInstance.resultsBySwiss(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] | The tournament ID. | defaults to undefined
 **nb** | [**number**] | Max number of players to fetch | (optional) defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The results of a Swiss tournament. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **swissTrf**
> string swissTrf()

Download a tournament in the Tournament Report File format, the FIDE standard.  Documentation: <https://www.fide.com/FIDE/handbook/C04Annex2_TRF16.pdf>  Example: <https://lichess.org/swiss/j8rtJ5GL.trf> 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .SwissTournamentsApi(configuration);

let body:.SwissTournamentsApiSwissTrfRequest = {
  // string | The tournament ID.
  id: "id_example",
};

apiInstance.swissTrf(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [**string**] | The tournament ID. | defaults to undefined


### Return type

**string**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: text/plain


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The TRF representation of a Swiss tournament. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


