# .TVApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**tvChannelGames**](TVApi.md#tvChannelGames) | **GET** /api/tv/{channel} | Get best ongoing games of a TV channel
[**tvChannels**](TVApi.md#tvChannels) | **GET** /api/tv/channels | Get current TV games
[**tvFeed**](TVApi.md#tvFeed) | **GET** /api/tv/feed | Stream current TV game


# **tvChannelGames**
> any tvChannelGames()

Get a list of ongoing games for a given TV channel. Similar to [lichess.org/games](https://lichess.org/games).  Available in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format, depending on the request Accept header. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .TVApi(configuration);

let body:.TVApiTvChannelGamesRequest = {
  // string | The name of the channel in lowercase.
  channel: "channel_example",
  // number | Number of games to fetch. (optional)
  nb: 10,
  // boolean | Include the PGN moves. (optional)
  moves: true,
  // boolean | Include the full PGN within the JSON response, in a `pgn` field. (optional)
  pgnInJson: false,
  // boolean | Include the PGN tags. (optional)
  tags: true,
  // boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }`  (optional)
  clocks: false,
  // boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]`  (optional)
  opening: false,
};

apiInstance.tvChannelGames(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **channel** | [**string**] | The name of the channel in lowercase. | defaults to undefined
 **nb** | [**number**] | Number of games to fetch. | (optional) defaults to 10
 **moves** | [**boolean**] | Include the PGN moves. | (optional) defaults to undefined
 **pgnInJson** | [**boolean**] | Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | (optional) defaults to undefined
 **tags** | [**boolean**] | Include the PGN tags. | (optional) defaults to undefined
 **clocks** | [**boolean**] | Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | (optional) defaults to undefined
 **opening** | [**boolean**] | Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | (optional) defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The representation of the games. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **tvChannels**
> any tvChannels()

Get basic info about the best games being played for each speed and variant, but also computer games and bot games.  See [lichess.org/tv](https://lichess.org/tv). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .TVApi(configuration);

let body:any = {};

apiInstance.tvChannels(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters
This endpoint does not need any parameter.


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of games being played for each speed and variant. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **tvFeed**
> any tvFeed()

Stream positions and moves of the current [TV game](https://lichess.org/tv) in [ndjson](#section/Introduction/Streaming-with-ND-JSON). A summary of the game is sent as a first message, and when the featured game changes.  Try it with `curl https://lichess.org/api/tv/feed`. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .TVApi(configuration);

let body:any = {};

apiInstance.tvFeed(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters
This endpoint does not need any parameter.


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The stream of the current TV game. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


