# .TeamsApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiTeamArena**](TeamsApi.md#apiTeamArena) | **GET** /api/team/{teamId}/arena | Get team Arena tournaments
[**apiTeamSwiss**](TeamsApi.md#apiTeamSwiss) | **GET** /api/team/{teamId}/swiss | Get team swiss tournaments
[**teamAll**](TeamsApi.md#teamAll) | **GET** /api/team/all | Get popular teams
[**teamIdJoin**](TeamsApi.md#teamIdJoin) | **POST** /team/{teamId}/join | Join a team
[**teamIdKickUserId**](TeamsApi.md#teamIdKickUserId) | **POST** /team/{teamId}/kick/{userId} | Kick a user from your team
[**teamIdPmAll**](TeamsApi.md#teamIdPmAll) | **POST** /team/{teamId}/pm-all | Message all members
[**teamIdQuit**](TeamsApi.md#teamIdQuit) | **POST** /team/{teamId}/quit | Leave a team
[**teamIdUsers**](TeamsApi.md#teamIdUsers) | **GET** /api/team/{teamId}/users | Get members of a team
[**teamOfUsername**](TeamsApi.md#teamOfUsername) | **GET** /api/team/of/{username} | Teams of a player
[**teamSearch**](TeamsApi.md#teamSearch) | **GET** /api/team/search | Search teams
[**teamShow**](TeamsApi.md#teamShow) | **GET** /api/team/{teamId} | Get a single team


# **apiTeamArena**
> Array<any> apiTeamArena()

Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .TeamsApi(configuration);

let body:.TeamsApiApiTeamArenaRequest = {
  // string | ID of the team
  teamId: "teamId_example",
  // number | How many tournaments to download. (optional)
  max: 100,
};

apiInstance.apiTeamArena(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | [**string**] | ID of the team | defaults to undefined
 **max** | [**number**] | How many tournaments to download. | (optional) defaults to 100


### Return type

**Array<any>**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of Arena tournaments of a team. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiTeamSwiss**
> Array<any> apiTeamSwiss()

Get all swiss tournaments of a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .TeamsApi(configuration);

let body:.TeamsApiApiTeamSwissRequest = {
  // string
  teamId: "coders",
  // number | How many tournaments to download. (optional)
  max: 100,
};

apiInstance.apiTeamSwiss(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | [**string**] |  | defaults to undefined
 **max** | [**number**] | How many tournaments to download. | (optional) defaults to 100


### Return type

**Array<any>**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of Swiss tournaments of a team. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **teamAll**
> InlineResponse2001 teamAll()

Paginator of the most popular teams. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .TeamsApi(configuration);

let body:.TeamsApiTeamAllRequest = {
  // number (optional)
  page: 1,
};

apiInstance.teamAll(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **page** | [**number**] |  | (optional) defaults to 1


### Return type

**InlineResponse2001**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | A paginated list of the most popular teams. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **teamIdJoin**
> Ok teamIdJoin()

Join a team. If the team requires a password but the `password` field is incorrect, then the call fails with `403 Forbidden`. Similarly, if the team join policy requires a confirmation but the `message` parameter is not given, then the call fails with `403 Forbidden`. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .TeamsApi(configuration);

let body:.TeamsApiTeamIdJoinRequest = {
  // string
  teamId: "coders",
  // string | Optional request message, if the team requires one. (optional)
  message: "message_example",
  // string | Optional password, if the team requires one. (optional)
  password: "password_example",
};

apiInstance.teamIdJoin(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | [**string**] |  | defaults to undefined
 **message** | [**string**] | Optional request message, if the team requires one. | (optional) defaults to undefined
 **password** | [**string**] | Optional password, if the team requires one. | (optional) defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The request to join a team was successfully sent. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **teamIdKickUserId**
> Ok teamIdKickUserId()

Kick a member out of one of your teams. - <https://lichess.org/team> 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .TeamsApi(configuration);

let body:.TeamsApiTeamIdKickUserIdRequest = {
  // string
  teamId: "coders",
  // string
  userId: "neio",
};

apiInstance.teamIdKickUserId(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | [**string**] |  | defaults to undefined
 **userId** | [**string**] |  | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The member has been kicked from the team. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **teamIdPmAll**
> Ok teamIdPmAll()

Send a private message to all members of a team. You must own the team. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .TeamsApi(configuration);

let body:.TeamsApiTeamIdPmAllRequest = {
  // string
  teamId: "coders",
  // string | The message to send to all your team members. (optional)
  message: "message_example",
};

apiInstance.teamIdPmAll(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | [**string**] |  | defaults to undefined
 **message** | [**string**] | The message to send to all your team members. | (optional) defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The message has successfully been sent to all team members. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The sending of message to all team members has failed. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **teamIdQuit**
> Ok teamIdQuit()

Leave a team. - <https://lichess.org/team> 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .TeamsApi(configuration);

let body:.TeamsApiTeamIdQuitRequest = {
  // string
  teamId: "coders",
};

apiInstance.teamIdQuit(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | [**string**] |  | defaults to undefined


### Return type

**Ok**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The logged in user has successfully left the team. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **teamIdUsers**
> UserExtended teamIdUsers()

Members are sorted by reverse chronological order of joining the team (most recent first). OAuth only required if the list of members is private.  Members are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .TeamsApi(configuration);

let body:.TeamsApiTeamIdUsersRequest = {
  // string
  teamId: "coders",
};

apiInstance.teamIdUsers(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | [**string**] |  | defaults to undefined


### Return type

**UserExtended**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of users in the team. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **teamOfUsername**
> Array<Team> teamOfUsername()

All the teams a player is a member of. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .TeamsApi(configuration);

let body:.TeamsApiTeamOfUsernameRequest = {
  // string
  username: "thibault",
};

apiInstance.teamOfUsername(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | [**string**] |  | defaults to undefined


### Return type

**Array<Team>**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of teams the user is a member of. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **teamSearch**
> Array<Team> teamSearch()

Paginator of team search results for a keyword. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .TeamsApi(configuration);

let body:.TeamsApiTeamSearchRequest = {
  // string (optional)
  text: "coders",
  // number (optional)
  page: 1,
};

apiInstance.teamSearch(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **text** | [**string**] |  | (optional) defaults to undefined
 **page** | [**number**] |  | (optional) defaults to 1


### Return type

**Array<Team>**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The paginated list of teams. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **teamShow**
> Team teamShow()

Infos about a team

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .TeamsApi(configuration);

let body:.TeamsApiTeamShowRequest = {
  // string
  teamId: "teamId_example",
};

apiInstance.teamShow(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | [**string**] |  | defaults to undefined


### Return type

**Team**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The information about the team. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


