# .UsersApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiCrosstable**](UsersApi.md#apiCrosstable) | **GET** /api/crosstable/{user1}/{user2} | Get crosstable
[**apiUser**](UsersApi.md#apiUser) | **GET** /api/user/{username} | Get user public data
[**apiUserActivity**](UsersApi.md#apiUserActivity) | **GET** /api/user/{username}/activity | Get user activity
[**apiUserPerf**](UsersApi.md#apiUserPerf) | **GET** /api/user/{username}/perf/{perf} | Get performance statistics of a user
[**apiUserRatingHistory**](UsersApi.md#apiUserRatingHistory) | **GET** /api/user/{username}/rating-history | Get rating history of a user
[**apiUsers**](UsersApi.md#apiUsers) | **POST** /api/users | Get users by ID
[**apiUsersStatus**](UsersApi.md#apiUsersStatus) | **GET** /api/users/status | Get real-time users status
[**player**](UsersApi.md#player) | **GET** /player | Get all top 10
[**playerTopNbPerfType**](UsersApi.md#playerTopNbPerfType) | **GET** /player/top/{nb}/{perfType} | Get one leaderboard
[**streamerLive**](UsersApi.md#streamerLive) | **GET** /streamer/live | Get live streamers
[**teamIdUsers**](UsersApi.md#teamIdUsers) | **GET** /api/team/{teamId}/users | Get members of a team


# **apiCrosstable**
> any apiCrosstable()

Get total number of games, and current score, of any two users.  If the `matchup` flag is provided, and the users are currently playing, also gets the current match game number and scores. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .UsersApi(configuration);

let body:.UsersApiApiCrosstableRequest = {
  // string
  user1: "user1_example",
  // string
  user2: "user2_example",
  // boolean | Whether to get the current match data, if any (optional)
  matchup: true,
};

apiInstance.apiCrosstable(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **user1** | [**string**] |  | defaults to undefined
 **user2** | [**string**] |  | defaults to undefined
 **matchup** | [**boolean**] | Whether to get the current match data, if any | (optional) defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The crosstable of the two users. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiUser**
> UserExtended apiUser()

Read public data of a user. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .UsersApi(configuration);

let body:.UsersApiApiUserRequest = {
  // string
  username: "username_example",
};

apiInstance.apiUser(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | [**string**] |  | defaults to undefined


### Return type

**UserExtended**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The information of the user. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiUserActivity**
> void apiUserActivity()

Read data to generate the activity feed of a user. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .UsersApi(configuration);

let body:.UsersApiApiUserActivityRequest = {
  // string
  username: "username_example",
};

apiInstance.apiUserActivity(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | [**string**] |  | defaults to undefined


### Return type

**void**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The activity feed of the user. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiUserPerf**
> any apiUserPerf()

Read performance statistics of a user, for a single performance. Similar to the [performance pages on the website](https://lichess.org/@/thibault/perf/bullet). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .UsersApi(configuration);

let body:.UsersApiApiUserPerfRequest = {
  // string
  username: "username_example",
  // PerfType
  perf: "ultraBullet",
};

apiInstance.apiUserPerf(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | [**string**] |  | defaults to undefined
 **perf** | **PerfType** |  | defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The performance statistics of the user |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiUserRatingHistory**
> any apiUserRatingHistory()

Read rating history of a user, for all perf types. There is at most one entry per day. Format of an entry is `[year, month, day, rating]`. `month` starts at zero (January). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .UsersApi(configuration);

let body:.UsersApiApiUserRatingHistoryRequest = {
  // string
  username: "username_example",
};

apiInstance.apiUserRatingHistory(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | [**string**] |  | defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The rating history of the user. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiUsers**
> Array<User> apiUsers(body)

Get up to 300 users by their IDs. Users are returned in the same order as the IDs.  The method is `POST` so a longer list of IDs can be sent in the request body. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .UsersApi(configuration);

let body:.UsersApiApiUsersRequest = {
  // string | User IDs separated by commas.
  body: "aliquantus,chess-network,lovlas",
};

apiInstance.apiUsers(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | **string**| User IDs separated by commas. |


### Return type

**Array<User>**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: text/plain
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of users. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiUsersStatus**
> Array<InlineResponse200> apiUsersStatus()

Read the `online`, `playing` and `streaming` flags of several users.  This API is very fast and cheap on lichess side. So you can call it quite often (like once every 5 seconds).  Use it to track players and know when they're connected on lichess and playing games. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .UsersApi(configuration);

let body:.UsersApiApiUsersStatusRequest = {
  // string | User IDs separated by commas. Up to 100 IDs.
  ids: "aliquantus,chess-network,lovlas",
};

apiInstance.apiUsersStatus(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ids** | [**string**] | User IDs separated by commas. Up to 100 IDs. | defaults to undefined


### Return type

**Array<InlineResponse200>**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of users and their respective statuses. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **player**
> any player()

Get the top 10 players for each speed and variant.  See <https://lichess.org/player>. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .UsersApi(configuration);

let body:any = {};

apiInstance.player(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters
This endpoint does not need any parameter.


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/vnd.lichess.v3+json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of variants with their respective top players. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **playerTopNbPerfType**
> any playerTopNbPerfType()

Get the leaderboard for a single speed or variant (a.k.a. `perfType`). There is no leaderboard for correspondence or puzzles.  See <https://lichess.org/player/top/200/bullet>. 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .UsersApi(configuration);

let body:.UsersApiPlayerTopNbPerfTypeRequest = {
  // number | How many users to fetch
  nb: 100,
  // 'ultraBullet' | 'bullet' | 'blitz' | 'rapid' | 'classical' | 'chess960' | 'crazyhouse' | 'antichess' | 'atomic' | 'horde' | 'kingOfTheHill' | 'racingKings' | 'threeCheck' | The speed or variant
  perfType: "bullet",
};

apiInstance.playerTopNbPerfType(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nb** | [**number**] | How many users to fetch | defaults to undefined
 **perfType** | [**&#39;ultraBullet&#39; | &#39;bullet&#39; | &#39;blitz&#39; | &#39;rapid&#39; | &#39;classical&#39; | &#39;chess960&#39; | &#39;crazyhouse&#39; | &#39;antichess&#39; | &#39;atomic&#39; | &#39;horde&#39; | &#39;kingOfTheHill&#39; | &#39;racingKings&#39; | &#39;threeCheck&#39;**]**Array<&#39;ultraBullet&#39; &#124; &#39;bullet&#39; &#124; &#39;blitz&#39; &#124; &#39;rapid&#39; &#124; &#39;classical&#39; &#124; &#39;chess960&#39; &#124; &#39;crazyhouse&#39; &#124; &#39;antichess&#39; &#124; &#39;atomic&#39; &#124; &#39;horde&#39; &#124; &#39;kingOfTheHill&#39; &#124; &#39;racingKings&#39; &#124; &#39;threeCheck&#39;>** | The speed or variant | defaults to undefined


### Return type

**any**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/vnd.lichess.v3+json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of top players for the variant. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **streamerLive**
> Array<InlineResponse2002> streamerLive()

Get basic info about currently streaming users.  This API is very fast and cheap on lichess side. So you can call it quite often (like once every 5 seconds). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .UsersApi(configuration);

let body:any = {};

apiInstance.streamerLive(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters
This endpoint does not need any parameter.


### Return type

**Array<InlineResponse2002>**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of live streamers and their respective information. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **teamIdUsers**
> UserExtended teamIdUsers()

Members are sorted by reverse chronological order of joining the team (most recent first). OAuth only required if the list of members is private.  Members are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .UsersApi(configuration);

let body:.UsersApiTeamIdUsersRequest = {
  // string
  teamId: "coders",
};

apiInstance.teamIdUsers(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | [**string**] |  | defaults to undefined


### Return type

**UserExtended**

### Authorization

[OAuth2](README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of users in the team. |  * Access-Control-Allow-Origin -  <br>  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


