// TODO: better import syntax?
import { BaseAPIRequestFactory, RequiredError } from './baseapi';
import {Configuration} from '../configuration';
import { RequestContext, HttpMethod, ResponseContext, HttpFile} from '../http/http';
import {ObjectSerializer} from '../models/ObjectSerializer';
import {ApiException} from './exception';
import {canConsumeForm, isCodeInRange} from '../util';


import { VariantKey } from '../models/VariantKey';

/**
 * no description
 */
export class AnalysisApiRequestFactory extends BaseAPIRequestFactory {

    /**
     * Get the cached evaluation of a position, if available.  Opening positions have more chances of being available. There are about 7 million positions in the database.  Up to 5 variations may be available. Variants are supported. 
     * Get cloud evaluation of a position.
     * @param fen FEN of the position
     * @param multiPv Number of variations
     * @param variant Variant
     */
    public async apiCloudEval(fen: string, multiPv?: number, variant?: VariantKey, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'fen' is not null or undefined
        if (fen === null || fen === undefined) {
            throw new RequiredError("AnalysisApi", "apiCloudEval", "fen");
        }




        // Path Params
        const localVarPath = '/api/cloud-eval';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (fen !== undefined) {
            requestContext.setQueryParam("fen", ObjectSerializer.serialize(fen, "string", ""));
        }

        // Query Params
        if (multiPv !== undefined) {
            requestContext.setQueryParam("multiPv", ObjectSerializer.serialize(multiPv, "number", ""));
        }

        // Query Params
        if (variant !== undefined) {
            requestContext.setQueryParam("variant", ObjectSerializer.serialize(variant, "VariantKey", ""));
        }



        return requestContext;
    }

}

export class AnalysisApiResponseProcessor {

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiCloudEval
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiCloudEval(response: ResponseContext): Promise<void > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            return;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: void = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "void", ""
            ) as void;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

}
