// TODO: better import syntax?
import { BaseAPIRequestFactory, RequiredError } from './baseapi';
import {Configuration} from '../configuration';
import { RequestContext, HttpMethod, ResponseContext, HttpFile} from '../http/http';
import {ObjectSerializer} from '../models/ObjectSerializer';
import {ApiException} from './exception';
import {canConsumeForm, isCodeInRange} from '../util';


import { ChallengeJson } from '../models/ChallengeJson';
import { GameJson } from '../models/GameJson';
import { InlineResponse2003 } from '../models/InlineResponse2003';
import { NotFound } from '../models/NotFound';
import { Ok } from '../models/Ok';
import { VariantKey } from '../models/VariantKey';

/**
 * no description
 */
export class ChallengesApiRequestFactory extends BaseAPIRequestFactory {

    /**
     * **For administrators only. You are not allowed to use this endpoint.**  Create and obtain `challenge:write` tokens for multiple users.  If a similar token already exists for a user, it is reused. This endpoint is idempotent. 
     * Admin challenge tokens
     * @param users Usernames separated with commas
     * @param description User visible description of the token
     */
    public async adminChallengeTokens(users: string, description: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'users' is not null or undefined
        if (users === null || users === undefined) {
            throw new RequiredError("ChallengesApi", "adminChallengeTokens", "users");
        }


        // verify required parameter 'description' is not null or undefined
        if (description === null || description === undefined) {
            throw new RequiredError("ChallengesApi", "adminChallengeTokens", "description");
        }


        // Path Params
        const localVarPath = '/api/token/admin-challenge';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Form Params
        const useForm = canConsumeForm([
            'application/x-www-form-urlencoded',
        ]);

        let localVarFormParams
        if (useForm) {
            localVarFormParams = new FormData();
        } else {
            localVarFormParams = new URLSearchParams();
        }

        if (users !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('users', users as any);
        }
        if (description !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('description', description as any);
        }

        requestContext.setBody(localVarFormParams);

        if(!useForm) {
            const contentType = ObjectSerializer.getPreferredMediaType([
                "application/x-www-form-urlencoded"
            ]);
            requestContext.setHeaderParam("Content-Type", contentType);
        }

        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Accept an incoming challenge.  You should receive a `gameStart` event on the [incoming events stream](#operation/apiStreamEvent). 
     * Accept a challenge
     * @param challengeId 
     */
    public async challengeAccept(challengeId: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'challengeId' is not null or undefined
        if (challengeId === null || challengeId === undefined) {
            throw new RequiredError("ChallengesApi", "challengeAccept", "challengeId");
        }


        // Path Params
        const localVarPath = '/api/challenge/{challengeId}/accept'
            .replace('{' + 'challengeId' + '}', encodeURIComponent(String(challengeId)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")


        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Start a game with Lichess AI.  You will be notified on the [event stream](#operation/apiStreamEvent) that a new game has started. 
     * Challenge the AI
     * @param level AI strength
     * @param clockLimit Clock initial time in seconds. If empty, a correspondence game is created.
     * @param clockIncrement Clock increment in seconds. If empty, a correspondence game is created.
     * @param days Days per move, for correspondence games. Clock settings must be omitted.
     * @param color Which color you get to play
     * @param variant 
     * @param fen Custom initial position (in FEN). Variant must be standard, and the game cannot be rated.
     */
    public async challengeAi(level?: number, clockLimit?: number, clockIncrement?: number, days?: number, color?: string, variant?: VariantKey, fen?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;








        // Path Params
        const localVarPath = '/api/challenge/ai';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Form Params
        const useForm = canConsumeForm([
            'application/x-www-form-urlencoded',
        ]);

        let localVarFormParams
        if (useForm) {
            localVarFormParams = new FormData();
        } else {
            localVarFormParams = new URLSearchParams();
        }

        if (level !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('level', level as any);
        }
        if (clockLimit !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('clock.limit', clockLimit as any);
        }
        if (clockIncrement !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('clock.increment', clockIncrement as any);
        }
        if (days !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('days', days as any);
        }
        if (color !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('color', color as any);
        }
        if (variant !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('variant', variant as any);
        }
        if (fen !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('fen', fen as any);
        }

        requestContext.setBody(localVarFormParams);

        if(!useForm) {
            const contentType = ObjectSerializer.getPreferredMediaType([
                "application/x-www-form-urlencoded"
            ]);
            requestContext.setHeaderParam("Content-Type", contentType);
        }

        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Cancel a challenge you sent, or aborts the game if the challenge was accepted, but the game was not yet played. Note that the ID of a game is the same as the ID of the challenge that created it. 
     * Cancel a challenge
     * @param challengeId 
     * @param opponentToken Optional &#x60;challenge:write&#x60; token of the opponent. If set, the game can be canceled even if both players have moved.
     */
    public async challengeCancel(challengeId: string, opponentToken?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'challengeId' is not null or undefined
        if (challengeId === null || challengeId === undefined) {
            throw new RequiredError("ChallengesApi", "challengeCancel", "challengeId");
        }



        // Path Params
        const localVarPath = '/api/challenge/{challengeId}/cancel'
            .replace('{' + 'challengeId' + '}', encodeURIComponent(String(challengeId)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (opponentToken !== undefined) {
            requestContext.setQueryParam("opponentToken", ObjectSerializer.serialize(opponentToken, "string", ""));
        }


        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Challenge someone to play. The targeted player can choose to accept or decline.  If the challenge is accepted, you will be notified on the [event stream](#operation/apiStreamEvent) that a new game has started. The game ID will be the same as the challenge ID.  If you also have an OAuth token with `challenge:write` scope for the receiving user, you can make them accept the challenge immediately by setting the `acceptByToken` field.  Challenges for realtime games (not correspondence) expire after 20s if not accepted. To prevent that, use the `keepAliveStream` flag described below. 
     * Create a challenge
     * @param username 
     * @param rated Game is rated and impacts players ratings
     * @param clockLimit Clock initial time in seconds. If empty, a correspondence game is created.
     * @param clockIncrement Clock increment in seconds. If empty, a correspondence game is created.
     * @param days Days per move, for correspondence games. Clock settings must be omitted.
     * @param color Which color you get to play
     * @param variant 
     * @param fen Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. Castling moves will use UCI_Chess960 notation, for example e1h1 instead of e1g1.
     * @param keepAliveStream If set, the response is streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). The challenge is kept alive until the connection is closed by the client. When the challenge is accepted, declined or canceled, a message of the form &#x60;{\\\&quot;done\\\&quot;:\\\&quot;accepted\\\&quot;}&#x60; is sent, then the connection is closed by the server. If not set, the response is not streamed, and the challenge expires after 20s if not accepted. 
     * @param acceptByToken Immediately accept the challenge and create the game. Pass in an OAuth token (with the &#x60;challenge:write&#x60; scope) for the receiving user. On success, the response will contain a &#x60;game&#x60; field instead of a &#x60;challenge&#x60; field.  Alternatively, consider the [bulk pairing API](#operation/bulkPairingCreate). 
     * @param message **Only if &#x60;acceptByToken&#x60; is set.**  Message that is sent to each player, when the game is created. It is sent from your user account.  &#x60;{opponent}&#x60;, &#x60;{player}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent name, player name, and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder. 
     */
    public async challengeCreate(username: string, rated?: boolean, clockLimit?: number, clockIncrement?: number, days?: number, color?: string, variant?: VariantKey, fen?: string, keepAliveStream?: boolean, acceptByToken?: string, message?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'username' is not null or undefined
        if (username === null || username === undefined) {
            throw new RequiredError("ChallengesApi", "challengeCreate", "username");
        }












        // Path Params
        const localVarPath = '/api/challenge/{username}'
            .replace('{' + 'username' + '}', encodeURIComponent(String(username)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Form Params
        const useForm = canConsumeForm([
            'application/x-www-form-urlencoded',
        ]);

        let localVarFormParams
        if (useForm) {
            localVarFormParams = new FormData();
        } else {
            localVarFormParams = new URLSearchParams();
        }

        if (rated !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('rated', rated as any);
        }
        if (clockLimit !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('clock.limit', clockLimit as any);
        }
        if (clockIncrement !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('clock.increment', clockIncrement as any);
        }
        if (days !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('days', days as any);
        }
        if (color !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('color', color as any);
        }
        if (variant !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('variant', variant as any);
        }
        if (fen !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('fen', fen as any);
        }
        if (keepAliveStream !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('keepAliveStream', keepAliveStream as any);
        }
        if (acceptByToken !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('acceptByToken', acceptByToken as any);
        }
        if (message !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('message', message as any);
        }

        requestContext.setBody(localVarFormParams);

        if(!useForm) {
            const contentType = ObjectSerializer.getPreferredMediaType([
                "application/x-www-form-urlencoded"
            ]);
            requestContext.setHeaderParam("Content-Type", contentType);
        }

        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Decline an incoming challenge. 
     * Decline a challenge
     * @param challengeId 
     * @param reason Reason challenge was declined. It will be translated to the player&#39;s language. See [the full list in the translation file](https://github.com/ornicar/lila/blob/43fbd61029ff3960a21fbd213944bed66325696d/translation/source/challenge.xml#L14).
     */
    public async challengeDecline(challengeId: string, reason?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'challengeId' is not null or undefined
        if (challengeId === null || challengeId === undefined) {
            throw new RequiredError("ChallengesApi", "challengeDecline", "challengeId");
        }



        // Path Params
        const localVarPath = '/api/challenge/{challengeId}/decline'
            .replace('{' + 'challengeId' + '}', encodeURIComponent(String(challengeId)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Form Params
        const useForm = canConsumeForm([
            'application/x-www-form-urlencoded',
        ]);

        let localVarFormParams
        if (useForm) {
            localVarFormParams = new FormData();
        } else {
            localVarFormParams = new URLSearchParams();
        }

        if (reason !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('reason', reason as any);
        }

        requestContext.setBody(localVarFormParams);

        if(!useForm) {
            const contentType = ObjectSerializer.getPreferredMediaType([
                "application/x-www-form-urlencoded"
            ]);
            requestContext.setHeaderParam("Content-Type", contentType);
        }

        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Get a list of challenges created by or targeted at you. 
     * List your challenges
     */
    public async challengeList(_options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // Path Params
        const localVarPath = '/api/challenge';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")


        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Create a challenge that any 2 players can join.  Share the URL of the challenge. the first 2 players to click it will be paired for a game.  The response body also contains `whiteUrl` and `blackUrl`. You can control which color each player gets by giving them these URLs, instead of the main challenge URL.  Open challenges expire after 24h.  To directly pair 2 known players, use [this endpoint](#operation/challengeCreate) instead, with the `acceptByToken` parameter. 
     * Open-ended challenge
     * @param rated Game is rated and impacts players ratings
     * @param clockLimit Clock initial time in seconds. If empty, a correspondence game is created.
     * @param clockIncrement Clock increment in seconds. If empty, a correspondence game is created.
     * @param variant 
     * @param fen Custom initial position (in FEN). Variant must be standard, and the game cannot be rated.
     * @param name Optional name for the challenge, that players will see on the challenge page.
     */
    public async challengeOpen(rated?: boolean, clockLimit?: number, clockIncrement?: number, variant?: VariantKey, fen?: string, name?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;







        // Path Params
        const localVarPath = '/api/challenge/open';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Form Params
        const useForm = canConsumeForm([
            'application/x-www-form-urlencoded',
        ]);

        let localVarFormParams
        if (useForm) {
            localVarFormParams = new FormData();
        } else {
            localVarFormParams = new URLSearchParams();
        }

        if (rated !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('rated', rated as any);
        }
        if (clockLimit !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('clock.limit', clockLimit as any);
        }
        if (clockIncrement !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('clock.increment', clockIncrement as any);
        }
        if (variant !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('variant', variant as any);
        }
        if (fen !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('fen', fen as any);
        }
        if (name !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('name', name as any);
        }

        requestContext.setBody(localVarFormParams);

        if(!useForm) {
            const contentType = ObjectSerializer.getPreferredMediaType([
                "application/x-www-form-urlencoded"
            ]);
            requestContext.setHeaderParam("Content-Type", contentType);
        }


        return requestContext;
    }

    /**
     * Start the clocks of a game immediately, even if a player has not yet made a move.  Requires the OAuth tokens of both players with `challenge:write` scope.  If the clocks have already started, the call will have no effect. 
     * Start clocks of a game
     * @param gameId 
     * @param token1 OAuth token of a player
     * @param token2 OAuth token of the other player
     */
    public async challengeStartClocks(gameId: string, token1?: string, token2?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'gameId' is not null or undefined
        if (gameId === null || gameId === undefined) {
            throw new RequiredError("ChallengesApi", "challengeStartClocks", "gameId");
        }




        // Path Params
        const localVarPath = '/api/challenge/{gameId}/start-clocks'
            .replace('{' + 'gameId' + '}', encodeURIComponent(String(gameId)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (token1 !== undefined) {
            requestContext.setQueryParam("token1", ObjectSerializer.serialize(token1, "string", ""));
        }

        // Query Params
        if (token2 !== undefined) {
            requestContext.setQueryParam("token2", ObjectSerializer.serialize(token2, "string", ""));
        }


        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Add seconds to the opponent's clock. Can be used to create games with time odds. 
     * Add time to the opponent clock
     * @param gameId 
     * @param seconds How many seconds to give
     */
    public async roundAddTime(gameId: string, seconds: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'gameId' is not null or undefined
        if (gameId === null || gameId === undefined) {
            throw new RequiredError("ChallengesApi", "roundAddTime", "gameId");
        }


        // verify required parameter 'seconds' is not null or undefined
        if (seconds === null || seconds === undefined) {
            throw new RequiredError("ChallengesApi", "roundAddTime", "seconds");
        }


        // Path Params
        const localVarPath = '/api/round/{gameId}/add-time/{seconds}'
            .replace('{' + 'gameId' + '}', encodeURIComponent(String(gameId)))
            .replace('{' + 'seconds' + '}', encodeURIComponent(String(seconds)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")


        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

}

export class ChallengesApiResponseProcessor {

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to adminChallengeTokens
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async adminChallengeTokens(response: ResponseContext): Promise<void > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            return;
        }
        if (isCodeInRange("400", response.httpStatusCode)) {
            const body: Error = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Error", ""
            ) as Error;
            throw new ApiException<Error>(400, "The creation of the tokens failed.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: void = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "void", ""
            ) as void;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to challengeAccept
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async challengeAccept(response: ResponseContext): Promise<Ok > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }
        if (isCodeInRange("404", response.httpStatusCode)) {
            const body: NotFound = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "NotFound", ""
            ) as NotFound;
            throw new ApiException<NotFound>(404, "The challenge to accept was not found.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to challengeAi
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async challengeAi(response: ResponseContext): Promise<GameJson > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: GameJson = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "GameJson", ""
            ) as GameJson;
            return body;
        }
        if (isCodeInRange("400", response.httpStatusCode)) {
            const body: Error = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Error", ""
            ) as Error;
            throw new ApiException<Error>(400, "The creation of a game with Lichess AI failed.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: GameJson = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "GameJson", ""
            ) as GameJson;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to challengeCancel
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async challengeCancel(response: ResponseContext): Promise<Ok > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }
        if (isCodeInRange("404", response.httpStatusCode)) {
            const body: NotFound = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "NotFound", ""
            ) as NotFound;
            throw new ApiException<NotFound>(404, "The challenge to cancel was not found.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to challengeCreate
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async challengeCreate(response: ResponseContext): Promise<ChallengeJson > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: ChallengeJson = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "ChallengeJson", ""
            ) as ChallengeJson;
            return body;
        }
        if (isCodeInRange("400", response.httpStatusCode)) {
            const body: Error = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Error", ""
            ) as Error;
            throw new ApiException<Error>(400, "The creation of the challenge failed.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: ChallengeJson = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "ChallengeJson", ""
            ) as ChallengeJson;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to challengeDecline
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async challengeDecline(response: ResponseContext): Promise<Ok > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }
        if (isCodeInRange("404", response.httpStatusCode)) {
            const body: NotFound = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "NotFound", ""
            ) as NotFound;
            throw new ApiException<NotFound>(404, "The challenge to decline was not found.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to challengeList
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async challengeList(response: ResponseContext): Promise<InlineResponse2003 > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: InlineResponse2003 = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "InlineResponse2003", ""
            ) as InlineResponse2003;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: InlineResponse2003 = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "InlineResponse2003", ""
            ) as InlineResponse2003;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to challengeOpen
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async challengeOpen(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }
        if (isCodeInRange("400", response.httpStatusCode)) {
            const body: Error = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Error", ""
            ) as Error;
            throw new ApiException<Error>(400, "The creation of the challenge failed.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to challengeStartClocks
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async challengeStartClocks(response: ResponseContext): Promise<Ok > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to roundAddTime
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async roundAddTime(response: ResponseContext): Promise<Ok > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

}
