// TODO: better import syntax?
import { BaseAPIRequestFactory, RequiredError } from './baseapi';
import {Configuration} from '../configuration';
import { RequestContext, HttpMethod, ResponseContext, HttpFile} from '../http/http';
import {ObjectSerializer} from '../models/ObjectSerializer';
import {ApiException} from './exception';
import {canConsumeForm, isCodeInRange} from '../util';


import { Speed } from '../models/Speed';
import { VariantKey } from '../models/VariantKey';

/**
 * no description
 */
export class OpeningExplorerApiRequestFactory extends BaseAPIRequestFactory {

    /**
     * **Endpoint: <https://explorer.lichess.ovh/lichess>**  Games sampled from all Lichess players.  Example: `curl https://explorer.lichess.ovh/lichess?variant=standard&speeds=blitz,rapid,classical&ratings=2200,2500&fen=rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR%20w%20KQkq%20-%200%201` 
     * Lichess games
     * @param variant Variant
     * @param fen FEN of the root position
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position. 
     * @param speeds Comma separated list of game speeds to look for
     * @param ratings Comma separated list of rating groups, ranging from their value to the next higher group
     * @param since Include only games from this month or later
     * @param until Include only games from this month or earlier
     * @param moves Number of most common moves to display
     * @param topGames Number of top games to display
     * @param recentGames Number of recent games to display
     */
    public async openingExplorerLichess(variant?: VariantKey, fen?: string, play?: string, speeds?: Array<Speed>, ratings?: Array<1600 | 1800 | 2000 | 2200 | 2500>, since?: string, until?: string, moves?: number, topGames?: number, recentGames?: number, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;











        // Path Params
        const localVarPath = '/lichess';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (variant !== undefined) {
            requestContext.setQueryParam("variant", ObjectSerializer.serialize(variant, "VariantKey", ""));
        }

        // Query Params
        if (fen !== undefined) {
            requestContext.setQueryParam("fen", ObjectSerializer.serialize(fen, "string", ""));
        }

        // Query Params
        if (play !== undefined) {
            requestContext.setQueryParam("play", ObjectSerializer.serialize(play, "string", ""));
        }

        // Query Params
        if (speeds !== undefined) {
            requestContext.setQueryParam("speeds", ObjectSerializer.serialize(speeds, "Array<Speed>", ""));
        }

        // Query Params
        if (ratings !== undefined) {
            requestContext.setQueryParam("ratings", ObjectSerializer.serialize(ratings, "Array<1600 | 1800 | 2000 | 2200 | 2500>", ""));
        }

        // Query Params
        if (since !== undefined) {
            requestContext.setQueryParam("since", ObjectSerializer.serialize(since, "string", ""));
        }

        // Query Params
        if (until !== undefined) {
            requestContext.setQueryParam("until", ObjectSerializer.serialize(until, "string", ""));
        }

        // Query Params
        if (moves !== undefined) {
            requestContext.setQueryParam("moves", ObjectSerializer.serialize(moves, "number", ""));
        }

        // Query Params
        if (topGames !== undefined) {
            requestContext.setQueryParam("topGames", ObjectSerializer.serialize(topGames, "number", ""));
        }

        // Query Params
        if (recentGames !== undefined) {
            requestContext.setQueryParam("recentGames", ObjectSerializer.serialize(recentGames, "number", ""));
        }



        return requestContext;
    }

    /**
     * **Endpoint: <https://explorer.lichess.ovh/masters>**  Example: `curl https://explorer.lichess.ovh/masters?play=d2d4,d7d5,c2c4,c7c6,c4d5` 
     * Masters database
     * @param fen FEN of the root position
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position. 
     * @param since Include only games from this year or later
     * @param until Include only games from thi year or earlier
     * @param moves Number of most common moves to display
     * @param topGames Number of top games to display
     */
    public async openingExplorerMaster(fen?: string, play?: string, since?: number, until?: number, moves?: number, topGames?: number, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;







        // Path Params
        const localVarPath = '/masters';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (fen !== undefined) {
            requestContext.setQueryParam("fen", ObjectSerializer.serialize(fen, "string", ""));
        }

        // Query Params
        if (play !== undefined) {
            requestContext.setQueryParam("play", ObjectSerializer.serialize(play, "string", ""));
        }

        // Query Params
        if (since !== undefined) {
            requestContext.setQueryParam("since", ObjectSerializer.serialize(since, "number", ""));
        }

        // Query Params
        if (until !== undefined) {
            requestContext.setQueryParam("until", ObjectSerializer.serialize(until, "number", ""));
        }

        // Query Params
        if (moves !== undefined) {
            requestContext.setQueryParam("moves", ObjectSerializer.serialize(moves, "number", ""));
        }

        // Query Params
        if (topGames !== undefined) {
            requestContext.setQueryParam("topGames", ObjectSerializer.serialize(topGames, "number", ""));
        }



        return requestContext;
    }

    /**
     * **Endpoint: `https://explorer.lichess.ovh/masters/pgn/{gameId}`**  Example: `curl https://explorer.lichess.ovh/masters/pgn/aAbqI4ey` 
     * OTB master game
     * @param gameId 
     */
    public async openingExplorerMasterGame(gameId: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'gameId' is not null or undefined
        if (gameId === null || gameId === undefined) {
            throw new RequiredError("OpeningExplorerApi", "openingExplorerMasterGame", "gameId");
        }


        // Path Params
        const localVarPath = '/master/pgn/{gameId}'
            .replace('{' + 'gameId' + '}', encodeURIComponent(String(gameId)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")



        return requestContext;
    }

    /**
     * **Endpoint: <https://explorer.lichess.ovh/player>**  Games of a Lichess player.  Responds with a stream of newline delimited JSON. Will start indexing on demand, immediately respond with the current results, and stream more updates until indexing is complete. The stream is throttled and deduplicated. Empty lines may be sent to avoid timeouts.  Will index new games at most once per minute, and revisit previously ongoing games at most once every day.  Example: `curl https://explorer.lichess.ovh/player?player=revoof&color=white&play=d2d4,d7d5&recentGames=1` 
     * Player games
     * @param variant Variant
     * @param fen FEN of the root position
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position. 
     * @param speeds Comma separated list of game speeds to look for
     * @param modes Comma separated list of modes
     * @param since Include only games from this month or later
     * @param until Include only games from this month or earlier
     * @param moves Number of most common moves to display
     * @param recentGames Number of recent games to display
     */
    public async openingExplorerPlayer(variant?: VariantKey, fen?: string, play?: string, speeds?: Array<Speed>, modes?: Array<'casual' | 'rated'>, since?: string, until?: string, moves?: number, recentGames?: number, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;










        // Path Params
        const localVarPath = '/player?';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (variant !== undefined) {
            requestContext.setQueryParam("variant", ObjectSerializer.serialize(variant, "VariantKey", ""));
        }

        // Query Params
        if (fen !== undefined) {
            requestContext.setQueryParam("fen", ObjectSerializer.serialize(fen, "string", ""));
        }

        // Query Params
        if (play !== undefined) {
            requestContext.setQueryParam("play", ObjectSerializer.serialize(play, "string", ""));
        }

        // Query Params
        if (speeds !== undefined) {
            requestContext.setQueryParam("speeds", ObjectSerializer.serialize(speeds, "Array<Speed>", ""));
        }

        // Query Params
        if (modes !== undefined) {
            requestContext.setQueryParam("modes", ObjectSerializer.serialize(modes, "Array<'casual' | 'rated'>", ""));
        }

        // Query Params
        if (since !== undefined) {
            requestContext.setQueryParam("since", ObjectSerializer.serialize(since, "string", ""));
        }

        // Query Params
        if (until !== undefined) {
            requestContext.setQueryParam("until", ObjectSerializer.serialize(until, "string", ""));
        }

        // Query Params
        if (moves !== undefined) {
            requestContext.setQueryParam("moves", ObjectSerializer.serialize(moves, "number", ""));
        }

        // Query Params
        if (recentGames !== undefined) {
            requestContext.setQueryParam("recentGames", ObjectSerializer.serialize(recentGames, "number", ""));
        }



        return requestContext;
    }

}

export class OpeningExplorerApiResponseProcessor {

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to openingExplorerLichess
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async openingExplorerLichess(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to openingExplorerMaster
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async openingExplorerMaster(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to openingExplorerMasterGame
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async openingExplorerMasterGame(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to openingExplorerPlayer
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async openingExplorerPlayer(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

}
