// TODO: better import syntax?
import { BaseAPIRequestFactory, RequiredError } from './baseapi';
import {Configuration} from '../configuration';
import { RequestContext, HttpMethod, ResponseContext, HttpFile} from '../http/http';
import {ObjectSerializer} from '../models/ObjectSerializer';
import {ApiException} from './exception';
import {canConsumeForm, isCodeInRange} from '../util';


import { Ok } from '../models/Ok';
import { SwissUnauthorisedEdit } from '../models/SwissUnauthorisedEdit';
import { VariantKey } from '../models/VariantKey';

/**
 * no description
 */
export class SwissTournamentsApiRequestFactory extends BaseAPIRequestFactory {

    /**
     * Join a Swiss tournament, possibly with a password. 
     * Join a Swiss tournament
     * @param id The tournament ID.
     * @param password The tournament password, if one is required
     */
    public async apiSwissJoin(id: string, password?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new RequiredError("SwissTournamentsApi", "apiSwissJoin", "id");
        }



        // Path Params
        const localVarPath = '/api/swiss/{id}/join'
            .replace('{' + 'id' + '}', encodeURIComponent(String(id)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Form Params
        const useForm = canConsumeForm([
            'application/x-www-form-urlencoded',
        ]);

        let localVarFormParams
        if (useForm) {
            localVarFormParams = new FormData();
        } else {
            localVarFormParams = new URLSearchParams();
        }

        if (password !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('password', password as any);
        }

        requestContext.setBody(localVarFormParams);

        if(!useForm) {
            const contentType = ObjectSerializer.getPreferredMediaType([
                "application/x-www-form-urlencoded"
            ]);
            requestContext.setHeaderParam("Content-Type", contentType);
        }

        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Create a Swiss tournament for your team.  This endpoint mirrors the Swiss tournament form from your team pagee.  You can create up to 12 tournaments per day. 
     * Create a new Swiss tournament
     * @param teamId ID of the team
     * @param clockLimit Clock initial time in seconds
     * @param clockIncrement Clock increment in seconds
     * @param nbRounds Maximum number of rounds to play
     * @param name The tournament name. Leave empty to get a random Grandmaster name
     * @param startsAt Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation.
     * @param roundInterval How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI. 
     * @param variant 
     * @param description Anything you want to tell players about the tournament
     * @param rated Games are rated and impact players ratings
     * @param chatFor Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players 
     */
    public async apiSwissNew(teamId: string, clockLimit: number, clockIncrement: number, nbRounds: number, name?: string, startsAt?: number, roundInterval?: number, variant?: VariantKey, description?: string, rated?: boolean, chatFor?: number, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'teamId' is not null or undefined
        if (teamId === null || teamId === undefined) {
            throw new RequiredError("SwissTournamentsApi", "apiSwissNew", "teamId");
        }


        // verify required parameter 'clockLimit' is not null or undefined
        if (clockLimit === null || clockLimit === undefined) {
            throw new RequiredError("SwissTournamentsApi", "apiSwissNew", "clockLimit");
        }


        // verify required parameter 'clockIncrement' is not null or undefined
        if (clockIncrement === null || clockIncrement === undefined) {
            throw new RequiredError("SwissTournamentsApi", "apiSwissNew", "clockIncrement");
        }


        // verify required parameter 'nbRounds' is not null or undefined
        if (nbRounds === null || nbRounds === undefined) {
            throw new RequiredError("SwissTournamentsApi", "apiSwissNew", "nbRounds");
        }









        // Path Params
        const localVarPath = '/api/swiss/new/{teamId}'
            .replace('{' + 'teamId' + '}', encodeURIComponent(String(teamId)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Form Params
        const useForm = canConsumeForm([
            'application/x-www-form-urlencoded',
        ]);

        let localVarFormParams
        if (useForm) {
            localVarFormParams = new FormData();
        } else {
            localVarFormParams = new URLSearchParams();
        }

        if (name !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('name', name as any);
        }
        if (clockLimit !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('clock.limit', clockLimit as any);
        }
        if (clockIncrement !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('clock.increment', clockIncrement as any);
        }
        if (nbRounds !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('nbRounds', nbRounds as any);
        }
        if (startsAt !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('startsAt', startsAt as any);
        }
        if (roundInterval !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('roundInterval', roundInterval as any);
        }
        if (variant !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('variant', variant as any);
        }
        if (description !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('description', description as any);
        }
        if (rated !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('rated', rated as any);
        }
        if (chatFor !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('chatFor', chatFor as any);
        }

        requestContext.setBody(localVarFormParams);

        if(!useForm) {
            const contentType = ObjectSerializer.getPreferredMediaType([
                "application/x-www-form-urlencoded"
            ]);
            requestContext.setHeaderParam("Content-Type", contentType);
        }

        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Terminate a Swiss tournament 
     * Terminate a Swiss tournament
     * @param id The Swiss tournament ID.
     */
    public async apiSwissTerminate(id: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new RequiredError("SwissTournamentsApi", "apiSwissTerminate", "id");
        }


        // Path Params
        const localVarPath = '/api/swiss/{id}/terminate'
            .replace('{' + 'id' + '}', encodeURIComponent(String(id)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")


        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Update a Swiss tournament.  Be mindful not to make important changes to ongoing tournaments. 
     * Update a Swiss tournament.
     * @param id The tournament ID.
     * @param clockLimit Clock initial time in seconds
     * @param clockIncrement Clock increment in seconds
     * @param nbRounds Maximum number of rounds to play
     * @param name The tournament name. Leave empty to get a random Grandmaster name
     * @param startsAt Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation.
     * @param roundInterval How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI. 
     * @param variant 
     * @param description Anything you want to tell players about the tournament
     * @param rated Games are rated and impact players ratings
     * @param chatFor Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players 
     */
    public async apiSwissUpdate(id: string, clockLimit: number, clockIncrement: number, nbRounds: number, name?: string, startsAt?: number, roundInterval?: number, variant?: VariantKey, description?: string, rated?: boolean, chatFor?: number, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new RequiredError("SwissTournamentsApi", "apiSwissUpdate", "id");
        }


        // verify required parameter 'clockLimit' is not null or undefined
        if (clockLimit === null || clockLimit === undefined) {
            throw new RequiredError("SwissTournamentsApi", "apiSwissUpdate", "clockLimit");
        }


        // verify required parameter 'clockIncrement' is not null or undefined
        if (clockIncrement === null || clockIncrement === undefined) {
            throw new RequiredError("SwissTournamentsApi", "apiSwissUpdate", "clockIncrement");
        }


        // verify required parameter 'nbRounds' is not null or undefined
        if (nbRounds === null || nbRounds === undefined) {
            throw new RequiredError("SwissTournamentsApi", "apiSwissUpdate", "nbRounds");
        }









        // Path Params
        const localVarPath = '/api/swiss/{id}/edit'
            .replace('{' + 'id' + '}', encodeURIComponent(String(id)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Form Params
        const useForm = canConsumeForm([
            'application/x-www-form-urlencoded',
        ]);

        let localVarFormParams
        if (useForm) {
            localVarFormParams = new FormData();
        } else {
            localVarFormParams = new URLSearchParams();
        }

        if (name !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('name', name as any);
        }
        if (clockLimit !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('clock.limit', clockLimit as any);
        }
        if (clockIncrement !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('clock.increment', clockIncrement as any);
        }
        if (nbRounds !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('nbRounds', nbRounds as any);
        }
        if (startsAt !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('startsAt', startsAt as any);
        }
        if (roundInterval !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('roundInterval', roundInterval as any);
        }
        if (variant !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('variant', variant as any);
        }
        if (description !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('description', description as any);
        }
        if (rated !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('rated', rated as any);
        }
        if (chatFor !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('chatFor', chatFor as any);
        }

        requestContext.setBody(localVarFormParams);

        if(!useForm) {
            const contentType = ObjectSerializer.getPreferredMediaType([
                "application/x-www-form-urlencoded"
            ]);
            requestContext.setHeaderParam("Content-Type", contentType);
        }

        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Get all swiss tournaments of a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get team swiss tournaments
     * @param teamId 
     * @param max How many tournaments to download.
     */
    public async apiTeamSwiss(teamId: string, max?: number, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'teamId' is not null or undefined
        if (teamId === null || teamId === undefined) {
            throw new RequiredError("SwissTournamentsApi", "apiTeamSwiss", "teamId");
        }



        // Path Params
        const localVarPath = '/api/team/{teamId}/swiss'
            .replace('{' + 'teamId' + '}', encodeURIComponent(String(teamId)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (max !== undefined) {
            requestContext.setQueryParam("max", ObjectSerializer.serialize(max, "number", ""));
        }



        return requestContext;
    }

    /**
     * Download games of a swiss tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (last round first) 
     * Export games of a Swiss tournament
     * @param id The tournament ID.
     * @param moves Include the PGN moves.
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @param tags Include the PGN tags.
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     */
    public async gamesBySwiss(id: string, moves?: boolean, pgnInJson?: boolean, tags?: boolean, clocks?: boolean, evals?: boolean, opening?: boolean, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new RequiredError("SwissTournamentsApi", "gamesBySwiss", "id");
        }








        // Path Params
        const localVarPath = '/api/swiss/{id}/games'
            .replace('{' + 'id' + '}', encodeURIComponent(String(id)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (moves !== undefined) {
            requestContext.setQueryParam("moves", ObjectSerializer.serialize(moves, "boolean", ""));
        }

        // Query Params
        if (pgnInJson !== undefined) {
            requestContext.setQueryParam("pgnInJson", ObjectSerializer.serialize(pgnInJson, "boolean", ""));
        }

        // Query Params
        if (tags !== undefined) {
            requestContext.setQueryParam("tags", ObjectSerializer.serialize(tags, "boolean", ""));
        }

        // Query Params
        if (clocks !== undefined) {
            requestContext.setQueryParam("clocks", ObjectSerializer.serialize(clocks, "boolean", ""));
        }

        // Query Params
        if (evals !== undefined) {
            requestContext.setQueryParam("evals", ObjectSerializer.serialize(evals, "boolean", ""));
        }

        // Query Params
        if (opening !== undefined) {
            requestContext.setQueryParam("opening", ObjectSerializer.serialize(opening, "boolean", ""));
        }



        return requestContext;
    }

    /**
     * Players of a swiss tournament, with their score and performance, sorted by rank (best first).  Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 
     * Get results of a swiss tournament
     * @param id The tournament ID.
     * @param nb Max number of players to fetch
     */
    public async resultsBySwiss(id: string, nb?: number, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new RequiredError("SwissTournamentsApi", "resultsBySwiss", "id");
        }



        // Path Params
        const localVarPath = '/api/swiss/{id}/results'
            .replace('{' + 'id' + '}', encodeURIComponent(String(id)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (nb !== undefined) {
            requestContext.setQueryParam("nb", ObjectSerializer.serialize(nb, "number", ""));
        }



        return requestContext;
    }

    /**
     * Download a tournament in the Tournament Report File format, the FIDE standard.  Documentation: <https://www.fide.com/FIDE/handbook/C04Annex2_TRF16.pdf>  Example: <https://lichess.org/swiss/j8rtJ5GL.trf> 
     * Export TRF of a Swiss tournament
     * @param id The tournament ID.
     */
    public async swissTrf(id: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new RequiredError("SwissTournamentsApi", "swissTrf", "id");
        }


        // Path Params
        const localVarPath = '/swiss/{id}.trf'
            .replace('{' + 'id' + '}', encodeURIComponent(String(id)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")



        return requestContext;
    }

}

export class SwissTournamentsApiResponseProcessor {

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiSwissJoin
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiSwissJoin(response: ResponseContext): Promise<Ok > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }
        if (isCodeInRange("400", response.httpStatusCode)) {
            const body: Error = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Error", ""
            ) as Error;
            throw new ApiException<Error>(400, "Joining the tournament failed.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiSwissNew
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiSwissNew(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }
        if (isCodeInRange("400", response.httpStatusCode)) {
            const body: Error = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Error", ""
            ) as Error;
            throw new ApiException<Error>(400, "The creation of the Swiss tournament failed.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiSwissTerminate
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiSwissTerminate(response: ResponseContext): Promise<Ok > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }
        if (isCodeInRange("400", response.httpStatusCode)) {
            const body: Error = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Error", ""
            ) as Error;
            throw new ApiException<Error>(400, "Terminating the Swiss tournament failed.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiSwissUpdate
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiSwissUpdate(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }
        if (isCodeInRange("400", response.httpStatusCode)) {
            const body: Error = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Error", ""
            ) as Error;
            throw new ApiException<Error>(400, "Updating the swiss failed.", body, response.headers);
        }
        if (isCodeInRange("401", response.httpStatusCode)) {
            const body: SwissUnauthorisedEdit = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "SwissUnauthorisedEdit", ""
            ) as SwissUnauthorisedEdit;
            throw new ApiException<SwissUnauthorisedEdit>(401, "This user cannot update this Swiss.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiTeamSwiss
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiTeamSwiss(response: ResponseContext): Promise<Array<any> > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: Array<any> = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Array<any>", ""
            ) as Array<any>;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: Array<any> = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Array<any>", ""
            ) as Array<any>;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to gamesBySwiss
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async gamesBySwiss(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to resultsBySwiss
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async resultsBySwiss(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to swissTrf
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async swissTrf(response: ResponseContext): Promise<string > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: string = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "string", ""
            ) as string;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: string = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "string", ""
            ) as string;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

}
