// TODO: better import syntax?
import { BaseAPIRequestFactory, RequiredError } from './baseapi';
import {Configuration} from '../configuration';
import { RequestContext, HttpMethod, ResponseContext, HttpFile} from '../http/http';
import {ObjectSerializer} from '../models/ObjectSerializer';
import {ApiException} from './exception';
import {canConsumeForm, isCodeInRange} from '../util';



/**
 * no description
 */
export class TVApiRequestFactory extends BaseAPIRequestFactory {

    /**
     * Get a list of ongoing games for a given TV channel. Similar to [lichess.org/games](https://lichess.org/games).  Available in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format, depending on the request Accept header. 
     * Get best ongoing games of a TV channel
     * @param channel The name of the channel in lowercase.
     * @param nb Number of games to fetch.
     * @param moves Include the PGN moves.
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @param tags Include the PGN tags.
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     */
    public async tvChannelGames(channel: string, nb?: number, moves?: boolean, pgnInJson?: boolean, tags?: boolean, clocks?: boolean, opening?: boolean, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'channel' is not null or undefined
        if (channel === null || channel === undefined) {
            throw new RequiredError("TVApi", "tvChannelGames", "channel");
        }








        // Path Params
        const localVarPath = '/api/tv/{channel}'
            .replace('{' + 'channel' + '}', encodeURIComponent(String(channel)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (nb !== undefined) {
            requestContext.setQueryParam("nb", ObjectSerializer.serialize(nb, "number", ""));
        }

        // Query Params
        if (moves !== undefined) {
            requestContext.setQueryParam("moves", ObjectSerializer.serialize(moves, "boolean", ""));
        }

        // Query Params
        if (pgnInJson !== undefined) {
            requestContext.setQueryParam("pgnInJson", ObjectSerializer.serialize(pgnInJson, "boolean", ""));
        }

        // Query Params
        if (tags !== undefined) {
            requestContext.setQueryParam("tags", ObjectSerializer.serialize(tags, "boolean", ""));
        }

        // Query Params
        if (clocks !== undefined) {
            requestContext.setQueryParam("clocks", ObjectSerializer.serialize(clocks, "boolean", ""));
        }

        // Query Params
        if (opening !== undefined) {
            requestContext.setQueryParam("opening", ObjectSerializer.serialize(opening, "boolean", ""));
        }



        return requestContext;
    }

    /**
     * Get basic info about the best games being played for each speed and variant, but also computer games and bot games.  See [lichess.org/tv](https://lichess.org/tv). 
     * Get current TV games
     */
    public async tvChannels(_options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // Path Params
        const localVarPath = '/api/tv/channels';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")



        return requestContext;
    }

    /**
     * Stream positions and moves of the current [TV game](https://lichess.org/tv) in [ndjson](#section/Introduction/Streaming-with-ND-JSON). A summary of the game is sent as a first message, and when the featured game changes.  Try it with `curl https://lichess.org/api/tv/feed`. 
     * Stream current TV game
     */
    public async tvFeed(_options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // Path Params
        const localVarPath = '/api/tv/feed';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")



        return requestContext;
    }

}

export class TVApiResponseProcessor {

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to tvChannelGames
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async tvChannelGames(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to tvChannels
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async tvChannels(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to tvFeed
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async tvFeed(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

}
