import { ResponseContext, RequestContext, HttpFile } from '../http/http';
import * as models from '../models/all';
import { Configuration} from '../configuration'

import { ApiStreamEvent } from '../models/ApiStreamEvent';
import { ArenaTournaments } from '../models/ArenaTournaments';
import { ChallengeCanceledEvent } from '../models/ChallengeCanceledEvent';
import { ChallengeDeclinedEvent } from '../models/ChallengeDeclinedEvent';
import { ChallengeEvent } from '../models/ChallengeEvent';
import { ChallengeJson } from '../models/ChallengeJson';
import { ChallengeJsonPerf } from '../models/ChallengeJsonPerf';
import { ChallengeUser } from '../models/ChallengeUser';
import { ChatLineEvent } from '../models/ChatLineEvent';
import { Clock } from '../models/Clock';
import { Count } from '../models/Count';
import { GameEventInfo } from '../models/GameEventInfo';
import { GameEventInfoCompat } from '../models/GameEventInfoCompat';
import { GameEventPlayer } from '../models/GameEventPlayer';
import { GameFinishEvent } from '../models/GameFinishEvent';
import { GameFullEvent } from '../models/GameFullEvent';
import { GameFullEventPerf } from '../models/GameFullEventPerf';
import { GameJson } from '../models/GameJson';
import { GameJsonAnalysis } from '../models/GameJsonAnalysis';
import { GameJsonClock } from '../models/GameJsonClock';
import { GameJsonJudgment } from '../models/GameJsonJudgment';
import { GameJsonOpening } from '../models/GameJsonOpening';
import { GameJsonPlayers } from '../models/GameJsonPlayers';
import { GameStartEvent } from '../models/GameStartEvent';
import { GameStateEvent } from '../models/GameStateEvent';
import { GameStatus } from '../models/GameStatus';
import { GameStreamEvent } from '../models/GameStreamEvent';
import { GameUser } from '../models/GameUser';
import { GameUserAnalysis } from '../models/GameUserAnalysis';
import { InlineResponse200 } from '../models/InlineResponse200';
import { InlineResponse2001 } from '../models/InlineResponse2001';
import { InlineResponse2002 } from '../models/InlineResponse2002';
import { InlineResponse2003 } from '../models/InlineResponse2003';
import { LightUser } from '../models/LightUser';
import { ModelError } from '../models/ModelError';
import { Move } from '../models/Move';
import { NotFound } from '../models/NotFound';
import { Ok } from '../models/Ok';
import { Perf } from '../models/Perf';
import { PerfType } from '../models/PerfType';
import { Perfs } from '../models/Perfs';
import { PlayTime } from '../models/PlayTime';
import { Profile } from '../models/Profile';
import { PuzzleRoundJson } from '../models/PuzzleRoundJson';
import { Speed } from '../models/Speed';
import { StormPerf } from '../models/StormPerf';
import { SwissUnauthorisedEdit } from '../models/SwissUnauthorisedEdit';
import { TablebaseJson } from '../models/TablebaseJson';
import { Team } from '../models/Team';
import { TimeControl } from '../models/TimeControl';
import { TimeControlClock } from '../models/TimeControlClock';
import { TimeControlClockAllOf } from '../models/TimeControlClockAllOf';
import { TimeControlCorrespondence } from '../models/TimeControlCorrespondence';
import { TimeControlCorrespondenceAllOf } from '../models/TimeControlCorrespondenceAllOf';
import { TimeControlUnlimited } from '../models/TimeControlUnlimited';
import { Title } from '../models/Title';
import { User } from '../models/User';
import { UserExtended } from '../models/UserExtended';
import { UserExtendedAllOf } from '../models/UserExtendedAllOf';
import { UserPreferences } from '../models/UserPreferences';
import { Variant } from '../models/Variant';
import { VariantKey } from '../models/VariantKey';

import { ObservableAccountApi } from "./ObservableAPI";
import { AccountApiRequestFactory, AccountApiResponseProcessor} from "../apis/AccountApi";

export interface AccountApiAccountRequest {
}

export interface AccountApiAccountEmailRequest {
}

export interface AccountApiAccountKidRequest {
}

export interface AccountApiAccountKidPostRequest {
    /**
     * Kid mode status
     * @type boolean
     * @memberof AccountApiaccountKidPost
     */
    v: boolean
}

export interface AccountApiAccountMeRequest {
}

export class ObjectAccountApi {
    private api: ObservableAccountApi

    public constructor(configuration: Configuration, requestFactory?: AccountApiRequestFactory, responseProcessor?: AccountApiResponseProcessor) {
        this.api = new ObservableAccountApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Read the preferences of the logged in user.  - <https://lichess.org/account/preferences/game-display> - <https://github.com/ornicar/lila/blob/master/modules/pref/src/main/Pref.scala> 
     * Get my preferences
     * @param param the request object
     */
    public account(param: AccountApiAccountRequest, options?: Configuration): Promise<any> {
        return this.api.account( options).toPromise();
    }

    /**
     * Read the email address of the logged in user. 
     * Get my email address
     * @param param the request object
     */
    public accountEmail(param: AccountApiAccountEmailRequest, options?: Configuration): Promise<any> {
        return this.api.accountEmail( options).toPromise();
    }

    /**
     * Read the kid mode status of the logged in user.  - <https://lichess.org/account/kid> 
     * Get my kid mode status
     * @param param the request object
     */
    public accountKid(param: AccountApiAccountKidRequest, options?: Configuration): Promise<any> {
        return this.api.accountKid( options).toPromise();
    }

    /**
     * Set the kid mode status of the logged in user.  - <https://lichess.org/account/kid> 
     * Set my kid mode status
     * @param param the request object
     */
    public accountKidPost(param: AccountApiAccountKidPostRequest, options?: Configuration): Promise<Ok> {
        return this.api.accountKidPost(param.v,  options).toPromise();
    }

    /**
     * Public informations about the logged in user. 
     * Get my profile
     * @param param the request object
     */
    public accountMe(param: AccountApiAccountMeRequest, options?: Configuration): Promise<UserExtended> {
        return this.api.accountMe( options).toPromise();
    }

}

import { ObservableAnalysisApi } from "./ObservableAPI";
import { AnalysisApiRequestFactory, AnalysisApiResponseProcessor} from "../apis/AnalysisApi";

export interface AnalysisApiApiCloudEvalRequest {
    /**
     * FEN of the position
     * @type string
     * @memberof AnalysisApiapiCloudEval
     */
    fen: string
    /**
     * Number of variations
     * @type number
     * @memberof AnalysisApiapiCloudEval
     */
    multiPv?: number
    /**
     * Variant
     * @type VariantKey
     * @memberof AnalysisApiapiCloudEval
     */
    variant?: VariantKey
}

export class ObjectAnalysisApi {
    private api: ObservableAnalysisApi

    public constructor(configuration: Configuration, requestFactory?: AnalysisApiRequestFactory, responseProcessor?: AnalysisApiResponseProcessor) {
        this.api = new ObservableAnalysisApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Get the cached evaluation of a position, if available.  Opening positions have more chances of being available. There are about 7 million positions in the database.  Up to 5 variations may be available. Variants are supported. 
     * Get cloud evaluation of a position.
     * @param param the request object
     */
    public apiCloudEval(param: AnalysisApiApiCloudEvalRequest, options?: Configuration): Promise<void> {
        return this.api.apiCloudEval(param.fen, param.multiPv, param.variant,  options).toPromise();
    }

}

import { ObservableArenaTournamentsApi } from "./ObservableAPI";
import { ArenaTournamentsApiRequestFactory, ArenaTournamentsApiResponseProcessor} from "../apis/ArenaTournamentsApi";

export interface ArenaTournamentsApiApiTeamArenaRequest {
    /**
     * ID of the team
     * @type string
     * @memberof ArenaTournamentsApiapiTeamArena
     */
    teamId: string
    /**
     * How many tournaments to download.
     * @type number
     * @memberof ArenaTournamentsApiapiTeamArena
     */
    max?: number
}

export interface ArenaTournamentsApiApiTournamentRequest {
}

export interface ArenaTournamentsApiApiTournamentJoinRequest {
    /**
     * The tournament ID.
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentJoin
     */
    id: string
    /**
     * The tournament password, if one is required
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentJoin
     */
    password?: string
    /**
     * The team to join the tournament with, for team battle tournaments
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentJoin
     */
    team?: string
}

export interface ArenaTournamentsApiApiTournamentPostRequest {
    /**
     * Clock initial time in minutes
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    clockTime: number
    /**
     * Clock increment in seconds
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    clockIncrement: number
    /**
     * How long the tournament lasts, in minutes
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    minutes: number
    /**
     * The tournament name. Leave empty to get a random Grandmaster name
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    name?: string
    /**
     * How long to wait before starting the tournament, from now, in minutes
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    waitMinutes?: number
    /**
     * Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    startDate?: number
    /**
     * 
     * @type VariantKey
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    variant?: VariantKey
    /**
     * Games are rated and impact players ratings
     * @type boolean
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    rated?: boolean
    /**
     * Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960).
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    position?: string
    /**
     * Whether the players can use berserk
     * @type boolean
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    berserkable?: boolean
    /**
     * After 2 wins, consecutive wins grant 4 points instead of 2.
     * @type boolean
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    streakable?: boolean
    /**
     * Whether the players can discuss in a chat
     * @type boolean
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    hasChat?: boolean
    /**
     * Anything you want to tell players about the tournament
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    description?: string
    /**
     * Make the tournament private, and restrict access with a password
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    password?: string
    /**
     * Set the ID of a team you lead to create a team battle. The other teams can be added using the [team battle edit endpoint](#operation/apiTournamentTeamBattlePost). 
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    teambBattleByTeam?: string
    /**
     * Restrict entry to members of a team.  The teamId is the last part of a team URL, e.g. &#x60;https://lichess.org/team/coders&#x60; has teamId &#x3D; &#x60;coders&#x60;.  Leave empty to let everyone join the tournament.  Do not use this to create team battles, use &#x60;teamBattleByTeam&#x60; instead. 
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    conditionsTeamMemberTeamId?: string
    /**
     * Minimum rating to join. Leave empty to let everyone join the tournament.
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    conditionsMinRatingRating?: number
    /**
     * Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament.
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    conditionsMaxRatingRating?: number
    /**
     * Minimum number of rated games required to join.
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentPost
     */
    conditionsNbRatedGameNb?: number
}

export interface ArenaTournamentsApiApiTournamentTeamBattlePostRequest {
    /**
     * The tournament ID (8 characters)..
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentTeamBattlePost
     */
    id: string
    /**
     * All team IDs of the team battle, separated by commas. Make sure to always send the full list. Teams that are not in the list will be removed from the team battle.  Example: &#x60;coders,zhigalko_sergei-fan-club,hhSwTKZv&#x60; 
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentTeamBattlePost
     */
    teams: string
    /**
     * Number team leaders per team.
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentTeamBattlePost
     */
    nbLeaders: number
}

export interface ArenaTournamentsApiApiTournamentTerminateRequest {
    /**
     * The tournament ID.
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentTerminate
     */
    id: string
}

export interface ArenaTournamentsApiApiTournamentUpdateRequest {
    /**
     * The tournament ID.
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    id: string
    /**
     * Clock initial time in minutes
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    clockTime: number
    /**
     * Clock increment in seconds
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    clockIncrement: number
    /**
     * How long the tournament lasts, in minutes
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    minutes: number
    /**
     * The tournament name. Leave empty to get a random Grandmaster name
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    name?: string
    /**
     * How long to wait before starting the tournament, from now, in minutes
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    waitMinutes?: number
    /**
     * Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    startDate?: number
    /**
     * 
     * @type VariantKey
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    variant?: VariantKey
    /**
     * Games are rated and impact players ratings
     * @type boolean
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    rated?: boolean
    /**
     * Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960).
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    position?: string
    /**
     * Whether the players can use berserk
     * @type boolean
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    berserkable?: boolean
    /**
     * After 2 wins, consecutive wins grant 4 points instead of 2.
     * @type boolean
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    streakable?: boolean
    /**
     * Whether the players can discuss in a chat
     * @type boolean
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    hasChat?: boolean
    /**
     * Anything you want to tell players about the tournament
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    description?: string
    /**
     * Make the tournament private, and restrict access with a password
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    password?: string
    /**
     * Minimum rating to join. Leave empty to let everyone join the tournament.
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    conditionsMinRatingRating?: number
    /**
     * Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament.
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    conditionsMaxRatingRating?: number
    /**
     * Minimum number of rated games required to join.
     * @type number
     * @memberof ArenaTournamentsApiapiTournamentUpdate
     */
    conditionsNbRatedGameNb?: number
}

export interface ArenaTournamentsApiApiTournamentWithdrawRequest {
    /**
     * The tournament ID.
     * @type string
     * @memberof ArenaTournamentsApiapiTournamentWithdraw
     */
    id: string
}

export interface ArenaTournamentsApiApiUserNameTournamentCreatedRequest {
    /**
     * The user whose created tournaments to fetch
     * @type string
     * @memberof ArenaTournamentsApiapiUserNameTournamentCreated
     */
    username: string
    /**
     * Include tournaments in the given status: \&quot;Created\&quot; (10), \&quot;Started\&quot; (20), \&quot;Finished\&quot; (30)  You can add this parameter more than once to include tournaments in different statuses.   Example: &#x60;?status&#x3D;10&amp;status&#x3D;20&#x60; 
     * @type 10 | 20 | 30
     * @memberof ArenaTournamentsApiapiUserNameTournamentCreated
     */
    status?: 10 | 20 | 30
}

export interface ArenaTournamentsApiGamesByTournamentRequest {
    /**
     * The tournament ID.
     * @type string
     * @memberof ArenaTournamentsApigamesByTournament
     */
    id: string
    /**
     * Only games of a particular player. Leave empty to fetch games of all players.
     * @type string
     * @memberof ArenaTournamentsApigamesByTournament
     */
    player?: string
    /**
     * Include the PGN moves.
     * @type boolean
     * @memberof ArenaTournamentsApigamesByTournament
     */
    moves?: boolean
    /**
     * Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @type boolean
     * @memberof ArenaTournamentsApigamesByTournament
     */
    pgnInJson?: boolean
    /**
     * Include the PGN tags.
     * @type boolean
     * @memberof ArenaTournamentsApigamesByTournament
     */
    tags?: boolean
    /**
     * Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @type boolean
     * @memberof ArenaTournamentsApigamesByTournament
     */
    clocks?: boolean
    /**
     * Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @type boolean
     * @memberof ArenaTournamentsApigamesByTournament
     */
    evals?: boolean
    /**
     * Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     * @type boolean
     * @memberof ArenaTournamentsApigamesByTournament
     */
    opening?: boolean
}

export interface ArenaTournamentsApiResultsByTournamentRequest {
    /**
     * The tournament ID.
     * @type string
     * @memberof ArenaTournamentsApiresultsByTournament
     */
    id: string
    /**
     * Max number of players to fetch
     * @type number
     * @memberof ArenaTournamentsApiresultsByTournament
     */
    nb?: number
}

export interface ArenaTournamentsApiTeamsByTournamentRequest {
    /**
     * The tournament ID.
     * @type string
     * @memberof ArenaTournamentsApiteamsByTournament
     */
    id: string
}

export interface ArenaTournamentsApiTournamentRequest {
    /**
     * The tournament ID.
     * @type string
     * @memberof ArenaTournamentsApitournament
     */
    id: string
    /**
     * Specify which page of player standings to view.
     * @type number
     * @memberof ArenaTournamentsApitournament
     */
    page?: number
}

export class ObjectArenaTournamentsApi {
    private api: ObservableArenaTournamentsApi

    public constructor(configuration: Configuration, requestFactory?: ArenaTournamentsApiRequestFactory, responseProcessor?: ArenaTournamentsApiResponseProcessor) {
        this.api = new ObservableArenaTournamentsApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get team Arena tournaments
     * @param param the request object
     */
    public apiTeamArena(param: ArenaTournamentsApiApiTeamArenaRequest, options?: Configuration): Promise<Array<any>> {
        return this.api.apiTeamArena(param.teamId, param.max,  options).toPromise();
    }

    /**
     * Get recently finished, ongoing, and upcoming tournaments.  This API is used to display the [Lichess tournament schedule](https://lichess.org/tournament). 
     * Get current tournaments
     * @param param the request object
     */
    public apiTournament(param: ArenaTournamentsApiApiTournamentRequest, options?: Configuration): Promise<ArenaTournaments> {
        return this.api.apiTournament( options).toPromise();
    }

    /**
     * Join an Arena tournament, possibly with a password and/or a team. 
     * Join an Arena tournament
     * @param param the request object
     */
    public apiTournamentJoin(param: ArenaTournamentsApiApiTournamentJoinRequest, options?: Configuration): Promise<Ok> {
        return this.api.apiTournamentJoin(param.id, param.password, param.team,  options).toPromise();
    }

    /**
     * Create a public or private Arena tournament.  This endpoint mirrors the form on <https://lichess.org/tournament/new>.  You can create up to 12 public tournaments per day, or 24 private tournaments.  A team battle can be created by specifying the `teambBattleByTeam` argument. 
     * Create a new Arena tournament
     * @param param the request object
     */
    public apiTournamentPost(param: ArenaTournamentsApiApiTournamentPostRequest, options?: Configuration): Promise<any> {
        return this.api.apiTournamentPost(param.clockTime, param.clockIncrement, param.minutes, param.name, param.waitMinutes, param.startDate, param.variant, param.rated, param.position, param.berserkable, param.streakable, param.hasChat, param.description, param.password, param.teambBattleByTeam, param.conditionsTeamMemberTeamId, param.conditionsMinRatingRating, param.conditionsMaxRatingRating, param.conditionsNbRatedGameNb,  options).toPromise();
    }

    /**
     * Set the teams and number of leaders of a team battle.  To update the other attributes of a team battle, use the [tournament update endpoint](#operation/apiTournamentUpdate). 
     * Update a team battle
     * @param param the request object
     */
    public apiTournamentTeamBattlePost(param: ArenaTournamentsApiApiTournamentTeamBattlePostRequest, options?: Configuration): Promise<any> {
        return this.api.apiTournamentTeamBattlePost(param.id, param.teams, param.nbLeaders,  options).toPromise();
    }

    /**
     * Terminate an Arena tournament 
     * Terminate an Arena tournament
     * @param param the request object
     */
    public apiTournamentTerminate(param: ArenaTournamentsApiApiTournamentTerminateRequest, options?: Configuration): Promise<Ok> {
        return this.api.apiTournamentTerminate(param.id,  options).toPromise();
    }

    /**
     * Update an Arena tournament.  Be mindful not to make important changes to ongoing tournaments.  Can be used to update a team battle. 
     * Update an Arena tournament
     * @param param the request object
     */
    public apiTournamentUpdate(param: ArenaTournamentsApiApiTournamentUpdateRequest, options?: Configuration): Promise<any> {
        return this.api.apiTournamentUpdate(param.id, param.clockTime, param.clockIncrement, param.minutes, param.name, param.waitMinutes, param.startDate, param.variant, param.rated, param.position, param.berserkable, param.streakable, param.hasChat, param.description, param.password, param.conditionsMinRatingRating, param.conditionsMaxRatingRating, param.conditionsNbRatedGameNb,  options).toPromise();
    }

    /**
     * Leave a future Arena tournament, or take a break on an ongoing Arena tournament. It's possible to join again later. Points and streaks are preserved. 
     * Pause of leave an Arena tournament
     * @param param the request object
     */
    public apiTournamentWithdraw(param: ArenaTournamentsApiApiTournamentWithdrawRequest, options?: Configuration): Promise<Ok> {
        return this.api.apiTournamentWithdraw(param.id,  options).toPromise();
    }

    /**
     * Get all tournaments created by a given user.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get tournaments created by a user
     * @param param the request object
     */
    public apiUserNameTournamentCreated(param: ArenaTournamentsApiApiUserNameTournamentCreatedRequest, options?: Configuration): Promise<any> {
        return this.api.apiUserNameTournamentCreated(param.username, param.status,  options).toPromise();
    }

    /**
     * Download games of a tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first) 
     * Export games of an Arena tournament
     * @param param the request object
     */
    public gamesByTournament(param: ArenaTournamentsApiGamesByTournamentRequest, options?: Configuration): Promise<any> {
        return this.api.gamesByTournament(param.id, param.player, param.moves, param.pgnInJson, param.tags, param.clocks, param.evals, param.opening,  options).toPromise();
    }

    /**
     * Players of an Arena tournament, with their score and performance, sorted by rank (best first).  **Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON)**, i.e. one JSON object per line.  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 
     * Get results of an Arena tournament
     * @param param the request object
     */
    public resultsByTournament(param: ArenaTournamentsApiResultsByTournamentRequest, options?: Configuration): Promise<any> {
        return this.api.resultsByTournament(param.id, param.nb,  options).toPromise();
    }

    /**
     * Teams of a team battle tournament, with top players, sorted by rank (best first). 
     * Get team standing of a team battle
     * @param param the request object
     */
    public teamsByTournament(param: ArenaTournamentsApiTeamsByTournamentRequest, options?: Configuration): Promise<any> {
        return this.api.teamsByTournament(param.id,  options).toPromise();
    }

    /**
     * Get detailed info about recently finished, current, or upcoming tournament's duels, player standings, and other info. 
     * Get info about an Arena tournament
     * @param param the request object
     */
    public tournament(param: ArenaTournamentsApiTournamentRequest, options?: Configuration): Promise<any> {
        return this.api.tournament(param.id, param.page,  options).toPromise();
    }

}

import { ObservableBoardApi } from "./ObservableAPI";
import { BoardApiRequestFactory, BoardApiResponseProcessor} from "../apis/BoardApi";

export interface BoardApiApiBoardSeekRequest {
    /**
     * Whether the game is rated and impacts players ratings.
     * @type boolean
     * @memberof BoardApiapiBoardSeek
     */
    rated?: boolean
    /**
     * Clock initial time in minutes. Required for real-time seeks.
     * @type number
     * @memberof BoardApiapiBoardSeek
     */
    time?: number
    /**
     * Clock increment in seconds. Required for real-time seeks.
     * @type number
     * @memberof BoardApiapiBoardSeek
     */
    increment?: number
    /**
     * Days per turn. Required for correspondence seeks.
     * @type number
     * @memberof BoardApiapiBoardSeek
     */
    days?: number
    /**
     * 
     * @type VariantKey
     * @memberof BoardApiapiBoardSeek
     */
    variant?: VariantKey
    /**
     * The color to play. Better left empty to automatically get 50% white.
     * @type string
     * @memberof BoardApiapiBoardSeek
     */
    color?: string
    /**
     * The rating range of potential opponents. Better left empty. Example: 1500-1800 
     * @type string
     * @memberof BoardApiapiBoardSeek
     */
    ratingRange?: string
}

export interface BoardApiApiStreamEventRequest {
}

export interface BoardApiBoardGameAbortRequest {
    /**
     * 
     * @type string
     * @memberof BoardApiboardGameAbort
     */
    gameId: string
}

export interface BoardApiBoardGameChatGetRequest {
    /**
     * 
     * @type string
     * @memberof BoardApiboardGameChatGet
     */
    gameId: string
}

export interface BoardApiBoardGameChatPostRequest {
    /**
     * 
     * @type string
     * @memberof BoardApiboardGameChatPost
     */
    gameId: string
    /**
     * 
     * @type string
     * @memberof BoardApiboardGameChatPost
     */
    room: string
    /**
     * 
     * @type string
     * @memberof BoardApiboardGameChatPost
     */
    text: string
}

export interface BoardApiBoardGameClaimVictoryRequest {
    /**
     * 
     * @type string
     * @memberof BoardApiboardGameClaimVictory
     */
    gameId: string
}

export interface BoardApiBoardGameDrawRequest {
    /**
     * 
     * @type string
     * @memberof BoardApiboardGameDraw
     */
    gameId: string
    /**
     * 
     * @type boolean
     * @memberof BoardApiboardGameDraw
     */
    accept: boolean
}

export interface BoardApiBoardGameMoveRequest {
    /**
     * 
     * @type string
     * @memberof BoardApiboardGameMove
     */
    gameId: string
    /**
     * The move to play, in UCI format
     * @type string
     * @memberof BoardApiboardGameMove
     */
    move: string
    /**
     * Whether to offer (or agree to) a draw
     * @type boolean
     * @memberof BoardApiboardGameMove
     */
    offeringDraw?: boolean
}

export interface BoardApiBoardGameResignRequest {
    /**
     * 
     * @type string
     * @memberof BoardApiboardGameResign
     */
    gameId: string
}

export interface BoardApiBoardGameStreamRequest {
    /**
     * 
     * @type string
     * @memberof BoardApiboardGameStream
     */
    gameId: string
}

export interface BoardApiBoardGameTakebackRequest {
    /**
     * 
     * @type string
     * @memberof BoardApiboardGameTakeback
     */
    gameId: string
    /**
     * 
     * @type boolean
     * @memberof BoardApiboardGameTakeback
     */
    accept: boolean
}

export class ObjectBoardApi {
    private api: ObservableBoardApi

    public constructor(configuration: Configuration, requestFactory?: BoardApiRequestFactory, responseProcessor?: BoardApiResponseProcessor) {
        this.api = new ObservableBoardApi(configuration, requestFactory, responseProcessor);
    }

    /**
     *    Create a public seek, to start a game with a random player.    ### Real-time seek    Specify the `time` and `increment` clock values.  The response is streamed but doesn't contain any information.    **Keep the connection open to keep the seek active**.    If the client closes the connection, the seek is canceled. This way, if the client terminates, the user won't be paired in a game they wouldn't play.   When the seek is accepted, or expires, the server closes the connection.    **Make sure to also have an [Event stream](#operation/apiStreamEvent) open**, to be notified when a game starts.   We recommend opening the [Event stream](#operation/apiStreamEvent) first, then the seek stream. This way,   you won't miss the game event if the seek is accepted immediately.    ### Correspondence seek    Specify the `days` per turn value.  The response is not streamed, it immediately completes with the seek ID. The seek remains active on the server until it is joined by someone.
     * Create a seek
     * @param param the request object
     */
    public apiBoardSeek(param: BoardApiApiBoardSeekRequest, options?: Configuration): Promise<void> {
        return this.api.apiBoardSeek(param.rated, param.time, param.increment, param.days, param.variant, param.color, param.ratingRange,  options).toPromise();
    }

    /**
     *    Stream the events reaching a lichess user in real time as [ndjson](#section/Introduction/Streaming-with-ND-JSON).    Each line is a JSON object containing a `type` field. Possible values are:   - `gameStart` Start of a game   - `gameFinish` Completion of a game   - `challenge` A player sends you a challenge   - `challengeCanceled` A player cancels their challenge to you   - `challengeDeclined` The opponent declines your challenge     When the stream opens, all current challenges and games are sent.
     * Stream incoming events
     * @param param the request object
     */
    public apiStreamEvent(param: BoardApiApiStreamEventRequest, options?: Configuration): Promise<ApiStreamEvent> {
        return this.api.apiStreamEvent( options).toPromise();
    }

    /**
     * Abort a game being played with the Board API. 
     * Abort a game
     * @param param the request object
     */
    public boardGameAbort(param: BoardApiBoardGameAbortRequest, options?: Configuration): Promise<Ok> {
        return this.api.boardGameAbort(param.gameId,  options).toPromise();
    }

    /**
     * Get the messages posted in the game chat 
     * Fetch the game chat
     * @param param the request object
     */
    public boardGameChatGet(param: BoardApiBoardGameChatGetRequest, options?: Configuration): Promise<any> {
        return this.api.boardGameChatGet(param.gameId,  options).toPromise();
    }

    /**
     * Post a message to the player or spectator chat, in a game being played with the Board API. 
     * Write in the chat
     * @param param the request object
     */
    public boardGameChatPost(param: BoardApiBoardGameChatPostRequest, options?: Configuration): Promise<Ok> {
        return this.api.boardGameChatPost(param.gameId, param.room, param.text,  options).toPromise();
    }

    /**
     * Claim victory when the opponent has left the game for a while. 
     * Claim victory of a game
     * @param param the request object
     */
    public boardGameClaimVictory(param: BoardApiBoardGameClaimVictoryRequest, options?: Configuration): Promise<Ok> {
        return this.api.boardGameClaimVictory(param.gameId,  options).toPromise();
    }

    /**
     * Create/accept/decline draw offers. - `yes`: Offer a draw, or accept the opponent's draw offer. - `no`: Decline a draw offer from the opponent. 
     * Handle draw offers
     * @param param the request object
     */
    public boardGameDraw(param: BoardApiBoardGameDrawRequest, options?: Configuration): Promise<Ok> {
        return this.api.boardGameDraw(param.gameId, param.accept,  options).toPromise();
    }

    /**
     * Make a move in a game being played with the Board API.  The move can also contain a draw offer/agreement. 
     * Make a Board move
     * @param param the request object
     */
    public boardGameMove(param: BoardApiBoardGameMoveRequest, options?: Configuration): Promise<Ok> {
        return this.api.boardGameMove(param.gameId, param.move, param.offeringDraw,  options).toPromise();
    }

    /**
     * Resign a game being played with the Board API. 
     * Resign a game
     * @param param the request object
     */
    public boardGameResign(param: BoardApiBoardGameResignRequest, options?: Configuration): Promise<Ok> {
        return this.api.boardGameResign(param.gameId,  options).toPromise();
    }

    /**
     *  Stream the state of a game being played with the Board API, as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  Use this endpoint to get updates about the game in real-time, with a single request.  Each line is a JSON object containing a `type` field. Possible values are:   - `gameFull` Full game data. All values are immutable, except for the `state` field.   - `gameState` Current state of the game. Immutable values not included. Sent when a move is played, a draw is offered, or when the game ends.   - `chatLine` Chat message sent by a user in the `room` \"player\" or \"spectator\".    The first line is always of type `gameFull`.
     * Stream Board game state
     * @param param the request object
     */
    public boardGameStream(param: BoardApiBoardGameStreamRequest, options?: Configuration): Promise<GameStreamEvent> {
        return this.api.boardGameStream(param.gameId,  options).toPromise();
    }

    /**
     * Create/accept/decline takebacks. - `yes`: Propose a takeback, or accept the opponent's takeback offer. - `no`: Decline a takeback offer from the opponent. 
     * Handle takeback offers
     * @param param the request object
     */
    public boardGameTakeback(param: BoardApiBoardGameTakebackRequest, options?: Configuration): Promise<Ok> {
        return this.api.boardGameTakeback(param.gameId, param.accept,  options).toPromise();
    }

}

import { ObservableBotApi } from "./ObservableAPI";
import { BotApiRequestFactory, BotApiResponseProcessor} from "../apis/BotApi";

export interface BotApiApiBotOnlineRequest {
    /**
     * How many bot users to fetch
     * @type number
     * @memberof BotApiapiBotOnline
     */
    nb?: number
}

export interface BotApiApiStreamEventRequest {
}

export interface BotApiBotAccountUpgradeRequest {
}

export interface BotApiBotGameAbortRequest {
    /**
     * 
     * @type string
     * @memberof BotApibotGameAbort
     */
    gameId: string
}

export interface BotApiBotGameChatRequest {
    /**
     * 
     * @type string
     * @memberof BotApibotGameChat
     */
    gameId: string
    /**
     * 
     * @type string
     * @memberof BotApibotGameChat
     */
    room: string
    /**
     * 
     * @type string
     * @memberof BotApibotGameChat
     */
    text: string
}

export interface BotApiBotGameMoveRequest {
    /**
     * 
     * @type string
     * @memberof BotApibotGameMove
     */
    gameId: string
    /**
     * The move to play, in UCI format
     * @type string
     * @memberof BotApibotGameMove
     */
    move: string
    /**
     * Whether to offer (or agree to) a draw
     * @type boolean
     * @memberof BotApibotGameMove
     */
    offeringDraw?: boolean
}

export interface BotApiBotGameResignRequest {
    /**
     * 
     * @type string
     * @memberof BotApibotGameResign
     */
    gameId: string
}

export interface BotApiBotGameStreamRequest {
    /**
     * 
     * @type string
     * @memberof BotApibotGameStream
     */
    gameId: string
}

export class ObjectBotApi {
    private api: ObservableBotApi

    public constructor(configuration: Configuration, requestFactory?: BotApiRequestFactory, responseProcessor?: BotApiResponseProcessor) {
        this.api = new ObservableBotApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Stream the [online bot users](https://lichess.org/player/bots), as [ndjson](#section/Introduction/Streaming-with-ND-JSON). Throttled to 50 bot users per second.
     * Get online bots
     * @param param the request object
     */
    public apiBotOnline(param: BotApiApiBotOnlineRequest, options?: Configuration): Promise<User> {
        return this.api.apiBotOnline(param.nb,  options).toPromise();
    }

    /**
     *    Stream the events reaching a lichess user in real time as [ndjson](#section/Introduction/Streaming-with-ND-JSON).    Each line is a JSON object containing a `type` field. Possible values are:   - `gameStart` Start of a game   - `gameFinish` Completion of a game   - `challenge` A player sends you a challenge   - `challengeCanceled` A player cancels their challenge to you   - `challengeDeclined` The opponent declines your challenge     When the stream opens, all current challenges and games are sent.
     * Stream incoming events
     * @param param the request object
     */
    public apiStreamEvent(param: BotApiApiStreamEventRequest, options?: Configuration): Promise<ApiStreamEvent> {
        return this.api.apiStreamEvent( options).toPromise();
    }

    /**
     * Upgrade a lichess player account into a Bot account. Only Bot accounts can use the Bot API.  The account **cannot have played any game** before becoming a Bot account. The upgrade is **irreversible**. The account will only be able to play as a Bot.  To upgrade an account to Bot, use the [official lichess-bot client](https://github.com/careless25/lichess-bot), or follow these steps: - Create an [API access token](https://lichess.org/account/oauth/token/create?scopes[]=bot:play) with \"Play bot moves\" permission. - `curl -d '' https://lichess.org/api/bot/account/upgrade -H \"Authorization: Bearer <yourTokenHere>\"`  To know if an account has already been upgraded, use the [Get my profile API](#operation/accountMe): the `title` field should be set to `BOT`. 
     * Upgrade to Bot account
     * @param param the request object
     */
    public botAccountUpgrade(param: BotApiBotAccountUpgradeRequest, options?: Configuration): Promise<Ok> {
        return this.api.botAccountUpgrade( options).toPromise();
    }

    /**
     * Abort a game being played with the Bot API. 
     * Abort a game
     * @param param the request object
     */
    public botGameAbort(param: BotApiBotGameAbortRequest, options?: Configuration): Promise<Ok> {
        return this.api.botGameAbort(param.gameId,  options).toPromise();
    }

    /**
     * Post a message to the player or spectator chat, in a game being played with the Bot API. 
     * Write in the chat
     * @param param the request object
     */
    public botGameChat(param: BotApiBotGameChatRequest, options?: Configuration): Promise<Ok> {
        return this.api.botGameChat(param.gameId, param.room, param.text,  options).toPromise();
    }

    /**
     * Make a move in a game being played with the Bot API.  The move can also contain a draw offer/agreement. 
     * Make a Bot move
     * @param param the request object
     */
    public botGameMove(param: BotApiBotGameMoveRequest, options?: Configuration): Promise<Ok> {
        return this.api.botGameMove(param.gameId, param.move, param.offeringDraw,  options).toPromise();
    }

    /**
     * Resign a game being played with the Bot API. 
     * Resign a game
     * @param param the request object
     */
    public botGameResign(param: BotApiBotGameResignRequest, options?: Configuration): Promise<Ok> {
        return this.api.botGameResign(param.gameId,  options).toPromise();
    }

    /**
     *  Stream the state of a game being played with the Bot API, as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  Use this endpoint to get updates about the game in real-time, with a single request.  Each line is a JSON object containing a `type` field. Possible values are:   - `gameFull` Full game data. All values are immutable, except for the `state` field.   - `gameState` Current state of the game. Immutable values not included.   - `chatLine` Chat message sent by a user (or the bot itself) in the `room` \"player\" or \"spectator\".    The first line is always of type `gameFull`.
     * Stream Bot game state
     * @param param the request object
     */
    public botGameStream(param: BotApiBotGameStreamRequest, options?: Configuration): Promise<GameStreamEvent> {
        return this.api.botGameStream(param.gameId,  options).toPromise();
    }

}

import { ObservableBroadcastsApi } from "./ObservableAPI";
import { BroadcastsApiRequestFactory, BroadcastsApiResponseProcessor} from "../apis/BroadcastsApi";

export interface BroadcastsApiBroadcastAllRoundsPgnRequest {
    /**
     * The broadcast tournament ID (8 characters).
     * @type string
     * @memberof BroadcastsApibroadcastAllRoundsPgn
     */
    broadcastTournamentId: string
}

export interface BroadcastsApiBroadcastIndexRequest {
    /**
     * Max number of broadcasts to fetch
     * @type number
     * @memberof BroadcastsApibroadcastIndex
     */
    nb?: number
}

export interface BroadcastsApiBroadcastPushRequest {
    /**
     * The broadcast round ID (8 characters).
     * @type string
     * @memberof BroadcastsApibroadcastPush
     */
    broadcastRoundId: string
    /**
     * The PGN. It can contain up to 64 games, separated by a double new line.
     * @type string
     * @memberof BroadcastsApibroadcastPush
     */
    body: string
}

export interface BroadcastsApiBroadcastRoundCreateRequest {
    /**
     * The broadcast tournament ID (8 characters).
     * @type string
     * @memberof BroadcastsApibroadcastRoundCreate
     */
    broadcastTournamentId: string
    /**
     * Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 1&#x60; 
     * @type string
     * @memberof BroadcastsApibroadcastRoundCreate
     */
    name: string
    /**
     * URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  If the syncUrl is missing, then the broadcast needs to be fed by [pushing PGN to it](#operation/broadcastPush). 
     * @type string
     * @memberof BroadcastsApibroadcastRoundCreate
     */
    syncUrl?: string
    /**
     * Timestamp in milliseconds of broadcast round start. Leave empty to manually start the broadcast round.  Example: &#x60;1356998400070&#x60; 
     * @type number
     * @memberof BroadcastsApibroadcastRoundCreate
     */
    startsAt?: number
}

export interface BroadcastsApiBroadcastRoundGetRequest {
    /**
     * The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used.
     * @type string
     * @memberof BroadcastsApibroadcastRoundGet
     */
    broadcastTournamentSlug: string
    /**
     * The broadcast round slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used.
     * @type string
     * @memberof BroadcastsApibroadcastRoundGet
     */
    broadcastRoundSlug: string
    /**
     * The broadcast Round ID (8 characters).
     * @type string
     * @memberof BroadcastsApibroadcastRoundGet
     */
    broadcastRoundId: string
}

export interface BroadcastsApiBroadcastRoundPgnRequest {
    /**
     * The round ID (8 characters).
     * @type string
     * @memberof BroadcastsApibroadcastRoundPgn
     */
    broadcastRoundId: string
}

export interface BroadcastsApiBroadcastRoundUpdateRequest {
    /**
     * The broadcast round ID (8 characters).
     * @type string
     * @memberof BroadcastsApibroadcastRoundUpdate
     */
    broadcastRoundId: string
    /**
     * Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 10&#x60; 
     * @type string
     * @memberof BroadcastsApibroadcastRoundUpdate
     */
    name: string
    /**
     * URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60; 
     * @type string
     * @memberof BroadcastsApibroadcastRoundUpdate
     */
    syncUrl?: string
    /**
     * Timestamp in milliseconds of broadcast start. Leave empty to manually start the broadcast.  Example: &#x60;1356998400070&#x60; 
     * @type number
     * @memberof BroadcastsApibroadcastRoundUpdate
     */
    startsAt?: number
}

export interface BroadcastsApiBroadcastStreamRoundPgnRequest {
    /**
     * The broadcast round ID (8 characters).
     * @type string
     * @memberof BroadcastsApibroadcastStreamRoundPgn
     */
    broadcastRoundId: string
}

export interface BroadcastsApiBroadcastTourCreateRequest {
    /**
     * Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60; 
     * @type string
     * @memberof BroadcastsApibroadcastTourCreate
     */
    name: string
    /**
     * Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60; 
     * @type string
     * @memberof BroadcastsApibroadcastTourCreate
     */
    description: string
    /**
     * Optional long description of the broadcast. Markdown is supported. Length must be less than 20,000 characters.
     * @type string
     * @memberof BroadcastsApibroadcastTourCreate
     */
    markup?: string
    /**
     * For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police.
     * @type boolean
     * @memberof BroadcastsApibroadcastTourCreate
     */
    official?: boolean
}

export interface BroadcastsApiBroadcastTourGetRequest {
    /**
     * The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastTournamentId&#x60; is actually used.
     * @type string
     * @memberof BroadcastsApibroadcastTourGet
     */
    slug: string
    /**
     * The broadcast tournament ID (8 characters).
     * @type string
     * @memberof BroadcastsApibroadcastTourGet
     */
    broadcastTournamentId: string
}

export interface BroadcastsApiBroadcastTourUpdateRequest {
    /**
     * The broadcast ID (8 characters).
     * @type string
     * @memberof BroadcastsApibroadcastTourUpdate
     */
    broadcastTournamentId: string
    /**
     * Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60; 
     * @type string
     * @memberof BroadcastsApibroadcastTourUpdate
     */
    name: string
    /**
     * Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60; 
     * @type string
     * @memberof BroadcastsApibroadcastTourUpdate
     */
    description: string
    /**
     * Optional long description of the broadcast tournament. Markdown is supported. Length must be less than 20,000 characters.
     * @type string
     * @memberof BroadcastsApibroadcastTourUpdate
     */
    markup?: string
    /**
     * For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police.
     * @type boolean
     * @memberof BroadcastsApibroadcastTourUpdate
     */
    official?: boolean
}

export class ObjectBroadcastsApi {
    private api: ObservableBroadcastsApi

    public constructor(configuration: Configuration, requestFactory?: BroadcastsApiRequestFactory, responseProcessor?: BroadcastsApiResponseProcessor) {
        this.api = new ObservableBroadcastsApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Download all games of all rounds of a broadcast in PGN format.  You may want to [download only the games of a single round](#operation/broadcastRoundPgn) instead. 
     * Export all rounds as PGN
     * @param param the request object
     */
    public broadcastAllRoundsPgn(param: BroadcastsApiBroadcastAllRoundsPgnRequest, options?: Configuration): Promise<any> {
        return this.api.broadcastAllRoundsPgn(param.broadcastTournamentId,  options).toPromise();
    }

    /**
     * Get all incoming, ongoing, and finished official broadcasts. The broadcasts are sorted by start date, most recent first.  Broadcasts are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get official broadcasts
     * @param param the request object
     */
    public broadcastIndex(param: BroadcastsApiBroadcastIndexRequest, options?: Configuration): Promise<Array<any>> {
        return this.api.broadcastIndex(param.nb,  options).toPromise();
    }

    /**
     * Update your broadcast with new PGN. Only for broadcast without a source URL. 
     * Push PGN to your broadcast round
     * @param param the request object
     */
    public broadcastPush(param: BroadcastsApiBroadcastPushRequest, options?: Configuration): Promise<Array<Ok>> {
        return this.api.broadcastPush(param.broadcastRoundId, param.body,  options).toPromise();
    }

    /**
     * Create a new broadcast round to relay external games. This endpoint accepts the same form data as the web form. 
     * Create a broadcast round
     * @param param the request object
     */
    public broadcastRoundCreate(param: BroadcastsApiBroadcastRoundCreateRequest, options?: Configuration): Promise<any> {
        return this.api.broadcastRoundCreate(param.broadcastTournamentId, param.name, param.syncUrl, param.startsAt,  options).toPromise();
    }

    /**
     * Get information about a broadcast round that you created. 
     * Get your broadcast round
     * @param param the request object
     */
    public broadcastRoundGet(param: BroadcastsApiBroadcastRoundGetRequest, options?: Configuration): Promise<Array<any>> {
        return this.api.broadcastRoundGet(param.broadcastTournamentSlug, param.broadcastRoundSlug, param.broadcastRoundId,  options).toPromise();
    }

    /**
     * Download all games of a single round of a broadcast tournament in PGN format.  You *could* poll this endpoint to get updates about a tournament, but it would be slow, and very inneficient.  Instead, consider [streaming the tournament](#operation/broadcastStreamRoundPgn) to get a new PGN every time a game is updated, in real-time. 
     * Export one round as PGN
     * @param param the request object
     */
    public broadcastRoundPgn(param: BroadcastsApiBroadcastRoundPgnRequest, options?: Configuration): Promise<any> {
        return this.api.broadcastRoundPgn(param.broadcastRoundId,  options).toPromise();
    }

    /**
     * Update information about a broadcast round that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. For instance, if you omit `startDate`, then any pre-existing start date will be removed. 
     * Update your broadcast round
     * @param param the request object
     */
    public broadcastRoundUpdate(param: BroadcastsApiBroadcastRoundUpdateRequest, options?: Configuration): Promise<Ok> {
        return this.api.broadcastRoundUpdate(param.broadcastRoundId, param.name, param.syncUrl, param.startsAt,  options).toPromise();
    }

    /**
     * This streaming endpoint first sends all games of a broadcast tournament in PGN format.  Then, it waits for new moves to be played. As soon as it happens, the entire PGN of the game is sent to the stream.  The stream will also send PGNs when games are added to the tournament.  This is the best way to get updates about an ongoing tournament. Streaming means no polling, and no pollings means no latency, and minimum impact on the server. 
     * Stream an ongoing broadcast tournament as PGN
     * @param param the request object
     */
    public broadcastStreamRoundPgn(param: BroadcastsApiBroadcastStreamRoundPgnRequest, options?: Configuration): Promise<any> {
        return this.api.broadcastStreamRoundPgn(param.broadcastRoundId,  options).toPromise();
    }

    /**
     * Create a new broadcast tournament to relay external games. This endpoint accepts the same form data as the [web form](https://lichess.org/broadcast/new). 
     * Create a broadcast tournament
     * @param param the request object
     */
    public broadcastTourCreate(param: BroadcastsApiBroadcastTourCreateRequest, options?: Configuration): Promise<any> {
        return this.api.broadcastTourCreate(param.name, param.description, param.markup, param.official,  options).toPromise();
    }

    /**
     * Get information about a broadcast tournament that you created. 
     * Get your broadcast tournament
     * @param param the request object
     */
    public broadcastTourGet(param: BroadcastsApiBroadcastTourGetRequest, options?: Configuration): Promise<Array<any>> {
        return this.api.broadcastTourGet(param.slug, param.broadcastTournamentId,  options).toPromise();
    }

    /**
     * Update information about a broadcast tournament that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. 
     * Update your broadcast tournament
     * @param param the request object
     */
    public broadcastTourUpdate(param: BroadcastsApiBroadcastTourUpdateRequest, options?: Configuration): Promise<Ok> {
        return this.api.broadcastTourUpdate(param.broadcastTournamentId, param.name, param.description, param.markup, param.official,  options).toPromise();
    }

}

import { ObservableBulkPairingsApi } from "./ObservableAPI";
import { BulkPairingsApiRequestFactory, BulkPairingsApiResponseProcessor} from "../apis/BulkPairingsApi";

export interface BulkPairingsApiBulkPairingCreateRequest {
    /**
     * OAuth tokens of all the players to pair, with the syntax &#x60;tokenOfWhitePlayerInGame1:tokenOfBlackPlayerInGame1,tokenOfWhitePlayerInGame2:tokenOfBlackPlayerInGame2,...&#x60;.  The 2 tokens of the players of a game are separated with &#x60;:&#x60;. The first token gets the white pieces. Games are separated with &#x60;,&#x60;.  Up to 1000 tokens can be sent, for a max of 500 games.  Each token must be included at most once.  Example: &#x60;token1:token2,token3:token4,token5:token6&#x60; 
     * @type string
     * @memberof BulkPairingsApibulkPairingCreate
     */
    players?: string
    /**
     * Clock initial time in seconds. Example: &#x60;600&#x60; 
     * @type number
     * @memberof BulkPairingsApibulkPairingCreate
     */
    clockLimit?: number
    /**
     * Clock increment in seconds. Example: &#x60;5&#x60; 
     * @type number
     * @memberof BulkPairingsApibulkPairingCreate
     */
    clockIncrement?: number
    /**
     * Date at which the games will be created. Up to 24h in the future. Omit, or set to current date and time, to start the games immediately. Example: &#x60;1612289869919&#x60; 
     * @type number
     * @memberof BulkPairingsApibulkPairingCreate
     */
    pairAt?: number
    /**
     * Date at which the clocks will be automatically started. Up to 24h in the future. Note that the clocks can start earlier than specified, if players start making moves in the game. If omitted, the clocks will not start automatically. Example: &#x60;1612289869919&#x60; 
     * @type number
     * @memberof BulkPairingsApibulkPairingCreate
     */
    startClocksAt?: number
    /**
     * Game is rated and impacts players ratings
     * @type boolean
     * @memberof BulkPairingsApibulkPairingCreate
     */
    rated?: boolean
    /**
     * 
     * @type VariantKey
     * @memberof BulkPairingsApibulkPairingCreate
     */
    variant?: VariantKey
    /**
     * Message that will be sent to each player, when the game is created.  It is sent from your user account.  &#x60;{opponent}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder. 
     * @type string
     * @memberof BulkPairingsApibulkPairingCreate
     */
    message?: string
}

export interface BulkPairingsApiBulkPairingDeleteRequest {
    /**
     * 
     * @type string
     * @memberof BulkPairingsApibulkPairingDelete
     */
    id: string
}

export interface BulkPairingsApiBulkPairingGetRequest {
}

export interface BulkPairingsApiBulkPairingStartClocksRequest {
    /**
     * 
     * @type string
     * @memberof BulkPairingsApibulkPairingStartClocks
     */
    id: string
}

export class ObjectBulkPairingsApi {
    private api: ObservableBulkPairingsApi

    public constructor(configuration: Configuration, requestFactory?: BulkPairingsApiRequestFactory, responseProcessor?: BulkPairingsApiResponseProcessor) {
        this.api = new ObservableBulkPairingsApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Schedule many games at once, up to 24h in advance.  OAuth tokens are required for all paired players, with the `challenge:write` scope.  You can schedule up to 500 games every 10 minutes. [Contact us](mailto:contact@lichess.org) if you need higher limits.  The entire bulk is rejected if:   - a token is missing   - a token is present more than once   - a token lacks the `challenge:write` scope   - a player account is closed   - a player is paired more than once   - a bulk is already scheduled to start at the same time with the same player   - you have 10 scheduled bulks   - you have 1000 scheduled games  Partial bulks are never created. Either it all fails, or it all succeeds. When it fails, it does so with an error message explaining the issue. Failed bulks are not counted in the rate limiting, they are free. Fix the issues, manually or programmatically, then retry to schedule the bulk.  A successful bulk creation returns a JSON bulk document. Its ID can be used for further operations. 
     * Create a bulk pairing
     * @param param the request object
     */
    public bulkPairingCreate(param: BulkPairingsApiBulkPairingCreateRequest, options?: Configuration): Promise<any> {
        return this.api.bulkPairingCreate(param.players, param.clockLimit, param.clockIncrement, param.pairAt, param.startClocksAt, param.rated, param.variant, param.message,  options).toPromise();
    }

    /**
     * Cancel and delete a bulk pairing that is scheduled in the future.  If the games have already been created, then this does nothing.  Canceling a bulk pairing does not refund the rate limit cost of that bulk pairing. 
     * Cancel a bulk pairing
     * @param param the request object
     */
    public bulkPairingDelete(param: BulkPairingsApiBulkPairingDeleteRequest, options?: Configuration): Promise<Ok> {
        return this.api.bulkPairingDelete(param.id,  options).toPromise();
    }

    /**
     * Get a list of upcoming bulk pairings you created.  Only bulk pairings that are scheduled in the future, or that have a clock start scheduled in the future, are listed.  Bulk pairings are deleted from the server after the pairings are done and the clocks have started. 
     * View upcoming bulk pairings
     * @param param the request object
     */
    public bulkPairingGet(param: BulkPairingsApiBulkPairingGetRequest, options?: Configuration): Promise<Array<any>> {
        return this.api.bulkPairingGet( options).toPromise();
    }

    /**
     * Immediately start all clocks of the games of a bulk pairing.  This overrides the `startClocksAt` value of an existing bulk pairing.  If the games have not yet been created (`bulk.pairAt` is in the future), then this does nothing.  If the clocks have already started (`bulk.startClocksAt` is in the past), then this does nothing. 
     * Manually start clocks
     * @param param the request object
     */
    public bulkPairingStartClocks(param: BulkPairingsApiBulkPairingStartClocksRequest, options?: Configuration): Promise<Ok> {
        return this.api.bulkPairingStartClocks(param.id,  options).toPromise();
    }

}

import { ObservableChallengesApi } from "./ObservableAPI";
import { ChallengesApiRequestFactory, ChallengesApiResponseProcessor} from "../apis/ChallengesApi";

export interface ChallengesApiAdminChallengeTokensRequest {
    /**
     * Usernames separated with commas
     * @type string
     * @memberof ChallengesApiadminChallengeTokens
     */
    users: string
    /**
     * User visible description of the token
     * @type string
     * @memberof ChallengesApiadminChallengeTokens
     */
    description: string
}

export interface ChallengesApiChallengeAcceptRequest {
    /**
     * 
     * @type string
     * @memberof ChallengesApichallengeAccept
     */
    challengeId: string
}

export interface ChallengesApiChallengeAiRequest {
    /**
     * AI strength
     * @type number
     * @memberof ChallengesApichallengeAi
     */
    level?: number
    /**
     * Clock initial time in seconds. If empty, a correspondence game is created.
     * @type number
     * @memberof ChallengesApichallengeAi
     */
    clockLimit?: number
    /**
     * Clock increment in seconds. If empty, a correspondence game is created.
     * @type number
     * @memberof ChallengesApichallengeAi
     */
    clockIncrement?: number
    /**
     * Days per move, for correspondence games. Clock settings must be omitted.
     * @type number
     * @memberof ChallengesApichallengeAi
     */
    days?: number
    /**
     * Which color you get to play
     * @type string
     * @memberof ChallengesApichallengeAi
     */
    color?: string
    /**
     * 
     * @type VariantKey
     * @memberof ChallengesApichallengeAi
     */
    variant?: VariantKey
    /**
     * Custom initial position (in FEN). Variant must be standard, and the game cannot be rated.
     * @type string
     * @memberof ChallengesApichallengeAi
     */
    fen?: string
}

export interface ChallengesApiChallengeCancelRequest {
    /**
     * 
     * @type string
     * @memberof ChallengesApichallengeCancel
     */
    challengeId: string
    /**
     * Optional &#x60;challenge:write&#x60; token of the opponent. If set, the game can be canceled even if both players have moved.
     * @type string
     * @memberof ChallengesApichallengeCancel
     */
    opponentToken?: string
}

export interface ChallengesApiChallengeCreateRequest {
    /**
     * 
     * @type string
     * @memberof ChallengesApichallengeCreate
     */
    username: string
    /**
     * Game is rated and impacts players ratings
     * @type boolean
     * @memberof ChallengesApichallengeCreate
     */
    rated?: boolean
    /**
     * Clock initial time in seconds. If empty, a correspondence game is created.
     * @type number
     * @memberof ChallengesApichallengeCreate
     */
    clockLimit?: number
    /**
     * Clock increment in seconds. If empty, a correspondence game is created.
     * @type number
     * @memberof ChallengesApichallengeCreate
     */
    clockIncrement?: number
    /**
     * Days per move, for correspondence games. Clock settings must be omitted.
     * @type number
     * @memberof ChallengesApichallengeCreate
     */
    days?: number
    /**
     * Which color you get to play
     * @type string
     * @memberof ChallengesApichallengeCreate
     */
    color?: string
    /**
     * 
     * @type VariantKey
     * @memberof ChallengesApichallengeCreate
     */
    variant?: VariantKey
    /**
     * Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. Castling moves will use UCI_Chess960 notation, for example e1h1 instead of e1g1.
     * @type string
     * @memberof ChallengesApichallengeCreate
     */
    fen?: string
    /**
     * If set, the response is streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). The challenge is kept alive until the connection is closed by the client. When the challenge is accepted, declined or canceled, a message of the form &#x60;{\\\&quot;done\\\&quot;:\\\&quot;accepted\\\&quot;}&#x60; is sent, then the connection is closed by the server. If not set, the response is not streamed, and the challenge expires after 20s if not accepted. 
     * @type boolean
     * @memberof ChallengesApichallengeCreate
     */
    keepAliveStream?: boolean
    /**
     * Immediately accept the challenge and create the game. Pass in an OAuth token (with the &#x60;challenge:write&#x60; scope) for the receiving user. On success, the response will contain a &#x60;game&#x60; field instead of a &#x60;challenge&#x60; field.  Alternatively, consider the [bulk pairing API](#operation/bulkPairingCreate). 
     * @type string
     * @memberof ChallengesApichallengeCreate
     */
    acceptByToken?: string
    /**
     * **Only if &#x60;acceptByToken&#x60; is set.**  Message that is sent to each player, when the game is created. It is sent from your user account.  &#x60;{opponent}&#x60;, &#x60;{player}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent name, player name, and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder. 
     * @type string
     * @memberof ChallengesApichallengeCreate
     */
    message?: string
}

export interface ChallengesApiChallengeDeclineRequest {
    /**
     * 
     * @type string
     * @memberof ChallengesApichallengeDecline
     */
    challengeId: string
    /**
     * Reason challenge was declined. It will be translated to the player&#39;s language. See [the full list in the translation file](https://github.com/ornicar/lila/blob/43fbd61029ff3960a21fbd213944bed66325696d/translation/source/challenge.xml#L14).
     * @type string
     * @memberof ChallengesApichallengeDecline
     */
    reason?: string
}

export interface ChallengesApiChallengeListRequest {
}

export interface ChallengesApiChallengeOpenRequest {
    /**
     * Game is rated and impacts players ratings
     * @type boolean
     * @memberof ChallengesApichallengeOpen
     */
    rated?: boolean
    /**
     * Clock initial time in seconds. If empty, a correspondence game is created.
     * @type number
     * @memberof ChallengesApichallengeOpen
     */
    clockLimit?: number
    /**
     * Clock increment in seconds. If empty, a correspondence game is created.
     * @type number
     * @memberof ChallengesApichallengeOpen
     */
    clockIncrement?: number
    /**
     * 
     * @type VariantKey
     * @memberof ChallengesApichallengeOpen
     */
    variant?: VariantKey
    /**
     * Custom initial position (in FEN). Variant must be standard, and the game cannot be rated.
     * @type string
     * @memberof ChallengesApichallengeOpen
     */
    fen?: string
    /**
     * Optional name for the challenge, that players will see on the challenge page.
     * @type string
     * @memberof ChallengesApichallengeOpen
     */
    name?: string
}

export interface ChallengesApiChallengeStartClocksRequest {
    /**
     * 
     * @type string
     * @memberof ChallengesApichallengeStartClocks
     */
    gameId: string
    /**
     * OAuth token of a player
     * @type string
     * @memberof ChallengesApichallengeStartClocks
     */
    token1?: string
    /**
     * OAuth token of the other player
     * @type string
     * @memberof ChallengesApichallengeStartClocks
     */
    token2?: string
}

export interface ChallengesApiRoundAddTimeRequest {
    /**
     * 
     * @type string
     * @memberof ChallengesApiroundAddTime
     */
    gameId: string
    /**
     * How many seconds to give
     * @type string
     * @memberof ChallengesApiroundAddTime
     */
    seconds: string
}

export class ObjectChallengesApi {
    private api: ObservableChallengesApi

    public constructor(configuration: Configuration, requestFactory?: ChallengesApiRequestFactory, responseProcessor?: ChallengesApiResponseProcessor) {
        this.api = new ObservableChallengesApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * **For administrators only. You are not allowed to use this endpoint.**  Create and obtain `challenge:write` tokens for multiple users.  If a similar token already exists for a user, it is reused. This endpoint is idempotent. 
     * Admin challenge tokens
     * @param param the request object
     */
    public adminChallengeTokens(param: ChallengesApiAdminChallengeTokensRequest, options?: Configuration): Promise<void> {
        return this.api.adminChallengeTokens(param.users, param.description,  options).toPromise();
    }

    /**
     * Accept an incoming challenge.  You should receive a `gameStart` event on the [incoming events stream](#operation/apiStreamEvent). 
     * Accept a challenge
     * @param param the request object
     */
    public challengeAccept(param: ChallengesApiChallengeAcceptRequest, options?: Configuration): Promise<Ok> {
        return this.api.challengeAccept(param.challengeId,  options).toPromise();
    }

    /**
     * Start a game with Lichess AI.  You will be notified on the [event stream](#operation/apiStreamEvent) that a new game has started. 
     * Challenge the AI
     * @param param the request object
     */
    public challengeAi(param: ChallengesApiChallengeAiRequest, options?: Configuration): Promise<GameJson> {
        return this.api.challengeAi(param.level, param.clockLimit, param.clockIncrement, param.days, param.color, param.variant, param.fen,  options).toPromise();
    }

    /**
     * Cancel a challenge you sent, or aborts the game if the challenge was accepted, but the game was not yet played. Note that the ID of a game is the same as the ID of the challenge that created it. 
     * Cancel a challenge
     * @param param the request object
     */
    public challengeCancel(param: ChallengesApiChallengeCancelRequest, options?: Configuration): Promise<Ok> {
        return this.api.challengeCancel(param.challengeId, param.opponentToken,  options).toPromise();
    }

    /**
     * Challenge someone to play. The targeted player can choose to accept or decline.  If the challenge is accepted, you will be notified on the [event stream](#operation/apiStreamEvent) that a new game has started. The game ID will be the same as the challenge ID.  If you also have an OAuth token with `challenge:write` scope for the receiving user, you can make them accept the challenge immediately by setting the `acceptByToken` field.  Challenges for realtime games (not correspondence) expire after 20s if not accepted. To prevent that, use the `keepAliveStream` flag described below. 
     * Create a challenge
     * @param param the request object
     */
    public challengeCreate(param: ChallengesApiChallengeCreateRequest, options?: Configuration): Promise<ChallengeJson> {
        return this.api.challengeCreate(param.username, param.rated, param.clockLimit, param.clockIncrement, param.days, param.color, param.variant, param.fen, param.keepAliveStream, param.acceptByToken, param.message,  options).toPromise();
    }

    /**
     * Decline an incoming challenge. 
     * Decline a challenge
     * @param param the request object
     */
    public challengeDecline(param: ChallengesApiChallengeDeclineRequest, options?: Configuration): Promise<Ok> {
        return this.api.challengeDecline(param.challengeId, param.reason,  options).toPromise();
    }

    /**
     * Get a list of challenges created by or targeted at you. 
     * List your challenges
     * @param param the request object
     */
    public challengeList(param: ChallengesApiChallengeListRequest, options?: Configuration): Promise<InlineResponse2003> {
        return this.api.challengeList( options).toPromise();
    }

    /**
     * Create a challenge that any 2 players can join.  Share the URL of the challenge. the first 2 players to click it will be paired for a game.  The response body also contains `whiteUrl` and `blackUrl`. You can control which color each player gets by giving them these URLs, instead of the main challenge URL.  Open challenges expire after 24h.  To directly pair 2 known players, use [this endpoint](#operation/challengeCreate) instead, with the `acceptByToken` parameter. 
     * Open-ended challenge
     * @param param the request object
     */
    public challengeOpen(param: ChallengesApiChallengeOpenRequest, options?: Configuration): Promise<any> {
        return this.api.challengeOpen(param.rated, param.clockLimit, param.clockIncrement, param.variant, param.fen, param.name,  options).toPromise();
    }

    /**
     * Start the clocks of a game immediately, even if a player has not yet made a move.  Requires the OAuth tokens of both players with `challenge:write` scope.  If the clocks have already started, the call will have no effect. 
     * Start clocks of a game
     * @param param the request object
     */
    public challengeStartClocks(param: ChallengesApiChallengeStartClocksRequest, options?: Configuration): Promise<Ok> {
        return this.api.challengeStartClocks(param.gameId, param.token1, param.token2,  options).toPromise();
    }

    /**
     * Add seconds to the opponent's clock. Can be used to create games with time odds. 
     * Add time to the opponent clock
     * @param param the request object
     */
    public roundAddTime(param: ChallengesApiRoundAddTimeRequest, options?: Configuration): Promise<Ok> {
        return this.api.roundAddTime(param.gameId, param.seconds,  options).toPromise();
    }

}

import { ObservableGamesApi } from "./ObservableAPI";
import { GamesApiRequestFactory, GamesApiResponseProcessor} from "../apis/GamesApi";

export interface GamesApiApiAccountPlayingRequest {
    /**
     * Max number of games to fetch
     * @type number
     * @memberof GamesApiapiAccountPlaying
     */
    nb?: number
}

export interface GamesApiApiGamesUserRequest {
    /**
     * The user name.
     * @type string
     * @memberof GamesApiapiGamesUser
     */
    username: string
    /**
     * Download games played since this timestamp.
     * @type number
     * @memberof GamesApiapiGamesUser
     */
    since?: number
    /**
     * Download games played until this timestamp.
     * @type number
     * @memberof GamesApiapiGamesUser
     */
    until?: number
    /**
     * How many games to download. Leave empty to download all games.
     * @type number
     * @memberof GamesApiapiGamesUser
     */
    max?: number
    /**
     * [Filter] Only games played against this opponent
     * @type string
     * @memberof GamesApiapiGamesUser
     */
    vs?: string
    /**
     * [Filter] Only rated (&#x60;true&#x60;) or casual (&#x60;false&#x60;) games
     * @type boolean
     * @memberof GamesApiapiGamesUser
     */
    rated?: boolean
    /**
     * [Filter] Only games in these speeds or variants.   Multiple perf types can be specified, separated by a comma.   Example: blitz,rapid,classical
     * @type PerfType
     * @memberof GamesApiapiGamesUser
     */
    perfType?: PerfType
    /**
     * [Filter] Only games played as this color.
     * @type &#39;white&#39; | &#39;black&#39;
     * @memberof GamesApiapiGamesUser
     */
    color?: 'white' | 'black'
    /**
     * [Filter] Only games with or without a computer analysis available
     * @type boolean
     * @memberof GamesApiapiGamesUser
     */
    analysed?: boolean
    /**
     * Include the PGN moves.
     * @type boolean
     * @memberof GamesApiapiGamesUser
     */
    moves?: boolean
    /**
     * Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. The response type must be set to &#x60;application/x-ndjson&#x60; by the request &#x60;Accept&#x60; header.
     * @type boolean
     * @memberof GamesApiapiGamesUser
     */
    pgnInJson?: boolean
    /**
     * Include the PGN tags.
     * @type boolean
     * @memberof GamesApiapiGamesUser
     */
    tags?: boolean
    /**
     * Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @type boolean
     * @memberof GamesApiapiGamesUser
     */
    clocks?: boolean
    /**
     * Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @type boolean
     * @memberof GamesApiapiGamesUser
     */
    evals?: boolean
    /**
     * Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     * @type boolean
     * @memberof GamesApiapiGamesUser
     */
    opening?: boolean
    /**
     * Include ongoing games. The last 3 moves will be omitted.
     * @type boolean
     * @memberof GamesApiapiGamesUser
     */
    ongoing?: boolean
    /**
     * Include finished games. Set to &#x60;false&#x60; to only get ongoing games.
     * @type boolean
     * @memberof GamesApiapiGamesUser
     */
    finished?: boolean
    /**
     * URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt; 
     * @type string
     * @memberof GamesApiapiGamesUser
     */
    players?: string
    /**
     * Sort order of the games.
     * @type &#39;dateAsc&#39; | &#39;dateDesc&#39;
     * @memberof GamesApiapiGamesUser
     */
    sort?: 'dateAsc' | 'dateDesc'
}

export interface GamesApiApiUserCurrentGameRequest {
    /**
     * 
     * @type string
     * @memberof GamesApiapiUserCurrentGame
     */
    username: string
    /**
     * Include the PGN moves.
     * @type boolean
     * @memberof GamesApiapiUserCurrentGame
     */
    moves?: boolean
    /**
     * Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @type boolean
     * @memberof GamesApiapiUserCurrentGame
     */
    pgnInJson?: boolean
    /**
     * Include the PGN tags.
     * @type boolean
     * @memberof GamesApiapiUserCurrentGame
     */
    tags?: boolean
    /**
     * Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @type boolean
     * @memberof GamesApiapiUserCurrentGame
     */
    clocks?: boolean
    /**
     * Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @type boolean
     * @memberof GamesApiapiUserCurrentGame
     */
    evals?: boolean
    /**
     * Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     * @type boolean
     * @memberof GamesApiapiUserCurrentGame
     */
    opening?: boolean
    /**
     * Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60; 
     * @type boolean
     * @memberof GamesApiapiUserCurrentGame
     */
    literate?: boolean
    /**
     * URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt; 
     * @type string
     * @memberof GamesApiapiUserCurrentGame
     */
    players?: string
}

export interface GamesApiGameImportRequest {
    /**
     * The PGN. It can contain only one game. Most standard tags are supported.
     * @type string
     * @memberof GamesApigameImport
     */
    pgn?: string
}

export interface GamesApiGamePgnRequest {
    /**
     * The game ID (8 characters).
     * @type string
     * @memberof GamesApigamePgn
     */
    gameId: string
    /**
     * Include the PGN moves.
     * @type boolean
     * @memberof GamesApigamePgn
     */
    moves?: boolean
    /**
     * Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @type boolean
     * @memberof GamesApigamePgn
     */
    pgnInJson?: boolean
    /**
     * Include the PGN tags.
     * @type boolean
     * @memberof GamesApigamePgn
     */
    tags?: boolean
    /**
     * Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @type boolean
     * @memberof GamesApigamePgn
     */
    clocks?: boolean
    /**
     * Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @type boolean
     * @memberof GamesApigamePgn
     */
    evals?: boolean
    /**
     * Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     * @type boolean
     * @memberof GamesApigamePgn
     */
    opening?: boolean
    /**
     * Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60; 
     * @type boolean
     * @memberof GamesApigamePgn
     */
    literate?: boolean
    /**
     * URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt; 
     * @type string
     * @memberof GamesApigamePgn
     */
    players?: string
}

export interface GamesApiGamesByUsersRequest {
    /**
     * Up to 300 user IDs separated by commas.
     * @type string
     * @memberof GamesApigamesByUsers
     */
    body: string
    /**
     * Include the already started games at the beginning of the stream.
     * @type boolean
     * @memberof GamesApigamesByUsers
     */
    withCurrentGames?: boolean
}

export interface GamesApiGamesExportIdsRequest {
    /**
     * Game IDs separated by commas. Up to 300.
     * @type string
     * @memberof GamesApigamesExportIds
     */
    body: string
    /**
     * Include the PGN moves.
     * @type boolean
     * @memberof GamesApigamesExportIds
     */
    moves?: boolean
    /**
     * Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @type boolean
     * @memberof GamesApigamesExportIds
     */
    pgnInJson?: boolean
    /**
     * Include the PGN tags.
     * @type boolean
     * @memberof GamesApigamesExportIds
     */
    tags?: boolean
    /**
     * Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @type boolean
     * @memberof GamesApigamesExportIds
     */
    clocks?: boolean
    /**
     * Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @type boolean
     * @memberof GamesApigamesExportIds
     */
    evals?: boolean
    /**
     * Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     * @type boolean
     * @memberof GamesApigamesExportIds
     */
    opening?: boolean
    /**
     * URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt; 
     * @type string
     * @memberof GamesApigamesExportIds
     */
    players?: string
}

export interface GamesApiStreamGameRequest {
    /**
     * 
     * @type string
     * @memberof GamesApistreamGame
     */
    id: string
}

export class ObjectGamesApi {
    private api: ObservableGamesApi

    public constructor(configuration: Configuration, requestFactory?: GamesApiRequestFactory, responseProcessor?: GamesApiResponseProcessor) {
        this.api = new ObservableGamesApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Get the ongoing games of the current user. Real-time and correspondence games are included. The most urgent games are listed first. 
     * Get my ongoing games
     * @param param the request object
     */
    public apiAccountPlaying(param: GamesApiApiAccountPlayingRequest, options?: Configuration): Promise<any> {
        return this.api.apiAccountPlaying(param.nb,  options).toPromise();
    }

    /**
     * Download all games of any user in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first)  We recommend streaming the response, for it can be very long. <https://lichess.org/@/german11> for instance has more than 320,000 games.  The game stream is throttled, depending on who is making the request:   - Anonymous request: 20 games per second   - [OAuth2 authenticated](#section/Authentication) request: 30 games per second   - Authenticated, downloading your own games: 60 games per second 
     * Export games of a user
     * @param param the request object
     */
    public apiGamesUser(param: GamesApiApiGamesUserRequest, options?: Configuration): Promise<any> {
        return this.api.apiGamesUser(param.username, param.since, param.until, param.max, param.vs, param.rated, param.perfType, param.color, param.analysed, param.moves, param.pgnInJson, param.tags, param.clocks, param.evals, param.opening, param.ongoing, param.finished, param.players, param.sort,  options).toPromise();
    }

    /**
     * Download the ongoing game, or the last game played, of a user. Available in either PGN or JSON format. If the game is ongoing, the 3 last moves are omitted. 
     * Export ongoing game of a user
     * @param param the request object
     */
    public apiUserCurrentGame(param: GamesApiApiUserCurrentGameRequest, options?: Configuration): Promise<any> {
        return this.api.apiUserCurrentGame(param.username, param.moves, param.pgnInJson, param.tags, param.clocks, param.evals, param.opening, param.literate, param.players,  options).toPromise();
    }

    /**
     * Import a game from PGN. See <https://lichess.org/paste>.  Rate limiting: 200 games per hour for OAuth requests, 100 games per hour for anonymous requests.  To broadcast ongoing games, consider [pushing to a broadcast instead](#operation/broadcastPush). 
     * Import one game
     * @param param the request object
     */
    public gameImport(param: GamesApiGameImportRequest, options?: Configuration): Promise<any> {
        return this.api.gameImport(param.pgn,  options).toPromise();
    }

    /**
     * Download one game in either PGN or JSON format.  Ongoing games have their last 3 moves omitted, after move 5. 
     * Export one game
     * @param param the request object
     */
    public gamePgn(param: GamesApiGamePgnRequest, options?: Configuration): Promise<any> {
        return this.api.gamePgn(param.gameId, param.moves, param.pgnInJson, param.tags, param.clocks, param.evals, param.opening, param.literate, param.players,  options).toPromise();
    }

    /**
     * Stream the games played between a list of users, in real time. Only games where **both players** are part of the list are included.  By default, games are only sent to the stream when they start. To also get all ongoing games at the beginning of the stream, use the `withCurrentGames` flag.  Maximum number of users: 300.  Games are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  The method is `POST` so a longer list of IDs can be sent in the request body. 
     * Stream games of users
     * @param param the request object
     */
    public gamesByUsers(param: GamesApiGamesByUsersRequest, options?: Configuration): Promise<any> {
        return this.api.gamesByUsers(param.body, param.withCurrentGames,  options).toPromise();
    }

    /**
     * Download games by IDs in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format, depending on the request Accept header.  Games are sorted by reverse chronological order (most recent first)  The method is `POST` so a longer list of IDs can be sent in the request body.  300 IDs can be submitted.  Ongoing games have their last 3 moves omitted, after move 5. 
     * Export games by IDs
     * @param param the request object
     */
    public gamesExportIds(param: GamesApiGamesExportIdsRequest, options?: Configuration): Promise<any> {
        return this.api.gamesExportIds(param.body, param.moves, param.pgnInJson, param.tags, param.clocks, param.evals, param.opening, param.players,  options).toPromise();
    }

    /**
     * Stream positions and moves of any ongoing game, in [ndjson](#section/Introduction/Streaming-with-ND-JSON).  A description of the game is sent as a first message. Then a message is sent each time a move is played. Finally a description of the game is sent when it finishes, and the stream is closed.  After move 5, the stream intentionally remains 3 moves behind the game status, as to prevent cheat bots from using this API.  No more than 8 game streams can be opened at the same time from the same IP address. 
     * Stream moves of a game
     * @param param the request object
     */
    public streamGame(param: GamesApiStreamGameRequest, options?: Configuration): Promise<any> {
        return this.api.streamGame(param.id,  options).toPromise();
    }

}

import { ObservableMessagingApi } from "./ObservableAPI";
import { MessagingApiRequestFactory, MessagingApiResponseProcessor} from "../apis/MessagingApi";

export interface MessagingApiInboxUsernameRequest {
    /**
     * 
     * @type string
     * @memberof MessagingApiinboxUsername
     */
    username: string
    /**
     * 
     * @type string
     * @memberof MessagingApiinboxUsername
     */
    text: string
}

export class ObjectMessagingApi {
    private api: ObservableMessagingApi

    public constructor(configuration: Configuration, requestFactory?: MessagingApiRequestFactory, responseProcessor?: MessagingApiResponseProcessor) {
        this.api = new ObservableMessagingApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Send a private message to another player. 
     * Send a private message
     * @param param the request object
     */
    public inboxUsername(param: MessagingApiInboxUsernameRequest, options?: Configuration): Promise<Ok> {
        return this.api.inboxUsername(param.username, param.text,  options).toPromise();
    }

}

import { ObservableOAuthApi } from "./ObservableAPI";
import { OAuthApiRequestFactory, OAuthApiResponseProcessor} from "../apis/OAuthApi";

export interface OAuthApiApiTokenRequest {
    /**
     * Must be &#x60;authorization_code&#x60;.
     * @type string
     * @memberof OAuthApiapiToken
     */
    grantType?: string
    /**
     * The authorization code that was sent in the &#x60;code&#x60; parameter to your &#x60;redirect_uri&#x60;.
     * @type string
     * @memberof OAuthApiapiToken
     */
    code?: string
    /**
     * A &#x60;code_challenge&#x60; was used to request the authorization code. This must be the &#x60;code_verifier&#x60; it was derived from.
     * @type string
     * @memberof OAuthApiapiToken
     */
    codeVerifier?: string
    /**
     * Must match the &#x60;redirect_uri&#x60; used to request the authorization code.
     * @type string
     * @memberof OAuthApiapiToken
     */
    redirectUri?: string
    /**
     * Must match the &#x60;client_id&#x60; used to request the authorization code.
     * @type string
     * @memberof OAuthApiapiToken
     */
    clientId?: string
}

export interface OAuthApiApiTokenDeleteRequest {
}

export interface OAuthApiOauthRequest {
    /**
     * Must be &#x60;code&#x60;.
     * @type string
     * @memberof OAuthApioauth
     */
    responseType: string
    /**
     * Arbitrary identifier that uniquely identifies your application.
     * @type string
     * @memberof OAuthApioauth
     */
    clientId: string
    /**
     * The absolute URL that the user should be redirected to with the authorization result.
     * @type string
     * @memberof OAuthApioauth
     */
    redirectUri: string
    /**
     * Must be &#x60;S256&#x60;.
     * @type string
     * @memberof OAuthApioauth
     */
    codeChallengeMethod: string
    /**
     * Compute &#x60;BASE64URL(SHA256(code_verifier))&#x60;.
     * @type string
     * @memberof OAuthApioauth
     */
    codeChallenge: string
    /**
     * Space separated list of requested OAuth scopes, if any.
     * @type string
     * @memberof OAuthApioauth
     */
    scope?: string
    /**
     * Arbitrary state that will be returned verbatim with the authorization result.
     * @type string
     * @memberof OAuthApioauth
     */
    state?: string
}

export class ObjectOAuthApi {
    private api: ObservableOAuthApi

    public constructor(configuration: Configuration, requestFactory?: OAuthApiRequestFactory, responseProcessor?: OAuthApiResponseProcessor) {
        this.api = new ObservableOAuthApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * OAuth2 token endpoint. Exchanges an authorization code for an access token. 
     * Obtain access token
     * @param param the request object
     */
    public apiToken(param: OAuthApiApiTokenRequest, options?: Configuration): Promise<void> {
        return this.api.apiToken(param.grantType, param.code, param.codeVerifier, param.redirectUri, param.clientId,  options).toPromise();
    }

    /**
     * Revokes the access token sent as Bearer for this request.
     * Revoke access token
     * @param param the request object
     */
    public apiTokenDelete(param: OAuthApiApiTokenDeleteRequest, options?: Configuration): Promise<void> {
        return this.api.apiTokenDelete( options).toPromise();
    }

    /**
     * OAuth2 authorization endpoint.  Start the OAuth2 Authorization Code Flow with PKCE by securely generating two random strings unique to each authorization request: * `code_verifier` * `state`  Store these in session storage. Make sure not to reveal `code_verifier` to eavesdroppers. Do not show it in URLs, do not abuse `state` to store it, do not send it over insecure connections. However it is fine if the user themselves can extract `code_verifier`, which will always be possible for fully client-side apps.  Then send the user to this endpoint. They will be prompted to grant authorization and then be redirected back to the given `redirect_uri`.  If the authorization failed, the following query string parameters will be appended to the redirection: * `error`, in particular with value `access_denied` if the user    cancelled authorization * `error_description` to aid debugging * `state`, exactly as passed in the `state` parameter  If the authorization succeeded, the following query string parameters will be appended to the redirection: * `code`, containing a fresh short-lived authorization code * `state`, exactly as passed in the `state` parameter  Next, to defend against cross site request forgery, check that the returned `state` matches the `state` you originally generated.  Finally, continue by using the authorization code to [obtain an access token](#operation/apiToken). 
     * Request authorization code
     * @param param the request object
     */
    public oauth(param: OAuthApiOauthRequest, options?: Configuration): Promise<void> {
        return this.api.oauth(param.responseType, param.clientId, param.redirectUri, param.codeChallengeMethod, param.codeChallenge, param.scope, param.state,  options).toPromise();
    }

}

import { ObservableOpeningExplorerApi } from "./ObservableAPI";
import { OpeningExplorerApiRequestFactory, OpeningExplorerApiResponseProcessor} from "../apis/OpeningExplorerApi";

export interface OpeningExplorerApiOpeningExplorerLichessRequest {
    /**
     * Variant
     * @type VariantKey
     * @memberof OpeningExplorerApiopeningExplorerLichess
     */
    variant?: VariantKey
    /**
     * FEN of the root position
     * @type string
     * @memberof OpeningExplorerApiopeningExplorerLichess
     */
    fen?: string
    /**
     * Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position. 
     * @type string
     * @memberof OpeningExplorerApiopeningExplorerLichess
     */
    play?: string
    /**
     * Comma separated list of game speeds to look for
     * @type Array&lt;Speed&gt;
     * @memberof OpeningExplorerApiopeningExplorerLichess
     */
    speeds?: Array<Speed>
    /**
     * Comma separated list of rating groups, ranging from their value to the next higher group
     * @type Array&lt;1600 | 1800 | 2000 | 2200 | 2500&gt;
     * @memberof OpeningExplorerApiopeningExplorerLichess
     */
    ratings?: Array<1600 | 1800 | 2000 | 2200 | 2500>
    /**
     * Include only games from this month or later
     * @type string
     * @memberof OpeningExplorerApiopeningExplorerLichess
     */
    since?: string
    /**
     * Include only games from this month or earlier
     * @type string
     * @memberof OpeningExplorerApiopeningExplorerLichess
     */
    until?: string
    /**
     * Number of most common moves to display
     * @type number
     * @memberof OpeningExplorerApiopeningExplorerLichess
     */
    moves?: number
    /**
     * Number of top games to display
     * @type number
     * @memberof OpeningExplorerApiopeningExplorerLichess
     */
    topGames?: number
    /**
     * Number of recent games to display
     * @type number
     * @memberof OpeningExplorerApiopeningExplorerLichess
     */
    recentGames?: number
}

export interface OpeningExplorerApiOpeningExplorerMasterRequest {
    /**
     * FEN of the root position
     * @type string
     * @memberof OpeningExplorerApiopeningExplorerMaster
     */
    fen?: string
    /**
     * Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position. 
     * @type string
     * @memberof OpeningExplorerApiopeningExplorerMaster
     */
    play?: string
    /**
     * Include only games from this year or later
     * @type number
     * @memberof OpeningExplorerApiopeningExplorerMaster
     */
    since?: number
    /**
     * Include only games from thi year or earlier
     * @type number
     * @memberof OpeningExplorerApiopeningExplorerMaster
     */
    until?: number
    /**
     * Number of most common moves to display
     * @type number
     * @memberof OpeningExplorerApiopeningExplorerMaster
     */
    moves?: number
    /**
     * Number of top games to display
     * @type number
     * @memberof OpeningExplorerApiopeningExplorerMaster
     */
    topGames?: number
}

export interface OpeningExplorerApiOpeningExplorerMasterGameRequest {
    /**
     * 
     * @type string
     * @memberof OpeningExplorerApiopeningExplorerMasterGame
     */
    gameId: string
}

export interface OpeningExplorerApiOpeningExplorerPlayerRequest {
    /**
     * Variant
     * @type VariantKey
     * @memberof OpeningExplorerApiopeningExplorerPlayer
     */
    variant?: VariantKey
    /**
     * FEN of the root position
     * @type string
     * @memberof OpeningExplorerApiopeningExplorerPlayer
     */
    fen?: string
    /**
     * Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position. 
     * @type string
     * @memberof OpeningExplorerApiopeningExplorerPlayer
     */
    play?: string
    /**
     * Comma separated list of game speeds to look for
     * @type Array&lt;Speed&gt;
     * @memberof OpeningExplorerApiopeningExplorerPlayer
     */
    speeds?: Array<Speed>
    /**
     * Comma separated list of modes
     * @type Array&lt;&#39;casual&#39; | &#39;rated&#39;&gt;
     * @memberof OpeningExplorerApiopeningExplorerPlayer
     */
    modes?: Array<'casual' | 'rated'>
    /**
     * Include only games from this month or later
     * @type string
     * @memberof OpeningExplorerApiopeningExplorerPlayer
     */
    since?: string
    /**
     * Include only games from this month or earlier
     * @type string
     * @memberof OpeningExplorerApiopeningExplorerPlayer
     */
    until?: string
    /**
     * Number of most common moves to display
     * @type number
     * @memberof OpeningExplorerApiopeningExplorerPlayer
     */
    moves?: number
    /**
     * Number of recent games to display
     * @type number
     * @memberof OpeningExplorerApiopeningExplorerPlayer
     */
    recentGames?: number
}

export class ObjectOpeningExplorerApi {
    private api: ObservableOpeningExplorerApi

    public constructor(configuration: Configuration, requestFactory?: OpeningExplorerApiRequestFactory, responseProcessor?: OpeningExplorerApiResponseProcessor) {
        this.api = new ObservableOpeningExplorerApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * **Endpoint: <https://explorer.lichess.ovh/lichess>**  Games sampled from all Lichess players.  Example: `curl https://explorer.lichess.ovh/lichess?variant=standard&speeds=blitz,rapid,classical&ratings=2200,2500&fen=rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR%20w%20KQkq%20-%200%201` 
     * Lichess games
     * @param param the request object
     */
    public openingExplorerLichess(param: OpeningExplorerApiOpeningExplorerLichessRequest, options?: Configuration): Promise<any> {
        return this.api.openingExplorerLichess(param.variant, param.fen, param.play, param.speeds, param.ratings, param.since, param.until, param.moves, param.topGames, param.recentGames,  options).toPromise();
    }

    /**
     * **Endpoint: <https://explorer.lichess.ovh/masters>**  Example: `curl https://explorer.lichess.ovh/masters?play=d2d4,d7d5,c2c4,c7c6,c4d5` 
     * Masters database
     * @param param the request object
     */
    public openingExplorerMaster(param: OpeningExplorerApiOpeningExplorerMasterRequest, options?: Configuration): Promise<any> {
        return this.api.openingExplorerMaster(param.fen, param.play, param.since, param.until, param.moves, param.topGames,  options).toPromise();
    }

    /**
     * **Endpoint: `https://explorer.lichess.ovh/masters/pgn/{gameId}`**  Example: `curl https://explorer.lichess.ovh/masters/pgn/aAbqI4ey` 
     * OTB master game
     * @param param the request object
     */
    public openingExplorerMasterGame(param: OpeningExplorerApiOpeningExplorerMasterGameRequest, options?: Configuration): Promise<any> {
        return this.api.openingExplorerMasterGame(param.gameId,  options).toPromise();
    }

    /**
     * **Endpoint: <https://explorer.lichess.ovh/player>**  Games of a Lichess player.  Responds with a stream of newline delimited JSON. Will start indexing on demand, immediately respond with the current results, and stream more updates until indexing is complete. The stream is throttled and deduplicated. Empty lines may be sent to avoid timeouts.  Will index new games at most once per minute, and revisit previously ongoing games at most once every day.  Example: `curl https://explorer.lichess.ovh/player?player=revoof&color=white&play=d2d4,d7d5&recentGames=1` 
     * Player games
     * @param param the request object
     */
    public openingExplorerPlayer(param: OpeningExplorerApiOpeningExplorerPlayerRequest, options?: Configuration): Promise<any> {
        return this.api.openingExplorerPlayer(param.variant, param.fen, param.play, param.speeds, param.modes, param.since, param.until, param.moves, param.recentGames,  options).toPromise();
    }

}

import { ObservablePuzzlesApi } from "./ObservableAPI";
import { PuzzlesApiRequestFactory, PuzzlesApiResponseProcessor} from "../apis/PuzzlesApi";

export interface PuzzlesApiApiPuzzleActivityRequest {
    /**
     * How many entries to download. Leave empty to download all activity.
     * @type number
     * @memberof PuzzlesApiapiPuzzleActivity
     */
    max?: number
}

export interface PuzzlesApiApiPuzzleDailyRequest {
}

export interface PuzzlesApiApiPuzzleDashboardRequest {
    /**
     * How many days to look back when aggregating puzzle results. 30 is sensible.
     * @type number
     * @memberof PuzzlesApiapiPuzzleDashboard
     */
    days: number
}

export interface PuzzlesApiApiStormDashboardRequest {
    /**
     * Username of the player
     * @type string
     * @memberof PuzzlesApiapiStormDashboard
     */
    username: string
    /**
     * How many days of history to return
     * @type number
     * @memberof PuzzlesApiapiStormDashboard
     */
    days?: number
}

export class ObjectPuzzlesApi {
    private api: ObservablePuzzlesApi

    public constructor(configuration: Configuration, requestFactory?: PuzzlesApiRequestFactory, responseProcessor?: PuzzlesApiResponseProcessor) {
        this.api = new ObservablePuzzlesApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Download your puzzle activity in [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Puzzle activity is sorted by reverse chronological order (most recent first)  We recommend streaming the response, for it can be very long. 
     * Get your puzzle activity
     * @param param the request object
     */
    public apiPuzzleActivity(param: PuzzlesApiApiPuzzleActivityRequest, options?: Configuration): Promise<PuzzleRoundJson> {
        return this.api.apiPuzzleActivity(param.max,  options).toPromise();
    }

    /**
     * Get the daily Lichess puzzle in JSON format.  Alternatively, you can [post it in your slack workspace](https://lichess.org/daily-puzzle-slack). 
     * Get the daily puzzle
     * @param param the request object
     */
    public apiPuzzleDaily(param: PuzzlesApiApiPuzzleDailyRequest, options?: Configuration): Promise<any> {
        return this.api.apiPuzzleDaily( options).toPromise();
    }

    /**
     * Download your [puzzle dashboard](https://lichess.org/training/dashboard/30/dashboard) as JSON.  Also includes all puzzle themes played, with aggregated results.  Allows re-creating the [improvement/strengths](https://lichess.org/training/dashboard/30/improvementAreas) interfaces. 
     * Get your puzzle dashboard
     * @param param the request object
     */
    public apiPuzzleDashboard(param: PuzzlesApiApiPuzzleDashboardRequest, options?: Configuration): Promise<any> {
        return this.api.apiPuzzleDashboard(param.days,  options).toPromise();
    }

    /**
     * Download the [storm dashboard](https://lichess.org/storm/dashboard/mrbasso) of any player as JSON.  Contains the aggregated highscores, and the history of storm runs aggregated by days.  Use `?days=0` if you only care about the highscores. 
     * Get the storm dashboard of a player
     * @param param the request object
     */
    public apiStormDashboard(param: PuzzlesApiApiStormDashboardRequest, options?: Configuration): Promise<any> {
        return this.api.apiStormDashboard(param.username, param.days,  options).toPromise();
    }

}

import { ObservableRelationsApi } from "./ObservableAPI";
import { RelationsApiRequestFactory, RelationsApiResponseProcessor} from "../apis/RelationsApi";

export interface RelationsApiApiUserFollowingRequest {
}

export interface RelationsApiFollowUserRequest {
    /**
     * 
     * @type string
     * @memberof RelationsApifollowUser
     */
    username: string
}

export interface RelationsApiUnfollowUserRequest {
    /**
     * 
     * @type string
     * @memberof RelationsApiunfollowUser
     */
    username: string
}

export class ObjectRelationsApi {
    private api: ObservableRelationsApi

    public constructor(configuration: Configuration, requestFactory?: RelationsApiRequestFactory, responseProcessor?: RelationsApiResponseProcessor) {
        this.api = new ObservableRelationsApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Users are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get users followed the logged in user
     * @param param the request object
     */
    public apiUserFollowing(param: RelationsApiApiUserFollowingRequest, options?: Configuration): Promise<UserExtended> {
        return this.api.apiUserFollowing( options).toPromise();
    }

    /**
     * Follow a player, adding them to your list of Lichess friends. 
     * Follow a player
     * @param param the request object
     */
    public followUser(param: RelationsApiFollowUserRequest, options?: Configuration): Promise<Ok> {
        return this.api.followUser(param.username,  options).toPromise();
    }

    /**
     * Unfollow a player, removing them from your list of Lichess friends. 
     * Unfollow a player
     * @param param the request object
     */
    public unfollowUser(param: RelationsApiUnfollowUserRequest, options?: Configuration): Promise<Ok> {
        return this.api.unfollowUser(param.username,  options).toPromise();
    }

}

import { ObservableSimulsApi } from "./ObservableAPI";
import { SimulsApiRequestFactory, SimulsApiResponseProcessor} from "../apis/SimulsApi";

export interface SimulsApiApiSimulRequest {
}

export class ObjectSimulsApi {
    private api: ObservableSimulsApi

    public constructor(configuration: Configuration, requestFactory?: SimulsApiRequestFactory, responseProcessor?: SimulsApiResponseProcessor) {
        this.api = new ObservableSimulsApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Get recently finished, ongoing, and upcoming simuls. 
     * Get current simuls
     * @param param the request object
     */
    public apiSimul(param: SimulsApiApiSimulRequest, options?: Configuration): Promise<Array<any>> {
        return this.api.apiSimul( options).toPromise();
    }

}

import { ObservableStudiesApi } from "./ObservableAPI";
import { StudiesApiRequestFactory, StudiesApiResponseProcessor} from "../apis/StudiesApi";

export interface StudiesApiStudyAllChaptersPgnRequest {
    /**
     * The study ID (8 characters).
     * @type string
     * @memberof StudiesApistudyAllChaptersPgn
     */
    studyId: string
    /**
     * Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @type boolean
     * @memberof StudiesApistudyAllChaptersPgn
     */
    clocks?: boolean
    /**
     * Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60; 
     * @type boolean
     * @memberof StudiesApistudyAllChaptersPgn
     */
    comments?: boolean
    /**
     * Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60; 
     * @type boolean
     * @memberof StudiesApistudyAllChaptersPgn
     */
    variations?: boolean
}

export interface StudiesApiStudyChapterPgnRequest {
    /**
     * The study ID (8 characters).
     * @type string
     * @memberof StudiesApistudyChapterPgn
     */
    studyId: string
    /**
     * The chapter ID (8 characters).
     * @type string
     * @memberof StudiesApistudyChapterPgn
     */
    chapterId: string
    /**
     * Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @type boolean
     * @memberof StudiesApistudyChapterPgn
     */
    clocks?: boolean
    /**
     * Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60; 
     * @type boolean
     * @memberof StudiesApistudyChapterPgn
     */
    comments?: boolean
    /**
     * Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60; 
     * @type boolean
     * @memberof StudiesApistudyChapterPgn
     */
    variations?: boolean
}

export interface StudiesApiStudyExportAllPgnRequest {
    /**
     * The user whose studies we export
     * @type string
     * @memberof StudiesApistudyExportAllPgn
     */
    username: string
    /**
     * Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @type boolean
     * @memberof StudiesApistudyExportAllPgn
     */
    clocks?: boolean
    /**
     * Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60; 
     * @type boolean
     * @memberof StudiesApistudyExportAllPgn
     */
    comments?: boolean
    /**
     * Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60; 
     * @type boolean
     * @memberof StudiesApistudyExportAllPgn
     */
    variations?: boolean
}

export class ObjectStudiesApi {
    private api: ObservableStudiesApi

    public constructor(configuration: Configuration, requestFactory?: StudiesApiRequestFactory, responseProcessor?: StudiesApiResponseProcessor) {
        this.api = new ObservableStudiesApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Download all chapters of a study in PGN format. 
     * Export all chapters
     * @param param the request object
     */
    public studyAllChaptersPgn(param: StudiesApiStudyAllChaptersPgnRequest, options?: Configuration): Promise<any> {
        return this.api.studyAllChaptersPgn(param.studyId, param.clocks, param.comments, param.variations,  options).toPromise();
    }

    /**
     * Download one study chapter in PGN format. 
     * Export one study chapter
     * @param param the request object
     */
    public studyChapterPgn(param: StudiesApiStudyChapterPgnRequest, options?: Configuration): Promise<any> {
        return this.api.studyChapterPgn(param.studyId, param.chapterId, param.clocks, param.comments, param.variations,  options).toPromise();
    }

    /**
     * Download all chapters of all studies of a user in PGN format.  If authenticated, then all public, unlisted, and private studies are included.  If not, only public, listed studies are included. 
     * Export all studies of a user
     * @param param the request object
     */
    public studyExportAllPgn(param: StudiesApiStudyExportAllPgnRequest, options?: Configuration): Promise<any> {
        return this.api.studyExportAllPgn(param.username, param.clocks, param.comments, param.variations,  options).toPromise();
    }

}

import { ObservableSwissTournamentsApi } from "./ObservableAPI";
import { SwissTournamentsApiRequestFactory, SwissTournamentsApiResponseProcessor} from "../apis/SwissTournamentsApi";

export interface SwissTournamentsApiApiSwissJoinRequest {
    /**
     * The tournament ID.
     * @type string
     * @memberof SwissTournamentsApiapiSwissJoin
     */
    id: string
    /**
     * The tournament password, if one is required
     * @type string
     * @memberof SwissTournamentsApiapiSwissJoin
     */
    password?: string
}

export interface SwissTournamentsApiApiSwissNewRequest {
    /**
     * ID of the team
     * @type string
     * @memberof SwissTournamentsApiapiSwissNew
     */
    teamId: string
    /**
     * Clock initial time in seconds
     * @type number
     * @memberof SwissTournamentsApiapiSwissNew
     */
    clockLimit: number
    /**
     * Clock increment in seconds
     * @type number
     * @memberof SwissTournamentsApiapiSwissNew
     */
    clockIncrement: number
    /**
     * Maximum number of rounds to play
     * @type number
     * @memberof SwissTournamentsApiapiSwissNew
     */
    nbRounds: number
    /**
     * The tournament name. Leave empty to get a random Grandmaster name
     * @type string
     * @memberof SwissTournamentsApiapiSwissNew
     */
    name?: string
    /**
     * Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation.
     * @type number
     * @memberof SwissTournamentsApiapiSwissNew
     */
    startsAt?: number
    /**
     * How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI. 
     * @type number
     * @memberof SwissTournamentsApiapiSwissNew
     */
    roundInterval?: number
    /**
     * 
     * @type VariantKey
     * @memberof SwissTournamentsApiapiSwissNew
     */
    variant?: VariantKey
    /**
     * Anything you want to tell players about the tournament
     * @type string
     * @memberof SwissTournamentsApiapiSwissNew
     */
    description?: string
    /**
     * Games are rated and impact players ratings
     * @type boolean
     * @memberof SwissTournamentsApiapiSwissNew
     */
    rated?: boolean
    /**
     * Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players 
     * @type number
     * @memberof SwissTournamentsApiapiSwissNew
     */
    chatFor?: number
}

export interface SwissTournamentsApiApiSwissTerminateRequest {
    /**
     * The Swiss tournament ID.
     * @type string
     * @memberof SwissTournamentsApiapiSwissTerminate
     */
    id: string
}

export interface SwissTournamentsApiApiSwissUpdateRequest {
    /**
     * The tournament ID.
     * @type string
     * @memberof SwissTournamentsApiapiSwissUpdate
     */
    id: string
    /**
     * Clock initial time in seconds
     * @type number
     * @memberof SwissTournamentsApiapiSwissUpdate
     */
    clockLimit: number
    /**
     * Clock increment in seconds
     * @type number
     * @memberof SwissTournamentsApiapiSwissUpdate
     */
    clockIncrement: number
    /**
     * Maximum number of rounds to play
     * @type number
     * @memberof SwissTournamentsApiapiSwissUpdate
     */
    nbRounds: number
    /**
     * The tournament name. Leave empty to get a random Grandmaster name
     * @type string
     * @memberof SwissTournamentsApiapiSwissUpdate
     */
    name?: string
    /**
     * Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation.
     * @type number
     * @memberof SwissTournamentsApiapiSwissUpdate
     */
    startsAt?: number
    /**
     * How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI. 
     * @type number
     * @memberof SwissTournamentsApiapiSwissUpdate
     */
    roundInterval?: number
    /**
     * 
     * @type VariantKey
     * @memberof SwissTournamentsApiapiSwissUpdate
     */
    variant?: VariantKey
    /**
     * Anything you want to tell players about the tournament
     * @type string
     * @memberof SwissTournamentsApiapiSwissUpdate
     */
    description?: string
    /**
     * Games are rated and impact players ratings
     * @type boolean
     * @memberof SwissTournamentsApiapiSwissUpdate
     */
    rated?: boolean
    /**
     * Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players 
     * @type number
     * @memberof SwissTournamentsApiapiSwissUpdate
     */
    chatFor?: number
}

export interface SwissTournamentsApiApiTeamSwissRequest {
    /**
     * 
     * @type string
     * @memberof SwissTournamentsApiapiTeamSwiss
     */
    teamId: string
    /**
     * How many tournaments to download.
     * @type number
     * @memberof SwissTournamentsApiapiTeamSwiss
     */
    max?: number
}

export interface SwissTournamentsApiGamesBySwissRequest {
    /**
     * The tournament ID.
     * @type string
     * @memberof SwissTournamentsApigamesBySwiss
     */
    id: string
    /**
     * Include the PGN moves.
     * @type boolean
     * @memberof SwissTournamentsApigamesBySwiss
     */
    moves?: boolean
    /**
     * Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @type boolean
     * @memberof SwissTournamentsApigamesBySwiss
     */
    pgnInJson?: boolean
    /**
     * Include the PGN tags.
     * @type boolean
     * @memberof SwissTournamentsApigamesBySwiss
     */
    tags?: boolean
    /**
     * Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @type boolean
     * @memberof SwissTournamentsApigamesBySwiss
     */
    clocks?: boolean
    /**
     * Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @type boolean
     * @memberof SwissTournamentsApigamesBySwiss
     */
    evals?: boolean
    /**
     * Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     * @type boolean
     * @memberof SwissTournamentsApigamesBySwiss
     */
    opening?: boolean
}

export interface SwissTournamentsApiResultsBySwissRequest {
    /**
     * The tournament ID.
     * @type string
     * @memberof SwissTournamentsApiresultsBySwiss
     */
    id: string
    /**
     * Max number of players to fetch
     * @type number
     * @memberof SwissTournamentsApiresultsBySwiss
     */
    nb?: number
}

export interface SwissTournamentsApiSwissTrfRequest {
    /**
     * The tournament ID.
     * @type string
     * @memberof SwissTournamentsApiswissTrf
     */
    id: string
}

export class ObjectSwissTournamentsApi {
    private api: ObservableSwissTournamentsApi

    public constructor(configuration: Configuration, requestFactory?: SwissTournamentsApiRequestFactory, responseProcessor?: SwissTournamentsApiResponseProcessor) {
        this.api = new ObservableSwissTournamentsApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Join a Swiss tournament, possibly with a password. 
     * Join a Swiss tournament
     * @param param the request object
     */
    public apiSwissJoin(param: SwissTournamentsApiApiSwissJoinRequest, options?: Configuration): Promise<Ok> {
        return this.api.apiSwissJoin(param.id, param.password,  options).toPromise();
    }

    /**
     * Create a Swiss tournament for your team.  This endpoint mirrors the Swiss tournament form from your team pagee.  You can create up to 12 tournaments per day. 
     * Create a new Swiss tournament
     * @param param the request object
     */
    public apiSwissNew(param: SwissTournamentsApiApiSwissNewRequest, options?: Configuration): Promise<any> {
        return this.api.apiSwissNew(param.teamId, param.clockLimit, param.clockIncrement, param.nbRounds, param.name, param.startsAt, param.roundInterval, param.variant, param.description, param.rated, param.chatFor,  options).toPromise();
    }

    /**
     * Terminate a Swiss tournament 
     * Terminate a Swiss tournament
     * @param param the request object
     */
    public apiSwissTerminate(param: SwissTournamentsApiApiSwissTerminateRequest, options?: Configuration): Promise<Ok> {
        return this.api.apiSwissTerminate(param.id,  options).toPromise();
    }

    /**
     * Update a Swiss tournament.  Be mindful not to make important changes to ongoing tournaments. 
     * Update a Swiss tournament.
     * @param param the request object
     */
    public apiSwissUpdate(param: SwissTournamentsApiApiSwissUpdateRequest, options?: Configuration): Promise<any> {
        return this.api.apiSwissUpdate(param.id, param.clockLimit, param.clockIncrement, param.nbRounds, param.name, param.startsAt, param.roundInterval, param.variant, param.description, param.rated, param.chatFor,  options).toPromise();
    }

    /**
     * Get all swiss tournaments of a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get team swiss tournaments
     * @param param the request object
     */
    public apiTeamSwiss(param: SwissTournamentsApiApiTeamSwissRequest, options?: Configuration): Promise<Array<any>> {
        return this.api.apiTeamSwiss(param.teamId, param.max,  options).toPromise();
    }

    /**
     * Download games of a swiss tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (last round first) 
     * Export games of a Swiss tournament
     * @param param the request object
     */
    public gamesBySwiss(param: SwissTournamentsApiGamesBySwissRequest, options?: Configuration): Promise<any> {
        return this.api.gamesBySwiss(param.id, param.moves, param.pgnInJson, param.tags, param.clocks, param.evals, param.opening,  options).toPromise();
    }

    /**
     * Players of a swiss tournament, with their score and performance, sorted by rank (best first).  Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 
     * Get results of a swiss tournament
     * @param param the request object
     */
    public resultsBySwiss(param: SwissTournamentsApiResultsBySwissRequest, options?: Configuration): Promise<any> {
        return this.api.resultsBySwiss(param.id, param.nb,  options).toPromise();
    }

    /**
     * Download a tournament in the Tournament Report File format, the FIDE standard.  Documentation: <https://www.fide.com/FIDE/handbook/C04Annex2_TRF16.pdf>  Example: <https://lichess.org/swiss/j8rtJ5GL.trf> 
     * Export TRF of a Swiss tournament
     * @param param the request object
     */
    public swissTrf(param: SwissTournamentsApiSwissTrfRequest, options?: Configuration): Promise<string> {
        return this.api.swissTrf(param.id,  options).toPromise();
    }

}

import { ObservableTVApi } from "./ObservableAPI";
import { TVApiRequestFactory, TVApiResponseProcessor} from "../apis/TVApi";

export interface TVApiTvChannelGamesRequest {
    /**
     * The name of the channel in lowercase.
     * @type string
     * @memberof TVApitvChannelGames
     */
    channel: string
    /**
     * Number of games to fetch.
     * @type number
     * @memberof TVApitvChannelGames
     */
    nb?: number
    /**
     * Include the PGN moves.
     * @type boolean
     * @memberof TVApitvChannelGames
     */
    moves?: boolean
    /**
     * Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @type boolean
     * @memberof TVApitvChannelGames
     */
    pgnInJson?: boolean
    /**
     * Include the PGN tags.
     * @type boolean
     * @memberof TVApitvChannelGames
     */
    tags?: boolean
    /**
     * Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @type boolean
     * @memberof TVApitvChannelGames
     */
    clocks?: boolean
    /**
     * Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     * @type boolean
     * @memberof TVApitvChannelGames
     */
    opening?: boolean
}

export interface TVApiTvChannelsRequest {
}

export interface TVApiTvFeedRequest {
}

export class ObjectTVApi {
    private api: ObservableTVApi

    public constructor(configuration: Configuration, requestFactory?: TVApiRequestFactory, responseProcessor?: TVApiResponseProcessor) {
        this.api = new ObservableTVApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Get a list of ongoing games for a given TV channel. Similar to [lichess.org/games](https://lichess.org/games).  Available in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format, depending on the request Accept header. 
     * Get best ongoing games of a TV channel
     * @param param the request object
     */
    public tvChannelGames(param: TVApiTvChannelGamesRequest, options?: Configuration): Promise<any> {
        return this.api.tvChannelGames(param.channel, param.nb, param.moves, param.pgnInJson, param.tags, param.clocks, param.opening,  options).toPromise();
    }

    /**
     * Get basic info about the best games being played for each speed and variant, but also computer games and bot games.  See [lichess.org/tv](https://lichess.org/tv). 
     * Get current TV games
     * @param param the request object
     */
    public tvChannels(param: TVApiTvChannelsRequest, options?: Configuration): Promise<any> {
        return this.api.tvChannels( options).toPromise();
    }

    /**
     * Stream positions and moves of the current [TV game](https://lichess.org/tv) in [ndjson](#section/Introduction/Streaming-with-ND-JSON). A summary of the game is sent as a first message, and when the featured game changes.  Try it with `curl https://lichess.org/api/tv/feed`. 
     * Stream current TV game
     * @param param the request object
     */
    public tvFeed(param: TVApiTvFeedRequest, options?: Configuration): Promise<any> {
        return this.api.tvFeed( options).toPromise();
    }

}

import { ObservableTablebaseApi } from "./ObservableAPI";
import { TablebaseApiRequestFactory, TablebaseApiResponseProcessor} from "../apis/TablebaseApi";

export interface TablebaseApiAntichessAtomicRequest {
}

export interface TablebaseApiTablebaseAtomicRequest {
}

export interface TablebaseApiTablebaseStandardRequest {
    /**
     * FEN of the position. Underscores allowed.
     * @type string
     * @memberof TablebaseApitablebaseStandard
     */
    fen: string
}

export class ObjectTablebaseApi {
    private api: ObservableTablebaseApi

    public constructor(configuration: Configuration, requestFactory?: TablebaseApiRequestFactory, responseProcessor?: TablebaseApiResponseProcessor) {
        this.api = new ObservableTablebaseApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Tablebase lookup for Antichess
     * @param param the request object
     */
    public antichessAtomic(param: TablebaseApiAntichessAtomicRequest, options?: Configuration): Promise<string> {
        return this.api.antichessAtomic( options).toPromise();
    }

    /**
     * Tablebase lookup for Atomic chess
     * @param param the request object
     */
    public tablebaseAtomic(param: TablebaseApiTablebaseAtomicRequest, options?: Configuration): Promise<string> {
        return this.api.tablebaseAtomic( options).toPromise();
    }

    /**
     * **Endpoint: <https://tablebase.lichess.ovh>**  Example: `curl http://tablebase.lichess.ovh/standard?fen=4k3/6KP/8/8/8/8/7p/8_w_-_-_0_1` 
     * Tablebase lookup
     * @param param the request object
     */
    public tablebaseStandard(param: TablebaseApiTablebaseStandardRequest, options?: Configuration): Promise<TablebaseJson> {
        return this.api.tablebaseStandard(param.fen,  options).toPromise();
    }

}

import { ObservableTeamsApi } from "./ObservableAPI";
import { TeamsApiRequestFactory, TeamsApiResponseProcessor} from "../apis/TeamsApi";

export interface TeamsApiApiTeamArenaRequest {
    /**
     * ID of the team
     * @type string
     * @memberof TeamsApiapiTeamArena
     */
    teamId: string
    /**
     * How many tournaments to download.
     * @type number
     * @memberof TeamsApiapiTeamArena
     */
    max?: number
}

export interface TeamsApiApiTeamSwissRequest {
    /**
     * 
     * @type string
     * @memberof TeamsApiapiTeamSwiss
     */
    teamId: string
    /**
     * How many tournaments to download.
     * @type number
     * @memberof TeamsApiapiTeamSwiss
     */
    max?: number
}

export interface TeamsApiTeamAllRequest {
    /**
     * 
     * @type number
     * @memberof TeamsApiteamAll
     */
    page?: number
}

export interface TeamsApiTeamIdJoinRequest {
    /**
     * 
     * @type string
     * @memberof TeamsApiteamIdJoin
     */
    teamId: string
    /**
     * Optional request message, if the team requires one.
     * @type string
     * @memberof TeamsApiteamIdJoin
     */
    message?: string
    /**
     * Optional password, if the team requires one.
     * @type string
     * @memberof TeamsApiteamIdJoin
     */
    password?: string
}

export interface TeamsApiTeamIdKickUserIdRequest {
    /**
     * 
     * @type string
     * @memberof TeamsApiteamIdKickUserId
     */
    teamId: string
    /**
     * 
     * @type string
     * @memberof TeamsApiteamIdKickUserId
     */
    userId: string
}

export interface TeamsApiTeamIdPmAllRequest {
    /**
     * 
     * @type string
     * @memberof TeamsApiteamIdPmAll
     */
    teamId: string
    /**
     * The message to send to all your team members.
     * @type string
     * @memberof TeamsApiteamIdPmAll
     */
    message?: string
}

export interface TeamsApiTeamIdQuitRequest {
    /**
     * 
     * @type string
     * @memberof TeamsApiteamIdQuit
     */
    teamId: string
}

export interface TeamsApiTeamIdUsersRequest {
    /**
     * 
     * @type string
     * @memberof TeamsApiteamIdUsers
     */
    teamId: string
}

export interface TeamsApiTeamOfUsernameRequest {
    /**
     * 
     * @type string
     * @memberof TeamsApiteamOfUsername
     */
    username: string
}

export interface TeamsApiTeamSearchRequest {
    /**
     * 
     * @type string
     * @memberof TeamsApiteamSearch
     */
    text?: string
    /**
     * 
     * @type number
     * @memberof TeamsApiteamSearch
     */
    page?: number
}

export interface TeamsApiTeamShowRequest {
    /**
     * 
     * @type string
     * @memberof TeamsApiteamShow
     */
    teamId: string
}

export class ObjectTeamsApi {
    private api: ObservableTeamsApi

    public constructor(configuration: Configuration, requestFactory?: TeamsApiRequestFactory, responseProcessor?: TeamsApiResponseProcessor) {
        this.api = new ObservableTeamsApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get team Arena tournaments
     * @param param the request object
     */
    public apiTeamArena(param: TeamsApiApiTeamArenaRequest, options?: Configuration): Promise<Array<any>> {
        return this.api.apiTeamArena(param.teamId, param.max,  options).toPromise();
    }

    /**
     * Get all swiss tournaments of a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get team swiss tournaments
     * @param param the request object
     */
    public apiTeamSwiss(param: TeamsApiApiTeamSwissRequest, options?: Configuration): Promise<Array<any>> {
        return this.api.apiTeamSwiss(param.teamId, param.max,  options).toPromise();
    }

    /**
     * Paginator of the most popular teams. 
     * Get popular teams
     * @param param the request object
     */
    public teamAll(param: TeamsApiTeamAllRequest, options?: Configuration): Promise<InlineResponse2001> {
        return this.api.teamAll(param.page,  options).toPromise();
    }

    /**
     * Join a team. If the team requires a password but the `password` field is incorrect, then the call fails with `403 Forbidden`. Similarly, if the team join policy requires a confirmation but the `message` parameter is not given, then the call fails with `403 Forbidden`. 
     * Join a team
     * @param param the request object
     */
    public teamIdJoin(param: TeamsApiTeamIdJoinRequest, options?: Configuration): Promise<Ok> {
        return this.api.teamIdJoin(param.teamId, param.message, param.password,  options).toPromise();
    }

    /**
     * Kick a member out of one of your teams. - <https://lichess.org/team> 
     * Kick a user from your team
     * @param param the request object
     */
    public teamIdKickUserId(param: TeamsApiTeamIdKickUserIdRequest, options?: Configuration): Promise<Ok> {
        return this.api.teamIdKickUserId(param.teamId, param.userId,  options).toPromise();
    }

    /**
     * Send a private message to all members of a team. You must own the team. 
     * Message all members
     * @param param the request object
     */
    public teamIdPmAll(param: TeamsApiTeamIdPmAllRequest, options?: Configuration): Promise<Ok> {
        return this.api.teamIdPmAll(param.teamId, param.message,  options).toPromise();
    }

    /**
     * Leave a team. - <https://lichess.org/team> 
     * Leave a team
     * @param param the request object
     */
    public teamIdQuit(param: TeamsApiTeamIdQuitRequest, options?: Configuration): Promise<Ok> {
        return this.api.teamIdQuit(param.teamId,  options).toPromise();
    }

    /**
     * Members are sorted by reverse chronological order of joining the team (most recent first). OAuth only required if the list of members is private.  Members are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get members of a team
     * @param param the request object
     */
    public teamIdUsers(param: TeamsApiTeamIdUsersRequest, options?: Configuration): Promise<UserExtended> {
        return this.api.teamIdUsers(param.teamId,  options).toPromise();
    }

    /**
     * All the teams a player is a member of. 
     * Teams of a player
     * @param param the request object
     */
    public teamOfUsername(param: TeamsApiTeamOfUsernameRequest, options?: Configuration): Promise<Array<Team>> {
        return this.api.teamOfUsername(param.username,  options).toPromise();
    }

    /**
     * Paginator of team search results for a keyword. 
     * Search teams
     * @param param the request object
     */
    public teamSearch(param: TeamsApiTeamSearchRequest, options?: Configuration): Promise<Array<Team>> {
        return this.api.teamSearch(param.text, param.page,  options).toPromise();
    }

    /**
     * Infos about a team
     * Get a single team
     * @param param the request object
     */
    public teamShow(param: TeamsApiTeamShowRequest, options?: Configuration): Promise<Team> {
        return this.api.teamShow(param.teamId,  options).toPromise();
    }

}

import { ObservableUsersApi } from "./ObservableAPI";
import { UsersApiRequestFactory, UsersApiResponseProcessor} from "../apis/UsersApi";

export interface UsersApiApiCrosstableRequest {
    /**
     * 
     * @type string
     * @memberof UsersApiapiCrosstable
     */
    user1: string
    /**
     * 
     * @type string
     * @memberof UsersApiapiCrosstable
     */
    user2: string
    /**
     * Whether to get the current match data, if any
     * @type boolean
     * @memberof UsersApiapiCrosstable
     */
    matchup?: boolean
}

export interface UsersApiApiUserRequest {
    /**
     * 
     * @type string
     * @memberof UsersApiapiUser
     */
    username: string
}

export interface UsersApiApiUserActivityRequest {
    /**
     * 
     * @type string
     * @memberof UsersApiapiUserActivity
     */
    username: string
}

export interface UsersApiApiUserPerfRequest {
    /**
     * 
     * @type string
     * @memberof UsersApiapiUserPerf
     */
    username: string
    /**
     * 
     * @type PerfType
     * @memberof UsersApiapiUserPerf
     */
    perf: PerfType
}

export interface UsersApiApiUserRatingHistoryRequest {
    /**
     * 
     * @type string
     * @memberof UsersApiapiUserRatingHistory
     */
    username: string
}

export interface UsersApiApiUsersRequest {
    /**
     * User IDs separated by commas.
     * @type string
     * @memberof UsersApiapiUsers
     */
    body: string
}

export interface UsersApiApiUsersStatusRequest {
    /**
     * User IDs separated by commas. Up to 100 IDs.
     * @type string
     * @memberof UsersApiapiUsersStatus
     */
    ids: string
}

export interface UsersApiPlayerRequest {
}

export interface UsersApiPlayerTopNbPerfTypeRequest {
    /**
     * How many users to fetch
     * @type number
     * @memberof UsersApiplayerTopNbPerfType
     */
    nb: number
    /**
     * The speed or variant
     * @type &#39;ultraBullet&#39; | &#39;bullet&#39; | &#39;blitz&#39; | &#39;rapid&#39; | &#39;classical&#39; | &#39;chess960&#39; | &#39;crazyhouse&#39; | &#39;antichess&#39; | &#39;atomic&#39; | &#39;horde&#39; | &#39;kingOfTheHill&#39; | &#39;racingKings&#39; | &#39;threeCheck&#39;
     * @memberof UsersApiplayerTopNbPerfType
     */
    perfType: 'ultraBullet' | 'bullet' | 'blitz' | 'rapid' | 'classical' | 'chess960' | 'crazyhouse' | 'antichess' | 'atomic' | 'horde' | 'kingOfTheHill' | 'racingKings' | 'threeCheck'
}

export interface UsersApiStreamerLiveRequest {
}

export interface UsersApiTeamIdUsersRequest {
    /**
     * 
     * @type string
     * @memberof UsersApiteamIdUsers
     */
    teamId: string
}

export class ObjectUsersApi {
    private api: ObservableUsersApi

    public constructor(configuration: Configuration, requestFactory?: UsersApiRequestFactory, responseProcessor?: UsersApiResponseProcessor) {
        this.api = new ObservableUsersApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Get total number of games, and current score, of any two users.  If the `matchup` flag is provided, and the users are currently playing, also gets the current match game number and scores. 
     * Get crosstable
     * @param param the request object
     */
    public apiCrosstable(param: UsersApiApiCrosstableRequest, options?: Configuration): Promise<any> {
        return this.api.apiCrosstable(param.user1, param.user2, param.matchup,  options).toPromise();
    }

    /**
     * Read public data of a user. 
     * Get user public data
     * @param param the request object
     */
    public apiUser(param: UsersApiApiUserRequest, options?: Configuration): Promise<UserExtended> {
        return this.api.apiUser(param.username,  options).toPromise();
    }

    /**
     * Read data to generate the activity feed of a user. 
     * Get user activity
     * @param param the request object
     */
    public apiUserActivity(param: UsersApiApiUserActivityRequest, options?: Configuration): Promise<void> {
        return this.api.apiUserActivity(param.username,  options).toPromise();
    }

    /**
     * Read performance statistics of a user, for a single performance. Similar to the [performance pages on the website](https://lichess.org/@/thibault/perf/bullet). 
     * Get performance statistics of a user
     * @param param the request object
     */
    public apiUserPerf(param: UsersApiApiUserPerfRequest, options?: Configuration): Promise<any> {
        return this.api.apiUserPerf(param.username, param.perf,  options).toPromise();
    }

    /**
     * Read rating history of a user, for all perf types. There is at most one entry per day. Format of an entry is `[year, month, day, rating]`. `month` starts at zero (January). 
     * Get rating history of a user
     * @param param the request object
     */
    public apiUserRatingHistory(param: UsersApiApiUserRatingHistoryRequest, options?: Configuration): Promise<any> {
        return this.api.apiUserRatingHistory(param.username,  options).toPromise();
    }

    /**
     * Get up to 300 users by their IDs. Users are returned in the same order as the IDs.  The method is `POST` so a longer list of IDs can be sent in the request body. 
     * Get users by ID
     * @param param the request object
     */
    public apiUsers(param: UsersApiApiUsersRequest, options?: Configuration): Promise<Array<User>> {
        return this.api.apiUsers(param.body,  options).toPromise();
    }

    /**
     * Read the `online`, `playing` and `streaming` flags of several users.  This API is very fast and cheap on lichess side. So you can call it quite often (like once every 5 seconds).  Use it to track players and know when they're connected on lichess and playing games. 
     * Get real-time users status
     * @param param the request object
     */
    public apiUsersStatus(param: UsersApiApiUsersStatusRequest, options?: Configuration): Promise<Array<InlineResponse200>> {
        return this.api.apiUsersStatus(param.ids,  options).toPromise();
    }

    /**
     * Get the top 10 players for each speed and variant.  See <https://lichess.org/player>. 
     * Get all top 10
     * @param param the request object
     */
    public player(param: UsersApiPlayerRequest, options?: Configuration): Promise<any> {
        return this.api.player( options).toPromise();
    }

    /**
     * Get the leaderboard for a single speed or variant (a.k.a. `perfType`). There is no leaderboard for correspondence or puzzles.  See <https://lichess.org/player/top/200/bullet>. 
     * Get one leaderboard
     * @param param the request object
     */
    public playerTopNbPerfType(param: UsersApiPlayerTopNbPerfTypeRequest, options?: Configuration): Promise<any> {
        return this.api.playerTopNbPerfType(param.nb, param.perfType,  options).toPromise();
    }

    /**
     * Get basic info about currently streaming users.  This API is very fast and cheap on lichess side. So you can call it quite often (like once every 5 seconds). 
     * Get live streamers
     * @param param the request object
     */
    public streamerLive(param: UsersApiStreamerLiveRequest, options?: Configuration): Promise<Array<InlineResponse2002>> {
        return this.api.streamerLive( options).toPromise();
    }

    /**
     * Members are sorted by reverse chronological order of joining the team (most recent first). OAuth only required if the list of members is private.  Members are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get members of a team
     * @param param the request object
     */
    public teamIdUsers(param: UsersApiTeamIdUsersRequest, options?: Configuration): Promise<UserExtended> {
        return this.api.teamIdUsers(param.teamId,  options).toPromise();
    }

}
