import { ResponseContext, RequestContext, HttpFile } from '../http/http';
import * as models from '../models/all';
import { Configuration} from '../configuration'

import { ApiStreamEvent } from '../models/ApiStreamEvent';
import { ArenaTournaments } from '../models/ArenaTournaments';
import { ChallengeCanceledEvent } from '../models/ChallengeCanceledEvent';
import { ChallengeDeclinedEvent } from '../models/ChallengeDeclinedEvent';
import { ChallengeEvent } from '../models/ChallengeEvent';
import { ChallengeJson } from '../models/ChallengeJson';
import { ChallengeJsonPerf } from '../models/ChallengeJsonPerf';
import { ChallengeUser } from '../models/ChallengeUser';
import { ChatLineEvent } from '../models/ChatLineEvent';
import { Clock } from '../models/Clock';
import { Count } from '../models/Count';
import { GameEventInfo } from '../models/GameEventInfo';
import { GameEventInfoCompat } from '../models/GameEventInfoCompat';
import { GameEventPlayer } from '../models/GameEventPlayer';
import { GameFinishEvent } from '../models/GameFinishEvent';
import { GameFullEvent } from '../models/GameFullEvent';
import { GameFullEventPerf } from '../models/GameFullEventPerf';
import { GameJson } from '../models/GameJson';
import { GameJsonAnalysis } from '../models/GameJsonAnalysis';
import { GameJsonClock } from '../models/GameJsonClock';
import { GameJsonJudgment } from '../models/GameJsonJudgment';
import { GameJsonOpening } from '../models/GameJsonOpening';
import { GameJsonPlayers } from '../models/GameJsonPlayers';
import { GameStartEvent } from '../models/GameStartEvent';
import { GameStateEvent } from '../models/GameStateEvent';
import { GameStatus } from '../models/GameStatus';
import { GameStreamEvent } from '../models/GameStreamEvent';
import { GameUser } from '../models/GameUser';
import { GameUserAnalysis } from '../models/GameUserAnalysis';
import { InlineResponse200 } from '../models/InlineResponse200';
import { InlineResponse2001 } from '../models/InlineResponse2001';
import { InlineResponse2002 } from '../models/InlineResponse2002';
import { InlineResponse2003 } from '../models/InlineResponse2003';
import { LightUser } from '../models/LightUser';
import { ModelError } from '../models/ModelError';
import { Move } from '../models/Move';
import { NotFound } from '../models/NotFound';
import { Ok } from '../models/Ok';
import { Perf } from '../models/Perf';
import { PerfType } from '../models/PerfType';
import { Perfs } from '../models/Perfs';
import { PlayTime } from '../models/PlayTime';
import { Profile } from '../models/Profile';
import { PuzzleRoundJson } from '../models/PuzzleRoundJson';
import { Speed } from '../models/Speed';
import { StormPerf } from '../models/StormPerf';
import { SwissUnauthorisedEdit } from '../models/SwissUnauthorisedEdit';
import { TablebaseJson } from '../models/TablebaseJson';
import { Team } from '../models/Team';
import { TimeControl } from '../models/TimeControl';
import { TimeControlClock } from '../models/TimeControlClock';
import { TimeControlClockAllOf } from '../models/TimeControlClockAllOf';
import { TimeControlCorrespondence } from '../models/TimeControlCorrespondence';
import { TimeControlCorrespondenceAllOf } from '../models/TimeControlCorrespondenceAllOf';
import { TimeControlUnlimited } from '../models/TimeControlUnlimited';
import { Title } from '../models/Title';
import { User } from '../models/User';
import { UserExtended } from '../models/UserExtended';
import { UserExtendedAllOf } from '../models/UserExtendedAllOf';
import { UserPreferences } from '../models/UserPreferences';
import { Variant } from '../models/Variant';
import { VariantKey } from '../models/VariantKey';
import { ObservableAccountApi } from './ObservableAPI';

import { AccountApiRequestFactory, AccountApiResponseProcessor} from "../apis/AccountApi";
export class PromiseAccountApi {
    private api: ObservableAccountApi

    public constructor(
        configuration: Configuration,
        requestFactory?: AccountApiRequestFactory,
        responseProcessor?: AccountApiResponseProcessor
    ) {
        this.api = new ObservableAccountApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Read the preferences of the logged in user.  - <https://lichess.org/account/preferences/game-display> - <https://github.com/ornicar/lila/blob/master/modules/pref/src/main/Pref.scala> 
     * Get my preferences
     */
    public account(_options?: Configuration): Promise<any> {
        const result = this.api.account(_options);
        return result.toPromise();
    }

    /**
     * Read the email address of the logged in user. 
     * Get my email address
     */
    public accountEmail(_options?: Configuration): Promise<any> {
        const result = this.api.accountEmail(_options);
        return result.toPromise();
    }

    /**
     * Read the kid mode status of the logged in user.  - <https://lichess.org/account/kid> 
     * Get my kid mode status
     */
    public accountKid(_options?: Configuration): Promise<any> {
        const result = this.api.accountKid(_options);
        return result.toPromise();
    }

    /**
     * Set the kid mode status of the logged in user.  - <https://lichess.org/account/kid> 
     * Set my kid mode status
     * @param v Kid mode status
     */
    public accountKidPost(v: boolean, _options?: Configuration): Promise<Ok> {
        const result = this.api.accountKidPost(v, _options);
        return result.toPromise();
    }

    /**
     * Public informations about the logged in user. 
     * Get my profile
     */
    public accountMe(_options?: Configuration): Promise<UserExtended> {
        const result = this.api.accountMe(_options);
        return result.toPromise();
    }


}



import { ObservableAnalysisApi } from './ObservableAPI';

import { AnalysisApiRequestFactory, AnalysisApiResponseProcessor} from "../apis/AnalysisApi";
export class PromiseAnalysisApi {
    private api: ObservableAnalysisApi

    public constructor(
        configuration: Configuration,
        requestFactory?: AnalysisApiRequestFactory,
        responseProcessor?: AnalysisApiResponseProcessor
    ) {
        this.api = new ObservableAnalysisApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Get the cached evaluation of a position, if available.  Opening positions have more chances of being available. There are about 7 million positions in the database.  Up to 5 variations may be available. Variants are supported. 
     * Get cloud evaluation of a position.
     * @param fen FEN of the position
     * @param multiPv Number of variations
     * @param variant Variant
     */
    public apiCloudEval(fen: string, multiPv?: number, variant?: VariantKey, _options?: Configuration): Promise<void> {
        const result = this.api.apiCloudEval(fen, multiPv, variant, _options);
        return result.toPromise();
    }


}



import { ObservableArenaTournamentsApi } from './ObservableAPI';

import { ArenaTournamentsApiRequestFactory, ArenaTournamentsApiResponseProcessor} from "../apis/ArenaTournamentsApi";
export class PromiseArenaTournamentsApi {
    private api: ObservableArenaTournamentsApi

    public constructor(
        configuration: Configuration,
        requestFactory?: ArenaTournamentsApiRequestFactory,
        responseProcessor?: ArenaTournamentsApiResponseProcessor
    ) {
        this.api = new ObservableArenaTournamentsApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get team Arena tournaments
     * @param teamId ID of the team
     * @param max How many tournaments to download.
     */
    public apiTeamArena(teamId: string, max?: number, _options?: Configuration): Promise<Array<any>> {
        const result = this.api.apiTeamArena(teamId, max, _options);
        return result.toPromise();
    }

    /**
     * Get recently finished, ongoing, and upcoming tournaments.  This API is used to display the [Lichess tournament schedule](https://lichess.org/tournament). 
     * Get current tournaments
     */
    public apiTournament(_options?: Configuration): Promise<ArenaTournaments> {
        const result = this.api.apiTournament(_options);
        return result.toPromise();
    }

    /**
     * Join an Arena tournament, possibly with a password and/or a team. 
     * Join an Arena tournament
     * @param id The tournament ID.
     * @param password The tournament password, if one is required
     * @param team The team to join the tournament with, for team battle tournaments
     */
    public apiTournamentJoin(id: string, password?: string, team?: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.apiTournamentJoin(id, password, team, _options);
        return result.toPromise();
    }

    /**
     * Create a public or private Arena tournament.  This endpoint mirrors the form on <https://lichess.org/tournament/new>.  You can create up to 12 public tournaments per day, or 24 private tournaments.  A team battle can be created by specifying the `teambBattleByTeam` argument. 
     * Create a new Arena tournament
     * @param clockTime Clock initial time in minutes
     * @param clockIncrement Clock increment in seconds
     * @param minutes How long the tournament lasts, in minutes
     * @param name The tournament name. Leave empty to get a random Grandmaster name
     * @param waitMinutes How long to wait before starting the tournament, from now, in minutes
     * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting
     * @param variant 
     * @param rated Games are rated and impact players ratings
     * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960).
     * @param berserkable Whether the players can use berserk
     * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2.
     * @param hasChat Whether the players can discuss in a chat
     * @param description Anything you want to tell players about the tournament
     * @param password Make the tournament private, and restrict access with a password
     * @param teambBattleByTeam Set the ID of a team you lead to create a team battle. The other teams can be added using the [team battle edit endpoint](#operation/apiTournamentTeamBattlePost). 
     * @param conditionsTeamMemberTeamId Restrict entry to members of a team.  The teamId is the last part of a team URL, e.g. &#x60;https://lichess.org/team/coders&#x60; has teamId &#x3D; &#x60;coders&#x60;.  Leave empty to let everyone join the tournament.  Do not use this to create team battles, use &#x60;teamBattleByTeam&#x60; instead. 
     * @param conditionsMinRatingRating Minimum rating to join. Leave empty to let everyone join the tournament.
     * @param conditionsMaxRatingRating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament.
     * @param conditionsNbRatedGameNb Minimum number of rated games required to join.
     */
    public apiTournamentPost(clockTime: number, clockIncrement: number, minutes: number, name?: string, waitMinutes?: number, startDate?: number, variant?: VariantKey, rated?: boolean, position?: string, berserkable?: boolean, streakable?: boolean, hasChat?: boolean, description?: string, password?: string, teambBattleByTeam?: string, conditionsTeamMemberTeamId?: string, conditionsMinRatingRating?: number, conditionsMaxRatingRating?: number, conditionsNbRatedGameNb?: number, _options?: Configuration): Promise<any> {
        const result = this.api.apiTournamentPost(clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, teambBattleByTeam, conditionsTeamMemberTeamId, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb, _options);
        return result.toPromise();
    }

    /**
     * Set the teams and number of leaders of a team battle.  To update the other attributes of a team battle, use the [tournament update endpoint](#operation/apiTournamentUpdate). 
     * Update a team battle
     * @param id The tournament ID (8 characters)..
     * @param teams All team IDs of the team battle, separated by commas. Make sure to always send the full list. Teams that are not in the list will be removed from the team battle.  Example: &#x60;coders,zhigalko_sergei-fan-club,hhSwTKZv&#x60; 
     * @param nbLeaders Number team leaders per team.
     */
    public apiTournamentTeamBattlePost(id: string, teams: string, nbLeaders: number, _options?: Configuration): Promise<any> {
        const result = this.api.apiTournamentTeamBattlePost(id, teams, nbLeaders, _options);
        return result.toPromise();
    }

    /**
     * Terminate an Arena tournament 
     * Terminate an Arena tournament
     * @param id The tournament ID.
     */
    public apiTournamentTerminate(id: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.apiTournamentTerminate(id, _options);
        return result.toPromise();
    }

    /**
     * Update an Arena tournament.  Be mindful not to make important changes to ongoing tournaments.  Can be used to update a team battle. 
     * Update an Arena tournament
     * @param id The tournament ID.
     * @param clockTime Clock initial time in minutes
     * @param clockIncrement Clock increment in seconds
     * @param minutes How long the tournament lasts, in minutes
     * @param name The tournament name. Leave empty to get a random Grandmaster name
     * @param waitMinutes How long to wait before starting the tournament, from now, in minutes
     * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting
     * @param variant 
     * @param rated Games are rated and impact players ratings
     * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960).
     * @param berserkable Whether the players can use berserk
     * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2.
     * @param hasChat Whether the players can discuss in a chat
     * @param description Anything you want to tell players about the tournament
     * @param password Make the tournament private, and restrict access with a password
     * @param conditionsMinRatingRating Minimum rating to join. Leave empty to let everyone join the tournament.
     * @param conditionsMaxRatingRating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament.
     * @param conditionsNbRatedGameNb Minimum number of rated games required to join.
     */
    public apiTournamentUpdate(id: string, clockTime: number, clockIncrement: number, minutes: number, name?: string, waitMinutes?: number, startDate?: number, variant?: VariantKey, rated?: boolean, position?: string, berserkable?: boolean, streakable?: boolean, hasChat?: boolean, description?: string, password?: string, conditionsMinRatingRating?: number, conditionsMaxRatingRating?: number, conditionsNbRatedGameNb?: number, _options?: Configuration): Promise<any> {
        const result = this.api.apiTournamentUpdate(id, clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb, _options);
        return result.toPromise();
    }

    /**
     * Leave a future Arena tournament, or take a break on an ongoing Arena tournament. It's possible to join again later. Points and streaks are preserved. 
     * Pause of leave an Arena tournament
     * @param id The tournament ID.
     */
    public apiTournamentWithdraw(id: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.apiTournamentWithdraw(id, _options);
        return result.toPromise();
    }

    /**
     * Get all tournaments created by a given user.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get tournaments created by a user
     * @param username The user whose created tournaments to fetch
     * @param status Include tournaments in the given status: \&quot;Created\&quot; (10), \&quot;Started\&quot; (20), \&quot;Finished\&quot; (30)  You can add this parameter more than once to include tournaments in different statuses.   Example: &#x60;?status&#x3D;10&amp;status&#x3D;20&#x60; 
     */
    public apiUserNameTournamentCreated(username: string, status?: 10 | 20 | 30, _options?: Configuration): Promise<any> {
        const result = this.api.apiUserNameTournamentCreated(username, status, _options);
        return result.toPromise();
    }

    /**
     * Download games of a tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first) 
     * Export games of an Arena tournament
     * @param id The tournament ID.
     * @param player Only games of a particular player. Leave empty to fetch games of all players.
     * @param moves Include the PGN moves.
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @param tags Include the PGN tags.
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     */
    public gamesByTournament(id: string, player?: string, moves?: boolean, pgnInJson?: boolean, tags?: boolean, clocks?: boolean, evals?: boolean, opening?: boolean, _options?: Configuration): Promise<any> {
        const result = this.api.gamesByTournament(id, player, moves, pgnInJson, tags, clocks, evals, opening, _options);
        return result.toPromise();
    }

    /**
     * Players of an Arena tournament, with their score and performance, sorted by rank (best first).  **Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON)**, i.e. one JSON object per line.  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 
     * Get results of an Arena tournament
     * @param id The tournament ID.
     * @param nb Max number of players to fetch
     */
    public resultsByTournament(id: string, nb?: number, _options?: Configuration): Promise<any> {
        const result = this.api.resultsByTournament(id, nb, _options);
        return result.toPromise();
    }

    /**
     * Teams of a team battle tournament, with top players, sorted by rank (best first). 
     * Get team standing of a team battle
     * @param id The tournament ID.
     */
    public teamsByTournament(id: string, _options?: Configuration): Promise<any> {
        const result = this.api.teamsByTournament(id, _options);
        return result.toPromise();
    }

    /**
     * Get detailed info about recently finished, current, or upcoming tournament's duels, player standings, and other info. 
     * Get info about an Arena tournament
     * @param id The tournament ID.
     * @param page Specify which page of player standings to view.
     */
    public tournament(id: string, page?: number, _options?: Configuration): Promise<any> {
        const result = this.api.tournament(id, page, _options);
        return result.toPromise();
    }


}



import { ObservableBoardApi } from './ObservableAPI';

import { BoardApiRequestFactory, BoardApiResponseProcessor} from "../apis/BoardApi";
export class PromiseBoardApi {
    private api: ObservableBoardApi

    public constructor(
        configuration: Configuration,
        requestFactory?: BoardApiRequestFactory,
        responseProcessor?: BoardApiResponseProcessor
    ) {
        this.api = new ObservableBoardApi(configuration, requestFactory, responseProcessor);
    }

    /**
     *    Create a public seek, to start a game with a random player.    ### Real-time seek    Specify the `time` and `increment` clock values.  The response is streamed but doesn't contain any information.    **Keep the connection open to keep the seek active**.    If the client closes the connection, the seek is canceled. This way, if the client terminates, the user won't be paired in a game they wouldn't play.   When the seek is accepted, or expires, the server closes the connection.    **Make sure to also have an [Event stream](#operation/apiStreamEvent) open**, to be notified when a game starts.   We recommend opening the [Event stream](#operation/apiStreamEvent) first, then the seek stream. This way,   you won't miss the game event if the seek is accepted immediately.    ### Correspondence seek    Specify the `days` per turn value.  The response is not streamed, it immediately completes with the seek ID. The seek remains active on the server until it is joined by someone.
     * Create a seek
     * @param rated Whether the game is rated and impacts players ratings.
     * @param time Clock initial time in minutes. Required for real-time seeks.
     * @param increment Clock increment in seconds. Required for real-time seeks.
     * @param days Days per turn. Required for correspondence seeks.
     * @param variant 
     * @param color The color to play. Better left empty to automatically get 50% white.
     * @param ratingRange The rating range of potential opponents. Better left empty. Example: 1500-1800 
     */
    public apiBoardSeek(rated?: boolean, time?: number, increment?: number, days?: number, variant?: VariantKey, color?: string, ratingRange?: string, _options?: Configuration): Promise<void> {
        const result = this.api.apiBoardSeek(rated, time, increment, days, variant, color, ratingRange, _options);
        return result.toPromise();
    }

    /**
     *    Stream the events reaching a lichess user in real time as [ndjson](#section/Introduction/Streaming-with-ND-JSON).    Each line is a JSON object containing a `type` field. Possible values are:   - `gameStart` Start of a game   - `gameFinish` Completion of a game   - `challenge` A player sends you a challenge   - `challengeCanceled` A player cancels their challenge to you   - `challengeDeclined` The opponent declines your challenge     When the stream opens, all current challenges and games are sent.
     * Stream incoming events
     */
    public apiStreamEvent(_options?: Configuration): Promise<ApiStreamEvent> {
        const result = this.api.apiStreamEvent(_options);
        return result.toPromise();
    }

    /**
     * Abort a game being played with the Board API. 
     * Abort a game
     * @param gameId 
     */
    public boardGameAbort(gameId: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.boardGameAbort(gameId, _options);
        return result.toPromise();
    }

    /**
     * Get the messages posted in the game chat 
     * Fetch the game chat
     * @param gameId 
     */
    public boardGameChatGet(gameId: string, _options?: Configuration): Promise<any> {
        const result = this.api.boardGameChatGet(gameId, _options);
        return result.toPromise();
    }

    /**
     * Post a message to the player or spectator chat, in a game being played with the Board API. 
     * Write in the chat
     * @param gameId 
     * @param room 
     * @param text 
     */
    public boardGameChatPost(gameId: string, room: string, text: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.boardGameChatPost(gameId, room, text, _options);
        return result.toPromise();
    }

    /**
     * Claim victory when the opponent has left the game for a while. 
     * Claim victory of a game
     * @param gameId 
     */
    public boardGameClaimVictory(gameId: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.boardGameClaimVictory(gameId, _options);
        return result.toPromise();
    }

    /**
     * Create/accept/decline draw offers. - `yes`: Offer a draw, or accept the opponent's draw offer. - `no`: Decline a draw offer from the opponent. 
     * Handle draw offers
     * @param gameId 
     * @param accept 
     */
    public boardGameDraw(gameId: string, accept: boolean, _options?: Configuration): Promise<Ok> {
        const result = this.api.boardGameDraw(gameId, accept, _options);
        return result.toPromise();
    }

    /**
     * Make a move in a game being played with the Board API.  The move can also contain a draw offer/agreement. 
     * Make a Board move
     * @param gameId 
     * @param move The move to play, in UCI format
     * @param offeringDraw Whether to offer (or agree to) a draw
     */
    public boardGameMove(gameId: string, move: string, offeringDraw?: boolean, _options?: Configuration): Promise<Ok> {
        const result = this.api.boardGameMove(gameId, move, offeringDraw, _options);
        return result.toPromise();
    }

    /**
     * Resign a game being played with the Board API. 
     * Resign a game
     * @param gameId 
     */
    public boardGameResign(gameId: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.boardGameResign(gameId, _options);
        return result.toPromise();
    }

    /**
     *  Stream the state of a game being played with the Board API, as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  Use this endpoint to get updates about the game in real-time, with a single request.  Each line is a JSON object containing a `type` field. Possible values are:   - `gameFull` Full game data. All values are immutable, except for the `state` field.   - `gameState` Current state of the game. Immutable values not included. Sent when a move is played, a draw is offered, or when the game ends.   - `chatLine` Chat message sent by a user in the `room` \"player\" or \"spectator\".    The first line is always of type `gameFull`.
     * Stream Board game state
     * @param gameId 
     */
    public boardGameStream(gameId: string, _options?: Configuration): Promise<GameStreamEvent> {
        const result = this.api.boardGameStream(gameId, _options);
        return result.toPromise();
    }

    /**
     * Create/accept/decline takebacks. - `yes`: Propose a takeback, or accept the opponent's takeback offer. - `no`: Decline a takeback offer from the opponent. 
     * Handle takeback offers
     * @param gameId 
     * @param accept 
     */
    public boardGameTakeback(gameId: string, accept: boolean, _options?: Configuration): Promise<Ok> {
        const result = this.api.boardGameTakeback(gameId, accept, _options);
        return result.toPromise();
    }


}



import { ObservableBotApi } from './ObservableAPI';

import { BotApiRequestFactory, BotApiResponseProcessor} from "../apis/BotApi";
export class PromiseBotApi {
    private api: ObservableBotApi

    public constructor(
        configuration: Configuration,
        requestFactory?: BotApiRequestFactory,
        responseProcessor?: BotApiResponseProcessor
    ) {
        this.api = new ObservableBotApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Stream the [online bot users](https://lichess.org/player/bots), as [ndjson](#section/Introduction/Streaming-with-ND-JSON). Throttled to 50 bot users per second.
     * Get online bots
     * @param nb How many bot users to fetch
     */
    public apiBotOnline(nb?: number, _options?: Configuration): Promise<User> {
        const result = this.api.apiBotOnline(nb, _options);
        return result.toPromise();
    }

    /**
     *    Stream the events reaching a lichess user in real time as [ndjson](#section/Introduction/Streaming-with-ND-JSON).    Each line is a JSON object containing a `type` field. Possible values are:   - `gameStart` Start of a game   - `gameFinish` Completion of a game   - `challenge` A player sends you a challenge   - `challengeCanceled` A player cancels their challenge to you   - `challengeDeclined` The opponent declines your challenge     When the stream opens, all current challenges and games are sent.
     * Stream incoming events
     */
    public apiStreamEvent(_options?: Configuration): Promise<ApiStreamEvent> {
        const result = this.api.apiStreamEvent(_options);
        return result.toPromise();
    }

    /**
     * Upgrade a lichess player account into a Bot account. Only Bot accounts can use the Bot API.  The account **cannot have played any game** before becoming a Bot account. The upgrade is **irreversible**. The account will only be able to play as a Bot.  To upgrade an account to Bot, use the [official lichess-bot client](https://github.com/careless25/lichess-bot), or follow these steps: - Create an [API access token](https://lichess.org/account/oauth/token/create?scopes[]=bot:play) with \"Play bot moves\" permission. - `curl -d '' https://lichess.org/api/bot/account/upgrade -H \"Authorization: Bearer <yourTokenHere>\"`  To know if an account has already been upgraded, use the [Get my profile API](#operation/accountMe): the `title` field should be set to `BOT`. 
     * Upgrade to Bot account
     */
    public botAccountUpgrade(_options?: Configuration): Promise<Ok> {
        const result = this.api.botAccountUpgrade(_options);
        return result.toPromise();
    }

    /**
     * Abort a game being played with the Bot API. 
     * Abort a game
     * @param gameId 
     */
    public botGameAbort(gameId: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.botGameAbort(gameId, _options);
        return result.toPromise();
    }

    /**
     * Post a message to the player or spectator chat, in a game being played with the Bot API. 
     * Write in the chat
     * @param gameId 
     * @param room 
     * @param text 
     */
    public botGameChat(gameId: string, room: string, text: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.botGameChat(gameId, room, text, _options);
        return result.toPromise();
    }

    /**
     * Make a move in a game being played with the Bot API.  The move can also contain a draw offer/agreement. 
     * Make a Bot move
     * @param gameId 
     * @param move The move to play, in UCI format
     * @param offeringDraw Whether to offer (or agree to) a draw
     */
    public botGameMove(gameId: string, move: string, offeringDraw?: boolean, _options?: Configuration): Promise<Ok> {
        const result = this.api.botGameMove(gameId, move, offeringDraw, _options);
        return result.toPromise();
    }

    /**
     * Resign a game being played with the Bot API. 
     * Resign a game
     * @param gameId 
     */
    public botGameResign(gameId: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.botGameResign(gameId, _options);
        return result.toPromise();
    }

    /**
     *  Stream the state of a game being played with the Bot API, as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  Use this endpoint to get updates about the game in real-time, with a single request.  Each line is a JSON object containing a `type` field. Possible values are:   - `gameFull` Full game data. All values are immutable, except for the `state` field.   - `gameState` Current state of the game. Immutable values not included.   - `chatLine` Chat message sent by a user (or the bot itself) in the `room` \"player\" or \"spectator\".    The first line is always of type `gameFull`.
     * Stream Bot game state
     * @param gameId 
     */
    public botGameStream(gameId: string, _options?: Configuration): Promise<GameStreamEvent> {
        const result = this.api.botGameStream(gameId, _options);
        return result.toPromise();
    }


}



import { ObservableBroadcastsApi } from './ObservableAPI';

import { BroadcastsApiRequestFactory, BroadcastsApiResponseProcessor} from "../apis/BroadcastsApi";
export class PromiseBroadcastsApi {
    private api: ObservableBroadcastsApi

    public constructor(
        configuration: Configuration,
        requestFactory?: BroadcastsApiRequestFactory,
        responseProcessor?: BroadcastsApiResponseProcessor
    ) {
        this.api = new ObservableBroadcastsApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Download all games of all rounds of a broadcast in PGN format.  You may want to [download only the games of a single round](#operation/broadcastRoundPgn) instead. 
     * Export all rounds as PGN
     * @param broadcastTournamentId The broadcast tournament ID (8 characters).
     */
    public broadcastAllRoundsPgn(broadcastTournamentId: string, _options?: Configuration): Promise<any> {
        const result = this.api.broadcastAllRoundsPgn(broadcastTournamentId, _options);
        return result.toPromise();
    }

    /**
     * Get all incoming, ongoing, and finished official broadcasts. The broadcasts are sorted by start date, most recent first.  Broadcasts are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get official broadcasts
     * @param nb Max number of broadcasts to fetch
     */
    public broadcastIndex(nb?: number, _options?: Configuration): Promise<Array<any>> {
        const result = this.api.broadcastIndex(nb, _options);
        return result.toPromise();
    }

    /**
     * Update your broadcast with new PGN. Only for broadcast without a source URL. 
     * Push PGN to your broadcast round
     * @param broadcastRoundId The broadcast round ID (8 characters).
     * @param body The PGN. It can contain up to 64 games, separated by a double new line.
     */
    public broadcastPush(broadcastRoundId: string, body: string, _options?: Configuration): Promise<Array<Ok>> {
        const result = this.api.broadcastPush(broadcastRoundId, body, _options);
        return result.toPromise();
    }

    /**
     * Create a new broadcast round to relay external games. This endpoint accepts the same form data as the web form. 
     * Create a broadcast round
     * @param broadcastTournamentId The broadcast tournament ID (8 characters).
     * @param name Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 1&#x60; 
     * @param syncUrl URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  If the syncUrl is missing, then the broadcast needs to be fed by [pushing PGN to it](#operation/broadcastPush). 
     * @param startsAt Timestamp in milliseconds of broadcast round start. Leave empty to manually start the broadcast round.  Example: &#x60;1356998400070&#x60; 
     */
    public broadcastRoundCreate(broadcastTournamentId: string, name: string, syncUrl?: string, startsAt?: number, _options?: Configuration): Promise<any> {
        const result = this.api.broadcastRoundCreate(broadcastTournamentId, name, syncUrl, startsAt, _options);
        return result.toPromise();
    }

    /**
     * Get information about a broadcast round that you created. 
     * Get your broadcast round
     * @param broadcastTournamentSlug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used.
     * @param broadcastRoundSlug The broadcast round slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used.
     * @param broadcastRoundId The broadcast Round ID (8 characters).
     */
    public broadcastRoundGet(broadcastTournamentSlug: string, broadcastRoundSlug: string, broadcastRoundId: string, _options?: Configuration): Promise<Array<any>> {
        const result = this.api.broadcastRoundGet(broadcastTournamentSlug, broadcastRoundSlug, broadcastRoundId, _options);
        return result.toPromise();
    }

    /**
     * Download all games of a single round of a broadcast tournament in PGN format.  You *could* poll this endpoint to get updates about a tournament, but it would be slow, and very inneficient.  Instead, consider [streaming the tournament](#operation/broadcastStreamRoundPgn) to get a new PGN every time a game is updated, in real-time. 
     * Export one round as PGN
     * @param broadcastRoundId The round ID (8 characters).
     */
    public broadcastRoundPgn(broadcastRoundId: string, _options?: Configuration): Promise<any> {
        const result = this.api.broadcastRoundPgn(broadcastRoundId, _options);
        return result.toPromise();
    }

    /**
     * Update information about a broadcast round that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. For instance, if you omit `startDate`, then any pre-existing start date will be removed. 
     * Update your broadcast round
     * @param broadcastRoundId The broadcast round ID (8 characters).
     * @param name Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 10&#x60; 
     * @param syncUrl URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60; 
     * @param startsAt Timestamp in milliseconds of broadcast start. Leave empty to manually start the broadcast.  Example: &#x60;1356998400070&#x60; 
     */
    public broadcastRoundUpdate(broadcastRoundId: string, name: string, syncUrl?: string, startsAt?: number, _options?: Configuration): Promise<Ok> {
        const result = this.api.broadcastRoundUpdate(broadcastRoundId, name, syncUrl, startsAt, _options);
        return result.toPromise();
    }

    /**
     * This streaming endpoint first sends all games of a broadcast tournament in PGN format.  Then, it waits for new moves to be played. As soon as it happens, the entire PGN of the game is sent to the stream.  The stream will also send PGNs when games are added to the tournament.  This is the best way to get updates about an ongoing tournament. Streaming means no polling, and no pollings means no latency, and minimum impact on the server. 
     * Stream an ongoing broadcast tournament as PGN
     * @param broadcastRoundId The broadcast round ID (8 characters).
     */
    public broadcastStreamRoundPgn(broadcastRoundId: string, _options?: Configuration): Promise<any> {
        const result = this.api.broadcastStreamRoundPgn(broadcastRoundId, _options);
        return result.toPromise();
    }

    /**
     * Create a new broadcast tournament to relay external games. This endpoint accepts the same form data as the [web form](https://lichess.org/broadcast/new). 
     * Create a broadcast tournament
     * @param name Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60; 
     * @param description Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60; 
     * @param markup Optional long description of the broadcast. Markdown is supported. Length must be less than 20,000 characters.
     * @param official For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police.
     */
    public broadcastTourCreate(name: string, description: string, markup?: string, official?: boolean, _options?: Configuration): Promise<any> {
        const result = this.api.broadcastTourCreate(name, description, markup, official, _options);
        return result.toPromise();
    }

    /**
     * Get information about a broadcast tournament that you created. 
     * Get your broadcast tournament
     * @param slug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastTournamentId&#x60; is actually used.
     * @param broadcastTournamentId The broadcast tournament ID (8 characters).
     */
    public broadcastTourGet(slug: string, broadcastTournamentId: string, _options?: Configuration): Promise<Array<any>> {
        const result = this.api.broadcastTourGet(slug, broadcastTournamentId, _options);
        return result.toPromise();
    }

    /**
     * Update information about a broadcast tournament that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. 
     * Update your broadcast tournament
     * @param broadcastTournamentId The broadcast ID (8 characters).
     * @param name Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60; 
     * @param description Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60; 
     * @param markup Optional long description of the broadcast tournament. Markdown is supported. Length must be less than 20,000 characters.
     * @param official For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police.
     */
    public broadcastTourUpdate(broadcastTournamentId: string, name: string, description: string, markup?: string, official?: boolean, _options?: Configuration): Promise<Ok> {
        const result = this.api.broadcastTourUpdate(broadcastTournamentId, name, description, markup, official, _options);
        return result.toPromise();
    }


}



import { ObservableBulkPairingsApi } from './ObservableAPI';

import { BulkPairingsApiRequestFactory, BulkPairingsApiResponseProcessor} from "../apis/BulkPairingsApi";
export class PromiseBulkPairingsApi {
    private api: ObservableBulkPairingsApi

    public constructor(
        configuration: Configuration,
        requestFactory?: BulkPairingsApiRequestFactory,
        responseProcessor?: BulkPairingsApiResponseProcessor
    ) {
        this.api = new ObservableBulkPairingsApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Schedule many games at once, up to 24h in advance.  OAuth tokens are required for all paired players, with the `challenge:write` scope.  You can schedule up to 500 games every 10 minutes. [Contact us](mailto:contact@lichess.org) if you need higher limits.  The entire bulk is rejected if:   - a token is missing   - a token is present more than once   - a token lacks the `challenge:write` scope   - a player account is closed   - a player is paired more than once   - a bulk is already scheduled to start at the same time with the same player   - you have 10 scheduled bulks   - you have 1000 scheduled games  Partial bulks are never created. Either it all fails, or it all succeeds. When it fails, it does so with an error message explaining the issue. Failed bulks are not counted in the rate limiting, they are free. Fix the issues, manually or programmatically, then retry to schedule the bulk.  A successful bulk creation returns a JSON bulk document. Its ID can be used for further operations. 
     * Create a bulk pairing
     * @param players OAuth tokens of all the players to pair, with the syntax &#x60;tokenOfWhitePlayerInGame1:tokenOfBlackPlayerInGame1,tokenOfWhitePlayerInGame2:tokenOfBlackPlayerInGame2,...&#x60;.  The 2 tokens of the players of a game are separated with &#x60;:&#x60;. The first token gets the white pieces. Games are separated with &#x60;,&#x60;.  Up to 1000 tokens can be sent, for a max of 500 games.  Each token must be included at most once.  Example: &#x60;token1:token2,token3:token4,token5:token6&#x60; 
     * @param clockLimit Clock initial time in seconds. Example: &#x60;600&#x60; 
     * @param clockIncrement Clock increment in seconds. Example: &#x60;5&#x60; 
     * @param pairAt Date at which the games will be created. Up to 24h in the future. Omit, or set to current date and time, to start the games immediately. Example: &#x60;1612289869919&#x60; 
     * @param startClocksAt Date at which the clocks will be automatically started. Up to 24h in the future. Note that the clocks can start earlier than specified, if players start making moves in the game. If omitted, the clocks will not start automatically. Example: &#x60;1612289869919&#x60; 
     * @param rated Game is rated and impacts players ratings
     * @param variant 
     * @param message Message that will be sent to each player, when the game is created.  It is sent from your user account.  &#x60;{opponent}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder. 
     */
    public bulkPairingCreate(players?: string, clockLimit?: number, clockIncrement?: number, pairAt?: number, startClocksAt?: number, rated?: boolean, variant?: VariantKey, message?: string, _options?: Configuration): Promise<any> {
        const result = this.api.bulkPairingCreate(players, clockLimit, clockIncrement, pairAt, startClocksAt, rated, variant, message, _options);
        return result.toPromise();
    }

    /**
     * Cancel and delete a bulk pairing that is scheduled in the future.  If the games have already been created, then this does nothing.  Canceling a bulk pairing does not refund the rate limit cost of that bulk pairing. 
     * Cancel a bulk pairing
     * @param id 
     */
    public bulkPairingDelete(id: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.bulkPairingDelete(id, _options);
        return result.toPromise();
    }

    /**
     * Get a list of upcoming bulk pairings you created.  Only bulk pairings that are scheduled in the future, or that have a clock start scheduled in the future, are listed.  Bulk pairings are deleted from the server after the pairings are done and the clocks have started. 
     * View upcoming bulk pairings
     */
    public bulkPairingGet(_options?: Configuration): Promise<Array<any>> {
        const result = this.api.bulkPairingGet(_options);
        return result.toPromise();
    }

    /**
     * Immediately start all clocks of the games of a bulk pairing.  This overrides the `startClocksAt` value of an existing bulk pairing.  If the games have not yet been created (`bulk.pairAt` is in the future), then this does nothing.  If the clocks have already started (`bulk.startClocksAt` is in the past), then this does nothing. 
     * Manually start clocks
     * @param id 
     */
    public bulkPairingStartClocks(id: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.bulkPairingStartClocks(id, _options);
        return result.toPromise();
    }


}



import { ObservableChallengesApi } from './ObservableAPI';

import { ChallengesApiRequestFactory, ChallengesApiResponseProcessor} from "../apis/ChallengesApi";
export class PromiseChallengesApi {
    private api: ObservableChallengesApi

    public constructor(
        configuration: Configuration,
        requestFactory?: ChallengesApiRequestFactory,
        responseProcessor?: ChallengesApiResponseProcessor
    ) {
        this.api = new ObservableChallengesApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * **For administrators only. You are not allowed to use this endpoint.**  Create and obtain `challenge:write` tokens for multiple users.  If a similar token already exists for a user, it is reused. This endpoint is idempotent. 
     * Admin challenge tokens
     * @param users Usernames separated with commas
     * @param description User visible description of the token
     */
    public adminChallengeTokens(users: string, description: string, _options?: Configuration): Promise<void> {
        const result = this.api.adminChallengeTokens(users, description, _options);
        return result.toPromise();
    }

    /**
     * Accept an incoming challenge.  You should receive a `gameStart` event on the [incoming events stream](#operation/apiStreamEvent). 
     * Accept a challenge
     * @param challengeId 
     */
    public challengeAccept(challengeId: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.challengeAccept(challengeId, _options);
        return result.toPromise();
    }

    /**
     * Start a game with Lichess AI.  You will be notified on the [event stream](#operation/apiStreamEvent) that a new game has started. 
     * Challenge the AI
     * @param level AI strength
     * @param clockLimit Clock initial time in seconds. If empty, a correspondence game is created.
     * @param clockIncrement Clock increment in seconds. If empty, a correspondence game is created.
     * @param days Days per move, for correspondence games. Clock settings must be omitted.
     * @param color Which color you get to play
     * @param variant 
     * @param fen Custom initial position (in FEN). Variant must be standard, and the game cannot be rated.
     */
    public challengeAi(level?: number, clockLimit?: number, clockIncrement?: number, days?: number, color?: string, variant?: VariantKey, fen?: string, _options?: Configuration): Promise<GameJson> {
        const result = this.api.challengeAi(level, clockLimit, clockIncrement, days, color, variant, fen, _options);
        return result.toPromise();
    }

    /**
     * Cancel a challenge you sent, or aborts the game if the challenge was accepted, but the game was not yet played. Note that the ID of a game is the same as the ID of the challenge that created it. 
     * Cancel a challenge
     * @param challengeId 
     * @param opponentToken Optional &#x60;challenge:write&#x60; token of the opponent. If set, the game can be canceled even if both players have moved.
     */
    public challengeCancel(challengeId: string, opponentToken?: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.challengeCancel(challengeId, opponentToken, _options);
        return result.toPromise();
    }

    /**
     * Challenge someone to play. The targeted player can choose to accept or decline.  If the challenge is accepted, you will be notified on the [event stream](#operation/apiStreamEvent) that a new game has started. The game ID will be the same as the challenge ID.  If you also have an OAuth token with `challenge:write` scope for the receiving user, you can make them accept the challenge immediately by setting the `acceptByToken` field.  Challenges for realtime games (not correspondence) expire after 20s if not accepted. To prevent that, use the `keepAliveStream` flag described below. 
     * Create a challenge
     * @param username 
     * @param rated Game is rated and impacts players ratings
     * @param clockLimit Clock initial time in seconds. If empty, a correspondence game is created.
     * @param clockIncrement Clock increment in seconds. If empty, a correspondence game is created.
     * @param days Days per move, for correspondence games. Clock settings must be omitted.
     * @param color Which color you get to play
     * @param variant 
     * @param fen Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. Castling moves will use UCI_Chess960 notation, for example e1h1 instead of e1g1.
     * @param keepAliveStream If set, the response is streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). The challenge is kept alive until the connection is closed by the client. When the challenge is accepted, declined or canceled, a message of the form &#x60;{\\\&quot;done\\\&quot;:\\\&quot;accepted\\\&quot;}&#x60; is sent, then the connection is closed by the server. If not set, the response is not streamed, and the challenge expires after 20s if not accepted. 
     * @param acceptByToken Immediately accept the challenge and create the game. Pass in an OAuth token (with the &#x60;challenge:write&#x60; scope) for the receiving user. On success, the response will contain a &#x60;game&#x60; field instead of a &#x60;challenge&#x60; field.  Alternatively, consider the [bulk pairing API](#operation/bulkPairingCreate). 
     * @param message **Only if &#x60;acceptByToken&#x60; is set.**  Message that is sent to each player, when the game is created. It is sent from your user account.  &#x60;{opponent}&#x60;, &#x60;{player}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent name, player name, and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder. 
     */
    public challengeCreate(username: string, rated?: boolean, clockLimit?: number, clockIncrement?: number, days?: number, color?: string, variant?: VariantKey, fen?: string, keepAliveStream?: boolean, acceptByToken?: string, message?: string, _options?: Configuration): Promise<ChallengeJson> {
        const result = this.api.challengeCreate(username, rated, clockLimit, clockIncrement, days, color, variant, fen, keepAliveStream, acceptByToken, message, _options);
        return result.toPromise();
    }

    /**
     * Decline an incoming challenge. 
     * Decline a challenge
     * @param challengeId 
     * @param reason Reason challenge was declined. It will be translated to the player&#39;s language. See [the full list in the translation file](https://github.com/ornicar/lila/blob/43fbd61029ff3960a21fbd213944bed66325696d/translation/source/challenge.xml#L14).
     */
    public challengeDecline(challengeId: string, reason?: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.challengeDecline(challengeId, reason, _options);
        return result.toPromise();
    }

    /**
     * Get a list of challenges created by or targeted at you. 
     * List your challenges
     */
    public challengeList(_options?: Configuration): Promise<InlineResponse2003> {
        const result = this.api.challengeList(_options);
        return result.toPromise();
    }

    /**
     * Create a challenge that any 2 players can join.  Share the URL of the challenge. the first 2 players to click it will be paired for a game.  The response body also contains `whiteUrl` and `blackUrl`. You can control which color each player gets by giving them these URLs, instead of the main challenge URL.  Open challenges expire after 24h.  To directly pair 2 known players, use [this endpoint](#operation/challengeCreate) instead, with the `acceptByToken` parameter. 
     * Open-ended challenge
     * @param rated Game is rated and impacts players ratings
     * @param clockLimit Clock initial time in seconds. If empty, a correspondence game is created.
     * @param clockIncrement Clock increment in seconds. If empty, a correspondence game is created.
     * @param variant 
     * @param fen Custom initial position (in FEN). Variant must be standard, and the game cannot be rated.
     * @param name Optional name for the challenge, that players will see on the challenge page.
     */
    public challengeOpen(rated?: boolean, clockLimit?: number, clockIncrement?: number, variant?: VariantKey, fen?: string, name?: string, _options?: Configuration): Promise<any> {
        const result = this.api.challengeOpen(rated, clockLimit, clockIncrement, variant, fen, name, _options);
        return result.toPromise();
    }

    /**
     * Start the clocks of a game immediately, even if a player has not yet made a move.  Requires the OAuth tokens of both players with `challenge:write` scope.  If the clocks have already started, the call will have no effect. 
     * Start clocks of a game
     * @param gameId 
     * @param token1 OAuth token of a player
     * @param token2 OAuth token of the other player
     */
    public challengeStartClocks(gameId: string, token1?: string, token2?: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.challengeStartClocks(gameId, token1, token2, _options);
        return result.toPromise();
    }

    /**
     * Add seconds to the opponent's clock. Can be used to create games with time odds. 
     * Add time to the opponent clock
     * @param gameId 
     * @param seconds How many seconds to give
     */
    public roundAddTime(gameId: string, seconds: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.roundAddTime(gameId, seconds, _options);
        return result.toPromise();
    }


}



import { ObservableGamesApi } from './ObservableAPI';

import { GamesApiRequestFactory, GamesApiResponseProcessor} from "../apis/GamesApi";
export class PromiseGamesApi {
    private api: ObservableGamesApi

    public constructor(
        configuration: Configuration,
        requestFactory?: GamesApiRequestFactory,
        responseProcessor?: GamesApiResponseProcessor
    ) {
        this.api = new ObservableGamesApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Get the ongoing games of the current user. Real-time and correspondence games are included. The most urgent games are listed first. 
     * Get my ongoing games
     * @param nb Max number of games to fetch
     */
    public apiAccountPlaying(nb?: number, _options?: Configuration): Promise<any> {
        const result = this.api.apiAccountPlaying(nb, _options);
        return result.toPromise();
    }

    /**
     * Download all games of any user in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first)  We recommend streaming the response, for it can be very long. <https://lichess.org/@/german11> for instance has more than 320,000 games.  The game stream is throttled, depending on who is making the request:   - Anonymous request: 20 games per second   - [OAuth2 authenticated](#section/Authentication) request: 30 games per second   - Authenticated, downloading your own games: 60 games per second 
     * Export games of a user
     * @param username The user name.
     * @param since Download games played since this timestamp.
     * @param until Download games played until this timestamp.
     * @param max How many games to download. Leave empty to download all games.
     * @param vs [Filter] Only games played against this opponent
     * @param rated [Filter] Only rated (&#x60;true&#x60;) or casual (&#x60;false&#x60;) games
     * @param perfType [Filter] Only games in these speeds or variants.   Multiple perf types can be specified, separated by a comma.   Example: blitz,rapid,classical
     * @param color [Filter] Only games played as this color.
     * @param analysed [Filter] Only games with or without a computer analysis available
     * @param moves Include the PGN moves.
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. The response type must be set to &#x60;application/x-ndjson&#x60; by the request &#x60;Accept&#x60; header.
     * @param tags Include the PGN tags.
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     * @param ongoing Include ongoing games. The last 3 moves will be omitted.
     * @param finished Include finished games. Set to &#x60;false&#x60; to only get ongoing games.
     * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt; 
     * @param sort Sort order of the games.
     */
    public apiGamesUser(username: string, since?: number, until?: number, max?: number, vs?: string, rated?: boolean, perfType?: PerfType, color?: 'white' | 'black', analysed?: boolean, moves?: boolean, pgnInJson?: boolean, tags?: boolean, clocks?: boolean, evals?: boolean, opening?: boolean, ongoing?: boolean, finished?: boolean, players?: string, sort?: 'dateAsc' | 'dateDesc', _options?: Configuration): Promise<any> {
        const result = this.api.apiGamesUser(username, since, until, max, vs, rated, perfType, color, analysed, moves, pgnInJson, tags, clocks, evals, opening, ongoing, finished, players, sort, _options);
        return result.toPromise();
    }

    /**
     * Download the ongoing game, or the last game played, of a user. Available in either PGN or JSON format. If the game is ongoing, the 3 last moves are omitted. 
     * Export ongoing game of a user
     * @param username 
     * @param moves Include the PGN moves.
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @param tags Include the PGN tags.
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     * @param literate Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60; 
     * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt; 
     */
    public apiUserCurrentGame(username: string, moves?: boolean, pgnInJson?: boolean, tags?: boolean, clocks?: boolean, evals?: boolean, opening?: boolean, literate?: boolean, players?: string, _options?: Configuration): Promise<any> {
        const result = this.api.apiUserCurrentGame(username, moves, pgnInJson, tags, clocks, evals, opening, literate, players, _options);
        return result.toPromise();
    }

    /**
     * Import a game from PGN. See <https://lichess.org/paste>.  Rate limiting: 200 games per hour for OAuth requests, 100 games per hour for anonymous requests.  To broadcast ongoing games, consider [pushing to a broadcast instead](#operation/broadcastPush). 
     * Import one game
     * @param pgn The PGN. It can contain only one game. Most standard tags are supported.
     */
    public gameImport(pgn?: string, _options?: Configuration): Promise<any> {
        const result = this.api.gameImport(pgn, _options);
        return result.toPromise();
    }

    /**
     * Download one game in either PGN or JSON format.  Ongoing games have their last 3 moves omitted, after move 5. 
     * Export one game
     * @param gameId The game ID (8 characters).
     * @param moves Include the PGN moves.
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @param tags Include the PGN tags.
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     * @param literate Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60; 
     * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt; 
     */
    public gamePgn(gameId: string, moves?: boolean, pgnInJson?: boolean, tags?: boolean, clocks?: boolean, evals?: boolean, opening?: boolean, literate?: boolean, players?: string, _options?: Configuration): Promise<any> {
        const result = this.api.gamePgn(gameId, moves, pgnInJson, tags, clocks, evals, opening, literate, players, _options);
        return result.toPromise();
    }

    /**
     * Stream the games played between a list of users, in real time. Only games where **both players** are part of the list are included.  By default, games are only sent to the stream when they start. To also get all ongoing games at the beginning of the stream, use the `withCurrentGames` flag.  Maximum number of users: 300.  Games are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  The method is `POST` so a longer list of IDs can be sent in the request body. 
     * Stream games of users
     * @param body Up to 300 user IDs separated by commas.
     * @param withCurrentGames Include the already started games at the beginning of the stream.
     */
    public gamesByUsers(body: string, withCurrentGames?: boolean, _options?: Configuration): Promise<any> {
        const result = this.api.gamesByUsers(body, withCurrentGames, _options);
        return result.toPromise();
    }

    /**
     * Download games by IDs in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format, depending on the request Accept header.  Games are sorted by reverse chronological order (most recent first)  The method is `POST` so a longer list of IDs can be sent in the request body.  300 IDs can be submitted.  Ongoing games have their last 3 moves omitted, after move 5. 
     * Export games by IDs
     * @param body Game IDs separated by commas. Up to 300.
     * @param moves Include the PGN moves.
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @param tags Include the PGN tags.
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt; 
     */
    public gamesExportIds(body: string, moves?: boolean, pgnInJson?: boolean, tags?: boolean, clocks?: boolean, evals?: boolean, opening?: boolean, players?: string, _options?: Configuration): Promise<any> {
        const result = this.api.gamesExportIds(body, moves, pgnInJson, tags, clocks, evals, opening, players, _options);
        return result.toPromise();
    }

    /**
     * Stream positions and moves of any ongoing game, in [ndjson](#section/Introduction/Streaming-with-ND-JSON).  A description of the game is sent as a first message. Then a message is sent each time a move is played. Finally a description of the game is sent when it finishes, and the stream is closed.  After move 5, the stream intentionally remains 3 moves behind the game status, as to prevent cheat bots from using this API.  No more than 8 game streams can be opened at the same time from the same IP address. 
     * Stream moves of a game
     * @param id 
     */
    public streamGame(id: string, _options?: Configuration): Promise<any> {
        const result = this.api.streamGame(id, _options);
        return result.toPromise();
    }


}



import { ObservableMessagingApi } from './ObservableAPI';

import { MessagingApiRequestFactory, MessagingApiResponseProcessor} from "../apis/MessagingApi";
export class PromiseMessagingApi {
    private api: ObservableMessagingApi

    public constructor(
        configuration: Configuration,
        requestFactory?: MessagingApiRequestFactory,
        responseProcessor?: MessagingApiResponseProcessor
    ) {
        this.api = new ObservableMessagingApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Send a private message to another player. 
     * Send a private message
     * @param username 
     * @param text 
     */
    public inboxUsername(username: string, text: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.inboxUsername(username, text, _options);
        return result.toPromise();
    }


}



import { ObservableOAuthApi } from './ObservableAPI';

import { OAuthApiRequestFactory, OAuthApiResponseProcessor} from "../apis/OAuthApi";
export class PromiseOAuthApi {
    private api: ObservableOAuthApi

    public constructor(
        configuration: Configuration,
        requestFactory?: OAuthApiRequestFactory,
        responseProcessor?: OAuthApiResponseProcessor
    ) {
        this.api = new ObservableOAuthApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * OAuth2 token endpoint. Exchanges an authorization code for an access token. 
     * Obtain access token
     * @param grantType Must be &#x60;authorization_code&#x60;.
     * @param code The authorization code that was sent in the &#x60;code&#x60; parameter to your &#x60;redirect_uri&#x60;.
     * @param codeVerifier A &#x60;code_challenge&#x60; was used to request the authorization code. This must be the &#x60;code_verifier&#x60; it was derived from.
     * @param redirectUri Must match the &#x60;redirect_uri&#x60; used to request the authorization code.
     * @param clientId Must match the &#x60;client_id&#x60; used to request the authorization code.
     */
    public apiToken(grantType?: string, code?: string, codeVerifier?: string, redirectUri?: string, clientId?: string, _options?: Configuration): Promise<void> {
        const result = this.api.apiToken(grantType, code, codeVerifier, redirectUri, clientId, _options);
        return result.toPromise();
    }

    /**
     * Revokes the access token sent as Bearer for this request.
     * Revoke access token
     */
    public apiTokenDelete(_options?: Configuration): Promise<void> {
        const result = this.api.apiTokenDelete(_options);
        return result.toPromise();
    }

    /**
     * OAuth2 authorization endpoint.  Start the OAuth2 Authorization Code Flow with PKCE by securely generating two random strings unique to each authorization request: * `code_verifier` * `state`  Store these in session storage. Make sure not to reveal `code_verifier` to eavesdroppers. Do not show it in URLs, do not abuse `state` to store it, do not send it over insecure connections. However it is fine if the user themselves can extract `code_verifier`, which will always be possible for fully client-side apps.  Then send the user to this endpoint. They will be prompted to grant authorization and then be redirected back to the given `redirect_uri`.  If the authorization failed, the following query string parameters will be appended to the redirection: * `error`, in particular with value `access_denied` if the user    cancelled authorization * `error_description` to aid debugging * `state`, exactly as passed in the `state` parameter  If the authorization succeeded, the following query string parameters will be appended to the redirection: * `code`, containing a fresh short-lived authorization code * `state`, exactly as passed in the `state` parameter  Next, to defend against cross site request forgery, check that the returned `state` matches the `state` you originally generated.  Finally, continue by using the authorization code to [obtain an access token](#operation/apiToken). 
     * Request authorization code
     * @param responseType Must be &#x60;code&#x60;.
     * @param clientId Arbitrary identifier that uniquely identifies your application.
     * @param redirectUri The absolute URL that the user should be redirected to with the authorization result.
     * @param codeChallengeMethod Must be &#x60;S256&#x60;.
     * @param codeChallenge Compute &#x60;BASE64URL(SHA256(code_verifier))&#x60;.
     * @param scope Space separated list of requested OAuth scopes, if any.
     * @param state Arbitrary state that will be returned verbatim with the authorization result.
     */
    public oauth(responseType: string, clientId: string, redirectUri: string, codeChallengeMethod: string, codeChallenge: string, scope?: string, state?: string, _options?: Configuration): Promise<void> {
        const result = this.api.oauth(responseType, clientId, redirectUri, codeChallengeMethod, codeChallenge, scope, state, _options);
        return result.toPromise();
    }


}



import { ObservableOpeningExplorerApi } from './ObservableAPI';

import { OpeningExplorerApiRequestFactory, OpeningExplorerApiResponseProcessor} from "../apis/OpeningExplorerApi";
export class PromiseOpeningExplorerApi {
    private api: ObservableOpeningExplorerApi

    public constructor(
        configuration: Configuration,
        requestFactory?: OpeningExplorerApiRequestFactory,
        responseProcessor?: OpeningExplorerApiResponseProcessor
    ) {
        this.api = new ObservableOpeningExplorerApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * **Endpoint: <https://explorer.lichess.ovh/lichess>**  Games sampled from all Lichess players.  Example: `curl https://explorer.lichess.ovh/lichess?variant=standard&speeds=blitz,rapid,classical&ratings=2200,2500&fen=rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR%20w%20KQkq%20-%200%201` 
     * Lichess games
     * @param variant Variant
     * @param fen FEN of the root position
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position. 
     * @param speeds Comma separated list of game speeds to look for
     * @param ratings Comma separated list of rating groups, ranging from their value to the next higher group
     * @param since Include only games from this month or later
     * @param until Include only games from this month or earlier
     * @param moves Number of most common moves to display
     * @param topGames Number of top games to display
     * @param recentGames Number of recent games to display
     */
    public openingExplorerLichess(variant?: VariantKey, fen?: string, play?: string, speeds?: Array<Speed>, ratings?: Array<1600 | 1800 | 2000 | 2200 | 2500>, since?: string, until?: string, moves?: number, topGames?: number, recentGames?: number, _options?: Configuration): Promise<any> {
        const result = this.api.openingExplorerLichess(variant, fen, play, speeds, ratings, since, until, moves, topGames, recentGames, _options);
        return result.toPromise();
    }

    /**
     * **Endpoint: <https://explorer.lichess.ovh/masters>**  Example: `curl https://explorer.lichess.ovh/masters?play=d2d4,d7d5,c2c4,c7c6,c4d5` 
     * Masters database
     * @param fen FEN of the root position
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position. 
     * @param since Include only games from this year or later
     * @param until Include only games from thi year or earlier
     * @param moves Number of most common moves to display
     * @param topGames Number of top games to display
     */
    public openingExplorerMaster(fen?: string, play?: string, since?: number, until?: number, moves?: number, topGames?: number, _options?: Configuration): Promise<any> {
        const result = this.api.openingExplorerMaster(fen, play, since, until, moves, topGames, _options);
        return result.toPromise();
    }

    /**
     * **Endpoint: `https://explorer.lichess.ovh/masters/pgn/{gameId}`**  Example: `curl https://explorer.lichess.ovh/masters/pgn/aAbqI4ey` 
     * OTB master game
     * @param gameId 
     */
    public openingExplorerMasterGame(gameId: string, _options?: Configuration): Promise<any> {
        const result = this.api.openingExplorerMasterGame(gameId, _options);
        return result.toPromise();
    }

    /**
     * **Endpoint: <https://explorer.lichess.ovh/player>**  Games of a Lichess player.  Responds with a stream of newline delimited JSON. Will start indexing on demand, immediately respond with the current results, and stream more updates until indexing is complete. The stream is throttled and deduplicated. Empty lines may be sent to avoid timeouts.  Will index new games at most once per minute, and revisit previously ongoing games at most once every day.  Example: `curl https://explorer.lichess.ovh/player?player=revoof&color=white&play=d2d4,d7d5&recentGames=1` 
     * Player games
     * @param variant Variant
     * @param fen FEN of the root position
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position. 
     * @param speeds Comma separated list of game speeds to look for
     * @param modes Comma separated list of modes
     * @param since Include only games from this month or later
     * @param until Include only games from this month or earlier
     * @param moves Number of most common moves to display
     * @param recentGames Number of recent games to display
     */
    public openingExplorerPlayer(variant?: VariantKey, fen?: string, play?: string, speeds?: Array<Speed>, modes?: Array<'casual' | 'rated'>, since?: string, until?: string, moves?: number, recentGames?: number, _options?: Configuration): Promise<any> {
        const result = this.api.openingExplorerPlayer(variant, fen, play, speeds, modes, since, until, moves, recentGames, _options);
        return result.toPromise();
    }


}



import { ObservablePuzzlesApi } from './ObservableAPI';

import { PuzzlesApiRequestFactory, PuzzlesApiResponseProcessor} from "../apis/PuzzlesApi";
export class PromisePuzzlesApi {
    private api: ObservablePuzzlesApi

    public constructor(
        configuration: Configuration,
        requestFactory?: PuzzlesApiRequestFactory,
        responseProcessor?: PuzzlesApiResponseProcessor
    ) {
        this.api = new ObservablePuzzlesApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Download your puzzle activity in [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Puzzle activity is sorted by reverse chronological order (most recent first)  We recommend streaming the response, for it can be very long. 
     * Get your puzzle activity
     * @param max How many entries to download. Leave empty to download all activity.
     */
    public apiPuzzleActivity(max?: number, _options?: Configuration): Promise<PuzzleRoundJson> {
        const result = this.api.apiPuzzleActivity(max, _options);
        return result.toPromise();
    }

    /**
     * Get the daily Lichess puzzle in JSON format.  Alternatively, you can [post it in your slack workspace](https://lichess.org/daily-puzzle-slack). 
     * Get the daily puzzle
     */
    public apiPuzzleDaily(_options?: Configuration): Promise<any> {
        const result = this.api.apiPuzzleDaily(_options);
        return result.toPromise();
    }

    /**
     * Download your [puzzle dashboard](https://lichess.org/training/dashboard/30/dashboard) as JSON.  Also includes all puzzle themes played, with aggregated results.  Allows re-creating the [improvement/strengths](https://lichess.org/training/dashboard/30/improvementAreas) interfaces. 
     * Get your puzzle dashboard
     * @param days How many days to look back when aggregating puzzle results. 30 is sensible.
     */
    public apiPuzzleDashboard(days: number, _options?: Configuration): Promise<any> {
        const result = this.api.apiPuzzleDashboard(days, _options);
        return result.toPromise();
    }

    /**
     * Download the [storm dashboard](https://lichess.org/storm/dashboard/mrbasso) of any player as JSON.  Contains the aggregated highscores, and the history of storm runs aggregated by days.  Use `?days=0` if you only care about the highscores. 
     * Get the storm dashboard of a player
     * @param username Username of the player
     * @param days How many days of history to return
     */
    public apiStormDashboard(username: string, days?: number, _options?: Configuration): Promise<any> {
        const result = this.api.apiStormDashboard(username, days, _options);
        return result.toPromise();
    }


}



import { ObservableRelationsApi } from './ObservableAPI';

import { RelationsApiRequestFactory, RelationsApiResponseProcessor} from "../apis/RelationsApi";
export class PromiseRelationsApi {
    private api: ObservableRelationsApi

    public constructor(
        configuration: Configuration,
        requestFactory?: RelationsApiRequestFactory,
        responseProcessor?: RelationsApiResponseProcessor
    ) {
        this.api = new ObservableRelationsApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Users are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get users followed the logged in user
     */
    public apiUserFollowing(_options?: Configuration): Promise<UserExtended> {
        const result = this.api.apiUserFollowing(_options);
        return result.toPromise();
    }

    /**
     * Follow a player, adding them to your list of Lichess friends. 
     * Follow a player
     * @param username 
     */
    public followUser(username: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.followUser(username, _options);
        return result.toPromise();
    }

    /**
     * Unfollow a player, removing them from your list of Lichess friends. 
     * Unfollow a player
     * @param username 
     */
    public unfollowUser(username: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.unfollowUser(username, _options);
        return result.toPromise();
    }


}



import { ObservableSimulsApi } from './ObservableAPI';

import { SimulsApiRequestFactory, SimulsApiResponseProcessor} from "../apis/SimulsApi";
export class PromiseSimulsApi {
    private api: ObservableSimulsApi

    public constructor(
        configuration: Configuration,
        requestFactory?: SimulsApiRequestFactory,
        responseProcessor?: SimulsApiResponseProcessor
    ) {
        this.api = new ObservableSimulsApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Get recently finished, ongoing, and upcoming simuls. 
     * Get current simuls
     */
    public apiSimul(_options?: Configuration): Promise<Array<any>> {
        const result = this.api.apiSimul(_options);
        return result.toPromise();
    }


}



import { ObservableStudiesApi } from './ObservableAPI';

import { StudiesApiRequestFactory, StudiesApiResponseProcessor} from "../apis/StudiesApi";
export class PromiseStudiesApi {
    private api: ObservableStudiesApi

    public constructor(
        configuration: Configuration,
        requestFactory?: StudiesApiRequestFactory,
        responseProcessor?: StudiesApiResponseProcessor
    ) {
        this.api = new ObservableStudiesApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Download all chapters of a study in PGN format. 
     * Export all chapters
     * @param studyId The study ID (8 characters).
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param comments Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60; 
     * @param variations Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60; 
     */
    public studyAllChaptersPgn(studyId: string, clocks?: boolean, comments?: boolean, variations?: boolean, _options?: Configuration): Promise<any> {
        const result = this.api.studyAllChaptersPgn(studyId, clocks, comments, variations, _options);
        return result.toPromise();
    }

    /**
     * Download one study chapter in PGN format. 
     * Export one study chapter
     * @param studyId The study ID (8 characters).
     * @param chapterId The chapter ID (8 characters).
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param comments Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60; 
     * @param variations Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60; 
     */
    public studyChapterPgn(studyId: string, chapterId: string, clocks?: boolean, comments?: boolean, variations?: boolean, _options?: Configuration): Promise<any> {
        const result = this.api.studyChapterPgn(studyId, chapterId, clocks, comments, variations, _options);
        return result.toPromise();
    }

    /**
     * Download all chapters of all studies of a user in PGN format.  If authenticated, then all public, unlisted, and private studies are included.  If not, only public, listed studies are included. 
     * Export all studies of a user
     * @param username The user whose studies we export
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param comments Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60; 
     * @param variations Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60; 
     */
    public studyExportAllPgn(username: string, clocks?: boolean, comments?: boolean, variations?: boolean, _options?: Configuration): Promise<any> {
        const result = this.api.studyExportAllPgn(username, clocks, comments, variations, _options);
        return result.toPromise();
    }


}



import { ObservableSwissTournamentsApi } from './ObservableAPI';

import { SwissTournamentsApiRequestFactory, SwissTournamentsApiResponseProcessor} from "../apis/SwissTournamentsApi";
export class PromiseSwissTournamentsApi {
    private api: ObservableSwissTournamentsApi

    public constructor(
        configuration: Configuration,
        requestFactory?: SwissTournamentsApiRequestFactory,
        responseProcessor?: SwissTournamentsApiResponseProcessor
    ) {
        this.api = new ObservableSwissTournamentsApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Join a Swiss tournament, possibly with a password. 
     * Join a Swiss tournament
     * @param id The tournament ID.
     * @param password The tournament password, if one is required
     */
    public apiSwissJoin(id: string, password?: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.apiSwissJoin(id, password, _options);
        return result.toPromise();
    }

    /**
     * Create a Swiss tournament for your team.  This endpoint mirrors the Swiss tournament form from your team pagee.  You can create up to 12 tournaments per day. 
     * Create a new Swiss tournament
     * @param teamId ID of the team
     * @param clockLimit Clock initial time in seconds
     * @param clockIncrement Clock increment in seconds
     * @param nbRounds Maximum number of rounds to play
     * @param name The tournament name. Leave empty to get a random Grandmaster name
     * @param startsAt Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation.
     * @param roundInterval How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI. 
     * @param variant 
     * @param description Anything you want to tell players about the tournament
     * @param rated Games are rated and impact players ratings
     * @param chatFor Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players 
     */
    public apiSwissNew(teamId: string, clockLimit: number, clockIncrement: number, nbRounds: number, name?: string, startsAt?: number, roundInterval?: number, variant?: VariantKey, description?: string, rated?: boolean, chatFor?: number, _options?: Configuration): Promise<any> {
        const result = this.api.apiSwissNew(teamId, clockLimit, clockIncrement, nbRounds, name, startsAt, roundInterval, variant, description, rated, chatFor, _options);
        return result.toPromise();
    }

    /**
     * Terminate a Swiss tournament 
     * Terminate a Swiss tournament
     * @param id The Swiss tournament ID.
     */
    public apiSwissTerminate(id: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.apiSwissTerminate(id, _options);
        return result.toPromise();
    }

    /**
     * Update a Swiss tournament.  Be mindful not to make important changes to ongoing tournaments. 
     * Update a Swiss tournament.
     * @param id The tournament ID.
     * @param clockLimit Clock initial time in seconds
     * @param clockIncrement Clock increment in seconds
     * @param nbRounds Maximum number of rounds to play
     * @param name The tournament name. Leave empty to get a random Grandmaster name
     * @param startsAt Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation.
     * @param roundInterval How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI. 
     * @param variant 
     * @param description Anything you want to tell players about the tournament
     * @param rated Games are rated and impact players ratings
     * @param chatFor Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players 
     */
    public apiSwissUpdate(id: string, clockLimit: number, clockIncrement: number, nbRounds: number, name?: string, startsAt?: number, roundInterval?: number, variant?: VariantKey, description?: string, rated?: boolean, chatFor?: number, _options?: Configuration): Promise<any> {
        const result = this.api.apiSwissUpdate(id, clockLimit, clockIncrement, nbRounds, name, startsAt, roundInterval, variant, description, rated, chatFor, _options);
        return result.toPromise();
    }

    /**
     * Get all swiss tournaments of a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get team swiss tournaments
     * @param teamId 
     * @param max How many tournaments to download.
     */
    public apiTeamSwiss(teamId: string, max?: number, _options?: Configuration): Promise<Array<any>> {
        const result = this.api.apiTeamSwiss(teamId, max, _options);
        return result.toPromise();
    }

    /**
     * Download games of a swiss tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (last round first) 
     * Export games of a Swiss tournament
     * @param id The tournament ID.
     * @param moves Include the PGN moves.
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @param tags Include the PGN tags.
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     */
    public gamesBySwiss(id: string, moves?: boolean, pgnInJson?: boolean, tags?: boolean, clocks?: boolean, evals?: boolean, opening?: boolean, _options?: Configuration): Promise<any> {
        const result = this.api.gamesBySwiss(id, moves, pgnInJson, tags, clocks, evals, opening, _options);
        return result.toPromise();
    }

    /**
     * Players of a swiss tournament, with their score and performance, sorted by rank (best first).  Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 
     * Get results of a swiss tournament
     * @param id The tournament ID.
     * @param nb Max number of players to fetch
     */
    public resultsBySwiss(id: string, nb?: number, _options?: Configuration): Promise<any> {
        const result = this.api.resultsBySwiss(id, nb, _options);
        return result.toPromise();
    }

    /**
     * Download a tournament in the Tournament Report File format, the FIDE standard.  Documentation: <https://www.fide.com/FIDE/handbook/C04Annex2_TRF16.pdf>  Example: <https://lichess.org/swiss/j8rtJ5GL.trf> 
     * Export TRF of a Swiss tournament
     * @param id The tournament ID.
     */
    public swissTrf(id: string, _options?: Configuration): Promise<string> {
        const result = this.api.swissTrf(id, _options);
        return result.toPromise();
    }


}



import { ObservableTVApi } from './ObservableAPI';

import { TVApiRequestFactory, TVApiResponseProcessor} from "../apis/TVApi";
export class PromiseTVApi {
    private api: ObservableTVApi

    public constructor(
        configuration: Configuration,
        requestFactory?: TVApiRequestFactory,
        responseProcessor?: TVApiResponseProcessor
    ) {
        this.api = new ObservableTVApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Get a list of ongoing games for a given TV channel. Similar to [lichess.org/games](https://lichess.org/games).  Available in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format, depending on the request Accept header. 
     * Get best ongoing games of a TV channel
     * @param channel The name of the channel in lowercase.
     * @param nb Number of games to fetch.
     * @param moves Include the PGN moves.
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @param tags Include the PGN tags.
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     */
    public tvChannelGames(channel: string, nb?: number, moves?: boolean, pgnInJson?: boolean, tags?: boolean, clocks?: boolean, opening?: boolean, _options?: Configuration): Promise<any> {
        const result = this.api.tvChannelGames(channel, nb, moves, pgnInJson, tags, clocks, opening, _options);
        return result.toPromise();
    }

    /**
     * Get basic info about the best games being played for each speed and variant, but also computer games and bot games.  See [lichess.org/tv](https://lichess.org/tv). 
     * Get current TV games
     */
    public tvChannels(_options?: Configuration): Promise<any> {
        const result = this.api.tvChannels(_options);
        return result.toPromise();
    }

    /**
     * Stream positions and moves of the current [TV game](https://lichess.org/tv) in [ndjson](#section/Introduction/Streaming-with-ND-JSON). A summary of the game is sent as a first message, and when the featured game changes.  Try it with `curl https://lichess.org/api/tv/feed`. 
     * Stream current TV game
     */
    public tvFeed(_options?: Configuration): Promise<any> {
        const result = this.api.tvFeed(_options);
        return result.toPromise();
    }


}



import { ObservableTablebaseApi } from './ObservableAPI';

import { TablebaseApiRequestFactory, TablebaseApiResponseProcessor} from "../apis/TablebaseApi";
export class PromiseTablebaseApi {
    private api: ObservableTablebaseApi

    public constructor(
        configuration: Configuration,
        requestFactory?: TablebaseApiRequestFactory,
        responseProcessor?: TablebaseApiResponseProcessor
    ) {
        this.api = new ObservableTablebaseApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Tablebase lookup for Antichess
     */
    public antichessAtomic(_options?: Configuration): Promise<string> {
        const result = this.api.antichessAtomic(_options);
        return result.toPromise();
    }

    /**
     * Tablebase lookup for Atomic chess
     */
    public tablebaseAtomic(_options?: Configuration): Promise<string> {
        const result = this.api.tablebaseAtomic(_options);
        return result.toPromise();
    }

    /**
     * **Endpoint: <https://tablebase.lichess.ovh>**  Example: `curl http://tablebase.lichess.ovh/standard?fen=4k3/6KP/8/8/8/8/7p/8_w_-_-_0_1` 
     * Tablebase lookup
     * @param fen FEN of the position. Underscores allowed.
     */
    public tablebaseStandard(fen: string, _options?: Configuration): Promise<TablebaseJson> {
        const result = this.api.tablebaseStandard(fen, _options);
        return result.toPromise();
    }


}



import { ObservableTeamsApi } from './ObservableAPI';

import { TeamsApiRequestFactory, TeamsApiResponseProcessor} from "../apis/TeamsApi";
export class PromiseTeamsApi {
    private api: ObservableTeamsApi

    public constructor(
        configuration: Configuration,
        requestFactory?: TeamsApiRequestFactory,
        responseProcessor?: TeamsApiResponseProcessor
    ) {
        this.api = new ObservableTeamsApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get team Arena tournaments
     * @param teamId ID of the team
     * @param max How many tournaments to download.
     */
    public apiTeamArena(teamId: string, max?: number, _options?: Configuration): Promise<Array<any>> {
        const result = this.api.apiTeamArena(teamId, max, _options);
        return result.toPromise();
    }

    /**
     * Get all swiss tournaments of a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get team swiss tournaments
     * @param teamId 
     * @param max How many tournaments to download.
     */
    public apiTeamSwiss(teamId: string, max?: number, _options?: Configuration): Promise<Array<any>> {
        const result = this.api.apiTeamSwiss(teamId, max, _options);
        return result.toPromise();
    }

    /**
     * Paginator of the most popular teams. 
     * Get popular teams
     * @param page 
     */
    public teamAll(page?: number, _options?: Configuration): Promise<InlineResponse2001> {
        const result = this.api.teamAll(page, _options);
        return result.toPromise();
    }

    /**
     * Join a team. If the team requires a password but the `password` field is incorrect, then the call fails with `403 Forbidden`. Similarly, if the team join policy requires a confirmation but the `message` parameter is not given, then the call fails with `403 Forbidden`. 
     * Join a team
     * @param teamId 
     * @param message Optional request message, if the team requires one.
     * @param password Optional password, if the team requires one.
     */
    public teamIdJoin(teamId: string, message?: string, password?: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.teamIdJoin(teamId, message, password, _options);
        return result.toPromise();
    }

    /**
     * Kick a member out of one of your teams. - <https://lichess.org/team> 
     * Kick a user from your team
     * @param teamId 
     * @param userId 
     */
    public teamIdKickUserId(teamId: string, userId: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.teamIdKickUserId(teamId, userId, _options);
        return result.toPromise();
    }

    /**
     * Send a private message to all members of a team. You must own the team. 
     * Message all members
     * @param teamId 
     * @param message The message to send to all your team members.
     */
    public teamIdPmAll(teamId: string, message?: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.teamIdPmAll(teamId, message, _options);
        return result.toPromise();
    }

    /**
     * Leave a team. - <https://lichess.org/team> 
     * Leave a team
     * @param teamId 
     */
    public teamIdQuit(teamId: string, _options?: Configuration): Promise<Ok> {
        const result = this.api.teamIdQuit(teamId, _options);
        return result.toPromise();
    }

    /**
     * Members are sorted by reverse chronological order of joining the team (most recent first). OAuth only required if the list of members is private.  Members are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get members of a team
     * @param teamId 
     */
    public teamIdUsers(teamId: string, _options?: Configuration): Promise<UserExtended> {
        const result = this.api.teamIdUsers(teamId, _options);
        return result.toPromise();
    }

    /**
     * All the teams a player is a member of. 
     * Teams of a player
     * @param username 
     */
    public teamOfUsername(username: string, _options?: Configuration): Promise<Array<Team>> {
        const result = this.api.teamOfUsername(username, _options);
        return result.toPromise();
    }

    /**
     * Paginator of team search results for a keyword. 
     * Search teams
     * @param text 
     * @param page 
     */
    public teamSearch(text?: string, page?: number, _options?: Configuration): Promise<Array<Team>> {
        const result = this.api.teamSearch(text, page, _options);
        return result.toPromise();
    }

    /**
     * Infos about a team
     * Get a single team
     * @param teamId 
     */
    public teamShow(teamId: string, _options?: Configuration): Promise<Team> {
        const result = this.api.teamShow(teamId, _options);
        return result.toPromise();
    }


}



import { ObservableUsersApi } from './ObservableAPI';

import { UsersApiRequestFactory, UsersApiResponseProcessor} from "../apis/UsersApi";
export class PromiseUsersApi {
    private api: ObservableUsersApi

    public constructor(
        configuration: Configuration,
        requestFactory?: UsersApiRequestFactory,
        responseProcessor?: UsersApiResponseProcessor
    ) {
        this.api = new ObservableUsersApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Get total number of games, and current score, of any two users.  If the `matchup` flag is provided, and the users are currently playing, also gets the current match game number and scores. 
     * Get crosstable
     * @param user1 
     * @param user2 
     * @param matchup Whether to get the current match data, if any
     */
    public apiCrosstable(user1: string, user2: string, matchup?: boolean, _options?: Configuration): Promise<any> {
        const result = this.api.apiCrosstable(user1, user2, matchup, _options);
        return result.toPromise();
    }

    /**
     * Read public data of a user. 
     * Get user public data
     * @param username 
     */
    public apiUser(username: string, _options?: Configuration): Promise<UserExtended> {
        const result = this.api.apiUser(username, _options);
        return result.toPromise();
    }

    /**
     * Read data to generate the activity feed of a user. 
     * Get user activity
     * @param username 
     */
    public apiUserActivity(username: string, _options?: Configuration): Promise<void> {
        const result = this.api.apiUserActivity(username, _options);
        return result.toPromise();
    }

    /**
     * Read performance statistics of a user, for a single performance. Similar to the [performance pages on the website](https://lichess.org/@/thibault/perf/bullet). 
     * Get performance statistics of a user
     * @param username 
     * @param perf 
     */
    public apiUserPerf(username: string, perf: PerfType, _options?: Configuration): Promise<any> {
        const result = this.api.apiUserPerf(username, perf, _options);
        return result.toPromise();
    }

    /**
     * Read rating history of a user, for all perf types. There is at most one entry per day. Format of an entry is `[year, month, day, rating]`. `month` starts at zero (January). 
     * Get rating history of a user
     * @param username 
     */
    public apiUserRatingHistory(username: string, _options?: Configuration): Promise<any> {
        const result = this.api.apiUserRatingHistory(username, _options);
        return result.toPromise();
    }

    /**
     * Get up to 300 users by their IDs. Users are returned in the same order as the IDs.  The method is `POST` so a longer list of IDs can be sent in the request body. 
     * Get users by ID
     * @param body User IDs separated by commas.
     */
    public apiUsers(body: string, _options?: Configuration): Promise<Array<User>> {
        const result = this.api.apiUsers(body, _options);
        return result.toPromise();
    }

    /**
     * Read the `online`, `playing` and `streaming` flags of several users.  This API is very fast and cheap on lichess side. So you can call it quite often (like once every 5 seconds).  Use it to track players and know when they're connected on lichess and playing games. 
     * Get real-time users status
     * @param ids User IDs separated by commas. Up to 100 IDs.
     */
    public apiUsersStatus(ids: string, _options?: Configuration): Promise<Array<InlineResponse200>> {
        const result = this.api.apiUsersStatus(ids, _options);
        return result.toPromise();
    }

    /**
     * Get the top 10 players for each speed and variant.  See <https://lichess.org/player>. 
     * Get all top 10
     */
    public player(_options?: Configuration): Promise<any> {
        const result = this.api.player(_options);
        return result.toPromise();
    }

    /**
     * Get the leaderboard for a single speed or variant (a.k.a. `perfType`). There is no leaderboard for correspondence or puzzles.  See <https://lichess.org/player/top/200/bullet>. 
     * Get one leaderboard
     * @param nb How many users to fetch
     * @param perfType The speed or variant
     */
    public playerTopNbPerfType(nb: number, perfType: 'ultraBullet' | 'bullet' | 'blitz' | 'rapid' | 'classical' | 'chess960' | 'crazyhouse' | 'antichess' | 'atomic' | 'horde' | 'kingOfTheHill' | 'racingKings' | 'threeCheck', _options?: Configuration): Promise<any> {
        const result = this.api.playerTopNbPerfType(nb, perfType, _options);
        return result.toPromise();
    }

    /**
     * Get basic info about currently streaming users.  This API is very fast and cheap on lichess side. So you can call it quite often (like once every 5 seconds). 
     * Get live streamers
     */
    public streamerLive(_options?: Configuration): Promise<Array<InlineResponse2002>> {
        const result = this.api.streamerLive(_options);
        return result.toPromise();
    }

    /**
     * Members are sorted by reverse chronological order of joining the team (most recent first). OAuth only required if the list of members is private.  Members are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get members of a team
     * @param teamId 
     */
    public teamIdUsers(teamId: string, _options?: Configuration): Promise<UserExtended> {
        const result = this.api.teamIdUsers(teamId, _options);
        return result.toPromise();
    }


}



